function [t_nodes,density] = Nystrom_Kelvin(curve_obj,num_trap,index_bdyf)

% This program sets up the linear system for solving the integral equation
% of the second kind based on using a double-layer potential to represent
% the solution of the interior Dirichlet problem for Laplace's equation.
% The numerical method is Nystrom's method with the trapezoidal rule. 
% See Section 7.2 (page 320) and formula (7.2.49) of my integral
% equations text.
%
% This is not intended for use only with completely smooth boundaries,
% unlike the use of pw_poly_collocation which does allow for a single 
% corner point.

% Input parameters:
% curve_obj -   This is an object identifying the type of boundary
%               curve on which Laplace's equation is being solved. It also
%               includes information regarding the definition of that
%               curve.
% num_trap -    The number of quadrature points for the definition of the
%               numerical integration approximation of the double layer 
%               operator.
% index_bdyf -  This is the index of the boundary function, given in the
%               external program 'bdyfcn'.

% Output values:
% t_nodes -     These are the node points at which the density function
%               is approximated.
% density -     These are the estimated values of the unknown double layer
%               density function.

% The parameterization interval is [0,L].
curve_parms = curve_obj.curve_parms;
L = curve_parms.length;

% Create the quadrature nodes and the subdivision of [0,L].
h_trap = L/num_trap;
t_nodes = h_trap*(1:num_trap)';

[point_orig,point_kelvin] = generate_curve_Kelvin(t_nodes,curve_obj);
x_nodes = point_kelvin.xk; y_nodes = point_kelvin.yk; 
dx_nodes = point_kelvin.dxk; dy_nodes = point_kelvin.dyk; 
d2x_nodes = point_kelvin.d2xk; d2y_nodes = point_kelvin.d2yk; 

% Calculate the array of kernel values to be used in evaluating the
% collocation integrals.
K_matrix = generate_K_Nystrom(num_trap,x_nodes,y_nodes,dx_nodes,...
    dy_nodes,d2x_nodes,d2y_nodes);

% Create the Nystrom system matrix.
KM = -pi*eye(num_trap) + h_trap*K_matrix;

% Create the right hand side of the linear system.
rhs = bdyfcn(t_nodes,point_orig.x,point_orig.y,index_bdyf);
if is_row(rhs)
    rhs = rhs';
end

% Solve the double-layer density function.
density = KM\rhs;

end % Nystrom_Kelvin
