function cans = conjugate_function_Nystrom_Kelvin(t,x_t,y_t,t_spline,...
    density_spline,curve_obj)

% Evaluate the conjugate function (Miller, pages 32-33, formula (2.18c)),
% at the scalar parameterization point t and the corresponding point 
% (x_t,y_t) on the curve.

% The formula for the conjugate function on the boundary is an integral. We 
% will integrate it over each subinterval as determined by the nodes in 
% t_spline, and we use Gauss quadrature of a given order over each 
% subinterval. This order is called cf_quad_order, and generally it can be
% chosen small, say 3. We set it in this program rather than as an input
% parameter. The structure curve_obj contains the needed information
% defining the boundary curve.

cf_quad_order = 3;
[quad_nodes,quad_wts] = gauss_nodes_wts(cf_quad_order,0,1);
L = 2*pi;

point_t = [t,x_t,y_t];
density_t = ppval(density_spline,t);
lnth = length(t_spline);

[lower,upper] = find_interval(t,t_spline);
a_t = t_spline(lower); b_t = t_spline(upper);

% Determine if t equals either t_spline(lower) or t_spline(upper).
if abs(a_t - t) < 100*eps || abs(b_t - t) < 100*eps
    % t is a subdivision node point.
    cans = 0;
    for i=1:lnth-1
        h = t_spline(i+1) - t_spline(i);
        s = t_spline(i) + h*quad_nodes;
        density_s = ppval(density_spline,s);
        [~,point_kelvin_s] = generate_curve_Kelvin(s,curve_obj);
        x = point_kelvin_s.xk; y = point_kelvin_s.yk; 
        dx = point_kelvin_s.dxk; dy = point_kelvin_s.dyk; 
        for j=1:cf_quad_order
            point_s = [s(j),x(j),y(j),dx(j),dy(j)];
            f = conjugate_kernel_Nystrom(point_t,point_s,density_t,...
                density_s(j));
            cans = cans + quad_wts(j)*h*f;
        end
    end
    return
end

% t is internal to [a_t,b_t] = [t_spline(i_t),t_spline(i_t+1)].
cans = 0;
for i=1:lower-1
    h = t_spline(i+1) - t_spline(i);
    s = t_spline(i) + h*quad_nodes;
    density_s = ppval(density_spline,s);
    [~,point_kelvin_s] = generate_curve_Kelvin(s,curve_obj);
    x = point_kelvin_s.xk; y = point_kelvin_s.yk; 
    dx = point_kelvin_s.dxk; dy = point_kelvin_s.dyk; 
    for j=1:cf_quad_order
        point_s = [s(j),x(j),y(j),dx(j),dy(j)];
        f = conjugate_kernel(point_t,point_s,density_t,density_s(j));
        cans = cans + quad_wts(j)*h*f;
    end
end

h = t - a_t;
s = a_t + h*quad_nodes;
density_s = ppval(density_spline,s);
[~,point_kelvin_s] = generate_curve_Kelvin(s,curve_obj);
x = point_kelvin_s.xk; y = point_kelvin_s.yk;
dx = point_kelvin_s.dxk; dy = point_kelvin_s.dyk; 
for j=1:cf_quad_order
    point_s = [s(j),x(j),y(j),dx(j),dy(j)];
    f = conjugate_kernel(point_t,point_s,density_t,density_s(j));
    cans = cans + quad_wts(j)*h*f;
end

h = b_t - t;
s = t + h*quad_nodes;
density_s = ppval(density_spline,s);
[~,point_kelvin_s] = generate_curve_Kelvin(s,curve_obj);
x = point_kelvin_s.xk; y = point_kelvin_s.yk;
dx = point_kelvin_s.dxk; dy = point_kelvin_s.dyk; 
for j=1:cf_quad_order
    point_s = [s(j),x(j),y(j),dx(j),dy(j)];
    f = conjugate_kernel(point_t,point_s,density_t,density_s(j));
    cans = cans + quad_wts(j)*h*f;
end

for i=upper:lnth-1
    h = t_spline(i+1) - t_spline(i);
    s = t_spline(i) + h*quad_nodes;
    [~,point_kelvin_s] = generate_curve_Kelvin(s,curve_obj);
    x = point_kelvin_s.xk; y = point_kelvin_s.yk; 
    dx = point_kelvin_s.dxk; dy = point_kelvin_s.dyk; 
    for j=1:cf_quad_order
        point_s = [s(j),x(j),y(j),dx(j),dy(j)];
        f = conjugate_kernel(point_t,point_s,density_t,density_s(j));
        cans = cans + quad_wts(j)*h*f;
    end
end

end % conjugate_function_Nystrom
