function [t_spline,spline_cf] ...
    = create_spline_conj_fcn_Nystrom_Kelvin(t_nodes,density,...
          curve_obj,multiplier_spline,index_bdyf)

% Create a spline approximation of the conjugate function. For the spacing,
% use num_trap*multiplier_spline subdivisions, where num_trap is number of
% subdivisions that were used in solving for the original double layer
% density function over the boundary. (multiplier_spline should be a
% positive integer.)

% INPUT:
% t_nodes - These are the nodes at which the Nystrom approximation was
%           computed using the trapezoidal rule. The number of subdivisions
%           length(num_trap).
% density - This is the Nystrom solution for the double layer density.
% curve_obj - This structure contains the information about the boundary.
% multiplier_spline - A positive integer used to determine the spacing for
%           creating the cubic spline. Use multiplier_spline*num_trap
%           subdivisions.
% index_bdyf - The index of boundary function when there is more than one 
%           choice. Use index_bdyf = 1 when there is only one such
%           function.
%
% OUTPUT:
% t_spline - The nodes for the cubic spline interpolating the conjugate
%           function.
% spline_cf - The structure defining the interpolating spline.

curve_parms = curve_obj.curve_parms;
L = curve_parms.length;

num_trap = length(t_nodes); h_trap = L/num_trap;

h_spline = L/(multiplier_spline*num_trap);
t_spline = 0:h_spline:L;
lnth = length(t_spline);
t_spline = [0,h_spline/2,t_spline(2:lnth-1),L-h_spline/2,L]';
num_spline = length(t_spline);

% Using Nystrom interpolation, extend the (double layer) density to the new
% node points in t_spline. Begin by calculating the needed curve values at
% the parameterization points in t_nodes and t_spline.
[~,point_kelvin_t] = generate_curve_Kelvin(t_nodes,curve_obj);
x_nodes = point_kelvin_t.xk; y_nodes = point_kelvin_t.yk; 
dx_nodes = point_kelvin_t.dxk; dy_nodes = point_kelvin_t.dyk; 
d2x_nodes = point_kelvin_t.d2xk; d2y_nodes = point_kelvin_t.d2yk; 

[point_orig_sp,point_kelvin_sp] = generate_curve_Kelvin(t_spline,curve_obj);
x_spline = point_kelvin_sp.xk; y_spline = point_kelvin_sp.yk; 

rhs = bdyfcn(t_spline,point_orig_sp.x,point_orig_sp.y,index_bdyf);

density_t_spline = zeros(num_spline,1);

% Use Nystrom interpolation to extend to t_spline the approximation of the
% double layer density function.
for ii=1:num_spline
    point_t = [x_spline(ii),y_spline(ii)];
    for j=1:num_trap
        point_s = [x_nodes(j),y_nodes(j),dx_nodes(j),dy_nodes(j),...
                d2x_nodes(j),d2y_nodes(j)];
        fker = kernel_Nystrom(point_t,point_s);
        density_t_spline(ii) = density_t_spline(ii) + fker*density(j);
    end
    density_t_spline(ii) = (h_trap*density_t_spline(ii) - rhs(ii))/pi;
end

density_spline = spline(t_spline,density_t_spline);

cf_values = zeros(num_spline,1);
for i=1:num_spline
    t = t_spline(i);
    [~,pt_kelvin_t] = generate_curve_Kelvin(t,curve_obj);
    temp = conjugate_function_Nystrom_Kelvin(t,pt_kelvin_t.xk,...
        pt_kelvin_t.yk,t_spline,density_spline,curve_obj);
    cf_values(i) = temp;
end

% Create the spline interpolating the conjugate function values.
spline_cf = spline(t_spline,cf_values);

end % create_spline_conjugate_fcn_Nystrom_Kelvin