function demo_bie_Nystrom_Kelvin(curve,num_trap,index_bdyf)

% Copyright 2013 by Kendall Atkinson
%
% This demonstrates various programs in the package, all associated with
% solving the exterior Dirichlet problem over the exterior region D_e. The
% solution method is based on transforming the problem to an interior
% Dirichlet problem via the Kelvin transform. The solution of this
% transformed problem is obtained by representing it as a double layer
% potential over a bounded interior region. The unknown dipole density
% function is approximated using Nystrom's method applied to a boundary
% integral equation of the second kind.
%
% The boundary is to be smooth and the complementary interior region D_i is 
% to be simply-connected. Two sample regions, with boundary an ellipse and 
% a limacon, are given in the subprogram 'set_bdy_param', given  following 
% the main program. The full definition of each curve is given in the 
% routine 'generate_curve'. The complementary interior region D_i is to 
% contain the origin. 
%
% For this test program, in order to test the evaluation of the potential 
% over the full region, we also assume that the inversion of D_e through 
% the unit circle, call it D_i:kelvin, contains a special point A with 
% respect to which it is starlike. This assumption is convenient as a means 
% of checking the computation of the double layer potential.
%
% As a part of this demo program, the boundary curve and the inverted
% boundary curve are shown. In addition, we provide a special print 
% instruction for information about each curve, given below in this current 
% program. 
%
% For the test case boundary value functions and true solutions, see the
% programs 'bdyfcn' and 'normal_deriv_bdyf'. Let u denote the solution
% of the exterior Dirichlet problem over D_e and let U denote the Kelvin 
% transform of u, defined over D_i:kelvin. The function U is harmonic over
% D_i:kelvin, and we represent it as a double layer potential with an
% unknown dipole density function.
% 
% The numerical method is Nystrom's method, carried out in the program 
% 'Nystrom_Kelvin'.  We also evaluate the approximating potential solution 
% and its error, doing so for the solution U over the bounded inverted 
% interior region. This is carried out in the programs 
% 'test_evaluate_potential_Nystrom' and 'test_evaluate_potential2_Nystrom'.  
% The first evaluates the potential along a line toward the boundary from 
% the given point A, and the second evaluates over the entire region. 
% Finally, we evaluate the conjugate solution over the boundary and we use 
% it to evaluate the normal derivative of the solution of the original 
% problem. This is done in the routine 'test_normal_deriv_method_Nystrom'.
%
% As a demonstration, use one of the commands and sample data.
%   demo_bie_Nystrom_Kelvin('ellipse',40,1)     Use a=1.5, b=0.75
%   demo_bie_Nystrom_Kelvin('cardioid',40,1)    Use c=0.8, k=1.0, a=b=1
% In all cases, we suggest using n_rad=10, n_ang=20 in the program
% 'test_evaluate_potential_Nystrom_Kelvin'.
%
% This program will request information defining the curve.  Later it will
% ask for information to set up a grid over the region for evaluating the
% double layer potential for U over D_i:kelvin.  At each point (x,y) in 
% this region, the double layer integral will be approximated using the 
% trapezoidal rule with num_trap*multiplier subdivisions of the boundary.
%
% The user must specify the name of the curve; see the function
% 'set_bdy_param' given below for examples of defining the curve. You must
% also provide the number of subdivisions, called num_trap, and the 
% quantity called multiplier, used in determining the numerical integration 
% over the boundary for the conjugate function and other quantities. You
% must also provide the index of the problem (index_bdyf) that is to be
% solved. Other parameters given below can be changed.  
%
% The structure 'curve_obj' is to contain the name of the curve and the
% structure 'curve_parms'.  The latter contains the data defining the
% curve, and this will vary with the curve being considered.
%
% INPUT:
% curve -       The name of the boundary curve.
% num_trap -    The number of subdivisions used in applying the Nystrom
%               method with the trapezoidal rule to the solution of the
%               double layer potential integral equation.
% index_bdyf -  This is the index for the boundary function, given in the
%               external program 'bdyfcn'.

% Display the input parameters.
disp(' ')
disp('INPUT PARAMETERS:')
disp(['curve = ',curve])
disp(['index_bdyf = ',num2str(index_bdyf)])
disp(['num_trap = ',num2str(num_trap)])
disp(' ')

[curve_parms, ~, ~] = set_bdy_param(curve);
disp(' ')

% The structure 'curve_obj' is to contain the name of the curve and the
% structure 'curve_parms'.  The latter contains the data defining the
% curve, and this will vary with the curve being considered.
curve_obj.name = curve;
curve_obj.curve_parms = curve_parms;
num_plot_curve_points = 200;
draw_bdy_Kelvin(curve_obj,num_plot_curve_points)
figure(gcf)
pause

[t_nodes_Nystrom,density_Nystrom] = Nystrom_Kelvin(...
                                      curve_obj,num_trap,index_bdyf);
test.density_Nystrom = density_Nystrom;
test.t_nodes_Nystrom = t_nodes_Nystrom;

figure
disp(' ')
disp(['This is the graph of the Nystrom-based double layer',...
    ' density function.'])
plot(t_nodes_Nystrom,density_Nystrom)
name = curve_obj.name;
title(['Interior Dirichlet Problem on ',name,...
    ': The Double Layer Density Function + Nystrom'])
print_curve_data(curve)
pause

disp(' ')
disp('We evaluate the double layer potential U along a line joining a ')
disp('given point A and a point on the boundary of the inverted boundary.')
disp('and a point on the boundary. The boundary point is specified by')
disp('giving its parameter value t, and you are to specify this value t.')
disp('In addition, numerical integration will be used over the ')
disp('parameterization interval of the boundary curve.  You will be asked')
disp('for a parameter used to determine the number of quadrature points.')

test_evaluate_potential_Nystrom_Kelvin(curve_obj,index_bdyf,test)
pause

disp(' ')
disp('We evaluate the potential over the bounded region D_i:kelvin.  We')
disp('use the assumption that the region is starlike with respect to the')
disp('origin to generate a polar coordinates type of grid in the interior')
disp('region. You will be asked for the number of subdivisions in')
disp('radial and angular directions.')
disp(' ')
disp('In addition, quadrature over the parameterization [0,L] of the')
disp('boundary curve is needed.  You will be asked for a multiplier that')
disp('determines the number of quadrature nodes to be used on [0,L].')

test_evaluate_potential2_Nystrom_Kelvin(curve_obj,index_bdyf,test)
pause

% Calculate the normal derivative of u over the boundary of the exterior
% region.
test_normal_deriv_method_Nystrom_Kelvin(curve_obj,index_bdyf,test)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function print_curve_data(curve)
% The following print contains curve dependent parameters.
switch curve
    case 'ellipse'
        a = curve_parms.ellipse_a; b = curve_parms.ellipse_b;     % Ellipse parameters        
        xlabel(['a = ',num2str(a),'   b = ',num2str(b),'   num:trap = ',...
            num2str(num_trap)])
    case 'cardioid'
        a = curve_parms.cardioid_a; b = curve_parms.cardioid_b;           
        c = curve_parms.cardioid_c; k = curve_parms.cardioid_k; % Cardioid parameters
        xlabel(['c = ',num2str(c),'   k = ',num2str(k),...
            '   a = ',num2str(a),'   b = ',num2str(b),'   num:trap = ',...
            num2str(num_trap)])
end
end % print_curve_data

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

end % demo_bie_Nystrom_Kelvin

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function [curve_parms, grading_param, spacing] = set_bdy_param(curve)
    
switch curve
    case 'ellipse'
        % Define the object containing the needed curve parameters for an ellipse.
        curve_parms.length = 2*pi;    % The length of the parameterization interval.
        disp('Give curve parameters for the ellipse.')
        disp('      (x/a)^2 + (y/b)^2 = 1')
        a = input('a = '); b = input('b = ');
        curve_parms.ellipse_a = a; curve_parms.ellipse_b = b; 
    case 'cardioid'
        % Define the object containing the needed curve parameters for a cardioid.
        % Initially try c=.8, k=1, a=b=1.
        curve_parms.length = 2*pi;    % The length of the parameterization interval.
        disp('Give the parameters for the cardioid')
        disp('(x,y) = (c*cos(t)+k)*(a*cos(t),b*sin(t)),   k > c')
        c = input('c = '); k = input('k = '); 
        a = input('a = '); b = input('b = ');
        curve_parms.cardioid_a = a; curve_parms.cardioid_b = b; 
        curve_parms.cardioid_c = c; curve_parms.cardioid_k = k; 
end

switch curve
    case 'ellipse'
        curve_parms.int_pt = [0 0];
    case 'cardioid'
        curve_parms.int_pt = [0,0];
end

% Allow input of grading parameter for the case of curve='teardrop'.
switch curve
    case 'ellipse'
        grading_param = 1;
        spacing = 'uniform';
    case {'cardioid'}
        grading_param = 1;
        spacing = 'uniform';
end

end % set_bdy_param
