function [cf_values,deriv_cf_values] = ...
    eval_spline_conj_fcn_Nystrom_Kelvin(t_eval,curve_obj,t_nodes,...
    density,multiplier_spline,index_bdyf)

% Create the spline interpolant on the boundary of the conjugate function
% for the Kelvin transform of the double layer harmonic function solving
% our exterior Dirichlet problem. Using it, calculate the normal derivative
% of the solution of our exterior Dirichlet problem at the parameterization
% points given in t_eval.
%
% INPUT:
% t_eval -  The evaluation points in the parameterization interval.
% curve_obj - This structure contains the information about the boundary.
% t_nodes - These are the parameterization node points for the Nystrom
%           approximation of our double layer.
% density - The Nystrom approximation of our double layer.
% multiplier_spline - A positive integer used to determine the spacing for
%           creating the cubic spline. Use multiplier_spline*num_trap
%           subdivisions.
% index_bdyf - The index of boundary function when there is more than one 
%           choice. Use index_bdyf = 1 when there is only one such
%           function.
% 
% OUTPUT:
% cf_values - The values of the conjugate function for the Kelvin transform
%           of the double layer harmonic function solving our exterior 
%           Dirichlet problem. 
% deriv_cf_values - The normal derivative values, at t_eval, of the 
%           solution of our exterior Dirichlet problem

curve_parms = curve_obj.curve_parms;
L = curve_parms.length;

[t_spline,spline_cf] = create_spline_conj_fcn_Nystrom_Kelvin(...
    t_nodes,density,curve_obj,multiplier_spline,index_bdyf);
[~,cf,num_int,~,~] = unmkpp(spline_cf);

delta = t_spline(3)-t_spline(1);
% Discard the interpolation points corresponding to the parameter points 
% delta/2 and L-delta/2. The cubic polynomials on [0,delta/2] and on
% [delta/2,delta] are the same, and therefore the polynomial on [0,delta/2]
% suffices for all of [0,delta].  The analogous result is true for the
% interval [L-delta,L].
t_spline = 0:delta:L;
cf = [cf(1,:)
      cf(3:num_int-1,:)];
[m,~] = size(cf);

lnth = length(t_eval);
cf_values = zeros(size(t_eval));
deriv_cf_values = zeros(size(t_eval));

for i=1:lnth
    t = t_eval(i);
    num_int = floor(1+t/delta);
    if num_int > m
        num_int = m;
    end
    if num_int < 1
        num_int = 1;
    end
    j = num_int;
    h = t - t_spline(j);
    cf_values(i) = cf(j,4)+h*(cf(j,3)+h*(cf(j,2)+h*cf(j,1)));
    deriv_cf_values(i) = cf(j,3)+h*(2*cf(j,2)+3*h*cf(j,1));
    % Correction for not using arc length as the parameterization variable
    [~,point_kelvin] = generate_curve_Kelvin(t,curve_obj);
    x = point_kelvin.xk; y = point_kelvin.yk; 
    dx = point_kelvin.dxk; dy = point_kelvin.dyk; 
    % Create the outer normal derivative
    deriv_cf_values(i) = -(x^2+y^2)*deriv_cf_values(i)/sqrt(dx^2+dy^2);
end

end % eval_spline_conjugate_fcn_Nystrom_Kelvin