function potential = evaluate_potential_Nystrom_Kelvin(x_eval,y_eval,...
   t_nodes,density,index_bdyf,curve_obj,multiplier)

% Let U be the Kelvin transform of the solution u to our exterior Dirichlet
% problem; U is defined over the inversion of our exterior region. The 
% double layer representation of U is approximated using the Nystrom method. 
% Evaluate the double-layer potential U with the given "density" function
% at the nodes given in (x_eval,y_eval), contained in the inversion of our
% exterior region. The coordinates x_eval and y_eval can be either
% one or two dimensional arrays. To approximate the boundary integral we
% use the trapezoidal rule with multiplier*num_trap subdivisions of the
% parameterization interval. The variable num_trap is the number of
% subdivisions used in obtaining the Nystrom solution with the trapezoidal
% method. As points approach the boundary, a higher order numerical 
% integration is needed to preserve the accuracy associated with that of 
% the approximating double layer density function.
%
% INPUT:    
% x_eval,y_eval - The coordinates in the interior region obtained by the 
%           inversion of our exterior region. 
% t_nodes - These are the nodes at which the Nystrom approximation was
%           computed using the trapezoidal rule. The number of subdivisions
%           length(num_trap).
% density - This is the Nystrom solution for the double layer density.
% curve_obj - This structure contains the information about the boundary.
% index_bdyf - The index of boundary function when there is more than one 
%           choice. Use index_bdyf = 1 when there is only one such
%           function.
% multiplier - A positive integer used to determine the number of 
%           subdivisions of the parameterization interval for the 
%           trapezoidal approximation of the double layer potential. Use
%           num_quad = multiplier_spline*num_trap subdivisions. The
%           variable num_trap is the number of subdivisions used in 
%           obtaining the Nystrom solution with the trapezoidal method.  
%           
% OUTPUT:   
% potential - The approximation of the double layer potential for U on the
%           interior region that is the inversion of our original exterior
%           region.

curve_parms = curve_obj.curve_parms;
L = curve_parms.length;
[nr,nc] = size(x_eval);

% The trapezoidal rule will be used over the boundary when integrating the
% double layer potential integral. The variable num_nodes is the number of
% subdivisions to be used in the trapezoidal rule.
num_trap = length(t_nodes); h_trap = L/num_trap;
num_quad = num_trap*multiplier;
h_quad = L/num_quad;
t_quad = h_quad*(1:num_quad)';

% Using Nystrom interpolation, extend the (double layer) density to the new
% quadrature node points. Begin by calculating the needed curve values at
% the points in t_nodes and t_quad.
[~,point_kelvin_t] = generate_curve_Kelvin(t_nodes,curve_obj);
x_nodes = point_kelvin_t.xk; y_nodes = point_kelvin_t.yk; 
dx_nodes = point_kelvin_t.dxk; dy_nodes = point_kelvin_t.dyk; 
d2x_nodes = point_kelvin_t.d2xk; d2y_nodes = point_kelvin_t.d2yk; 

[point_orig_q,point_kelvin_q] = generate_curve_Kelvin(t_quad,curve_obj);
x_quad = point_kelvin_q.xk; y_quad = point_kelvin_q.yk; 
dx_quad = point_kelvin_q.dxk; dy_quad = point_kelvin_q.dyk; 

rhs = bdyfcn(t_quad,point_orig_q.x,point_orig_q.y,index_bdyf);
density_quad = zeros(num_quad,1);

% Do Nystrom interpolation to extend the Nystrom solution to the new
% quadrature node points in t_quad.
for ii=1:num_quad
    if multiplier*floor(ii/multiplier) == ii
        % Use original density value.
        density_quad(ii) = density(ii/multiplier);
    else
        % Do Nystrom interpolation.
        point_t = [x_quad(ii),y_quad(ii)];
        for j=1:num_trap
            point_s = [x_nodes(j),y_nodes(j),dx_nodes(j),dy_nodes(j),...
                d2x_nodes(j),d2y_nodes(j)];
            fker = kernel_Nystrom(point_t,point_s);
            density_quad(ii) = density_quad(ii) + fker*density(j);
        end
        density_quad(ii) = (h_trap*density_quad(ii) - rhs(ii))/pi;
    end
end
              
% Evaluate the potential function.
potential = zeros(nr,nc);
for ii=1:nr
    for j=1:nc
        sum = 0;
        for k=1:num_quad
            point = [x_quad(k),y_quad(k),dx_quad(k),dy_quad(k)];
            sum = sum + density_quad(k)*kernel_M(x_eval(ii,j),...
                y_eval(ii,j),point);
        end
        potential(ii,j) = h_quad*sum;
    end
end

end % evaluate_potential_Nystrom_Kelvin

%========================================================================
function value = kernel_M(x,y,point_s)

% Evaluate the double layer potential kernel function for a point (x,y)
% interior to the region of interest. For a formula, see  (7.2.57) on page
% 324 of my integral equation text.

% point_s = [x_s,y_s,dx_s,dy_s] with (x_s,y_s) the point on the boundary 
% corresponding to the integration parameterization variable s. The 
% vector (dx_s,dy_s) is the first derivative of the vector function 
% (x(s),y(s)), evaluated at the given parameterization point s.  It is 
% assumed that s, x_s, y_s, ... are each single numbers, not arrays.

x_s = point_s(1); y_s = point_s(2);
dx_s = point_s(3); dy_s = point_s(4);

denominator = (x_s-x)^2 + (y_s-y)^2;
numerator = -dy_s*(x_s-x) + dx_s*(y_s-y);
value = numerator/denominator;

end % kernel_M

