function point_orig = generate_curve(t,curve_obj)

% This is a user-specified function.
%
% Generate the points (x,y) on the boundary curve, corresponding to
% the parameterization variables in t.  We also generate the first 
% and second derivatives of the parameterization function.
%
% INPUT;
% t -   The parameterization points at which the curve is to be evaluated.
%       In particular, give the xy-coordinates along with the first and
%       second derivatives of the curve function.
% curve_obj - This structure contains the information about the boundary.
%
% OUTPUT: 
% point_orig - The xy-coordinates along with the first and second 
%       derivatives of the curve function. This is a structure.

curve = curve_obj.name;
curve_parms = curve_obj.curve_parms;
switch curve
    case 'ellipse'
        % This is the ellipse (x/a)^2 + (y/b)^2 = 1
        a = curve_parms.ellipse_a; b = curve_parms.ellipse_b;
        cs = cos(t); sn = sin(t);
        x = a*cs; y = b*sn;
        dx = -a*sn; dy = b*cs;
        d2x = -x; d2y = -y;
    case 'cardioid'
        % This defines the cardioid boundary
        %   (x,y) = r(a cos(theta),b sin(theta))
        %       r = c*cos(theta) + k
        % Choose k > c, and choose a,b > 0. 
        a = curve_parms.cardioid_a; b = curve_parms.cardioid_b;           
        c = curve_parms.cardioid_c; k = curve_parms.cardioid_k; % Cardioid parameters
        theta = t - pi;
        cs = cos(theta); sn = sin(theta);
        r = c*cs + k; dr = -c*sn; d2r = -c*cs;
        x = a*r.*cs; 
        x = x - a*c;
        dx = a*(dr.*cs - r.*sn); 
        d2x = a*(d2r.*cs - 2*dr.*sn - r.*cs); 
        y = b*r.*sn;
        dy = b*(dr.*sn + r.*cs);
        d2y = b*(d2r.*sn + 2*dr.*cs - r.*sn);
end

point_orig.t = t;
point_orig.x = x; point_orig.y = y; 
point_orig.dx = dx; point_orig.dy = dy; 
point_orig.d2x = d2x; point_orig.d2y = d2y; 

end % generate_curve