function cans = normal_deriv_bdyf_Kelvin(point_orig,index_f)

% This is a user-specified function. It is given in a peculiar, but
% convenient way to specify normal derivative boundary data.
%
% Evaluate the normal derivative boundary data.  This assumes the original
% boundary function is of the form 
%    U(x,y) = u(x/x^2+y^2,y/x^2+y^2)
% with u defined as a potential on the interior region that is the 
% inversion through the unit circle of the original exterior region. The 
% structure 'point_orig' contains the information on the original curve 
% before application of the inversion, the boundary to the exterior region. 
% For (x,y) on the boundary of the original exterior region, given in 
% point_orig, the point (xi,eta)=(x/x^2+y^2,y/x^2+y^2) is on the boundary 
% of the interior region obtained by applying the inversion to the exterior 
% region.

% INPUT:
% point_orig - point information from the original boundary. This is a
%           structure.
% index_f - The index of the boundary and solution data for the problem to
%           be solved.
%
% OUTPUT:
% cans -    The normal derivative of the Kelvin transformed harmonic 
%           function at the boundary of the inverted curve.

x = point_orig.x; y = point_orig.y; 
dx = point_orig.dx; dy = point_orig.dy; 
% normal = [dy,-dx]./sqrt(dx.^2+dy.^2);
normal = zeros(length(x),2);
denom = sqrt(dx.^2+dy.^2);
normal(:,1) = dy./denom; normal(:,2) = -dx./denom;

% Prepare for differentiation of U(x,y), using derivatives with respect to
% of u(xi,eta) and using derivatives of (xi,eta) with respect to (x,y).
xi = x./(x.^2+y.^2); eta = y./(x.^2+y.^2);
rsq = x.^2 + y.^2;
temp1 = y.^2 - x.^2;
dx_xi = temp1./rsq.^2; dy_eta = -dx_xi; dxy = -2*x.*y./rsq.^2;

%%%%%%%%%%%%% USER SPECIFIED MATERIAL %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
switch index_f
case 1
%   bdyfcn = exp(xi).*cos(eta) as a function of (x,y).
    dxi_u = exp(xi).*cos(eta);
    deta_u = -exp(xi).*sin(eta);   
case 2
%   bdyfcn = xi;
    dxi_u = ones(size(xi));
    deta_u = zeros(size(xi));
case 3
%   bdyfcn = xi.^2 - eta.^2;
    dxi_u = 2*xi;
    deta_u = -2*eta;
case 4
%   bdyfcn = 1;
    dxi_u = zeros(size(xi));
    deta_u = zeros(size(xi));
case 5
%   bdyfcn = exp(xi).*sin(eta);
    dxi_u = exp(xi).*sin(eta);
    deta_u = exp(xi).*cos(eta);
end
%%%%%%%%%%%%% END OF USER SPECIFIED MATERIAL %%%%%%%%%%%%%%%%%%%%%%%%%%%%

dx_bdyf = dxi_u.*dx_xi + deta_u.*dxy;
dy_bdyf = dxi_u.*dxy + deta_u.*dy_eta;
cans = dx_bdyf.*normal(:,1)+dy_bdyf.*normal(:,2);

end % normal_deriv_bdyf_Kelvin