function [t_nodes,approx_u] = Nystrom_ExtNmn(curve_obj,normal_deriv,...
    num_trap,Fourier_degree,index_bdyf)

% This program sets up the linear system for solving the integral equation
% of the second kind based on using a direct formula relating the Dirichlet
% and Neumann data on the boundary. See (7.2.66) on page 328 of my integral
% equations text. The numerical method is Nystrom's method with the 
% trapezoidal rule. The right side of (7.2.66) is evaluated numerically
% using (7.2.69)-(7.2.72) on page 328.
%
% This is intended for use with smooth boundaries.

% Input parameters:
% curve_obj -   This is an object identifying the type of boundary
%               curve on which Laplace's equation is being solved. It also
%               includes information regarding the definition of that
%               curve.
% Fourier_degree - The degree of the Fourier approximation of the given 
%               normal derivative, to be used in 'create_rhs_NMN'.
% num_trap -    The number of quadrature points for the definition of the
%               numerical integration approximation of the double layer 
%               operator.
% index_bdyf -  This is the index of the boundary function, given in the
%               external program 'normal_deriv_bdyf'.

% Output values:
% t_nodes -     These are the node points at which the density function
%               is approximated.
% density -     These are the estimated values of the unknown double layer
%               density function.

% The parameterization interval is [0,2*pi].
% Create the quadrature nodes and the subdivision of [0,2*pi].
h_trap = 2*pi/num_trap;
t_nodes = h_trap*(1:num_trap)';

[x_nodes,dx_nodes,d2x_nodes,y_nodes,dy_nodes,d2y_nodes] = ...
                            generate_curve(t_nodes,curve_obj);

% Calculate the array of kernel values to be used in evaluating the
% collocation integrals.
K_matrix = generate_K_Nystrom(num_trap,x_nodes,y_nodes,dx_nodes,...
    dy_nodes,d2x_nodes,d2y_nodes);

% Create the Nystrom system matrix.
KM = -pi*eye(num_trap) + h_trap*K_matrix;

% Create the right hand side of the linear system.
num_quad = max(100,3*Fourier_degree + 1);  % num_quad > 99, for use in 
                                           % 'create_rhs_NMN'
rhs = create_rhs_NMN(normal_deriv,t_nodes,x_nodes,y_nodes,index_bdyf,...
    Fourier_degree,num_quad,curve_obj);

if is_row(rhs)
    rhs = rhs';
end

% Solve the double-layer density function.
approx_u = KM\rhs;

end % Nystrom_ExtNmn
