function demo_Nystrom_ExtNmn(curve,num_trap,Fourier_degree,index_bdyf)

% Copyright 2013 by Kendall Atkinson
%
% This demonstrates the program 'Nystrom_ExtNmn' associated with
% solving the exterior Neumann problem over the exterior region D_e.
% An integral equation of the second kind is solved for the Dirichlet
% boundary data. The integral equation is based on using a direct 
% formulation relating the Dirichlet and Neumann data on the boundary.
% See (7.2.66) on page 328 of my integral equations text. 
%
% The boundary is to be smooth and the complementary interior region D_i is 
% to be simply-connected. Two sample regions, with boundary an ellipse and 
% a limacon, are given in the subprogram 'set_bdy_param', given  following 
% this main program. The full definition of each curve is given in the 
% routine 'generate_curve'. Also, the parameterization interval must be
% [0,2*pi] because of the use of a Fourier series approximation on this
% interval.
%
% For the test case boundary value functions and true solutions, see the
% programs 'bdyfcn' and 'normal_deriv_bdyf'. Let u denote the solution
% of the exterior Neumann problem over D_e. The given boundary data is
% contained in 'normal_deriv_bdyf' and the true solution is given in
% 'bdyfcn'.
%
% The numerical method is Nystrom's method, carried out in the program 
% 'Nystrom_ExtNmn'. The user gives the normal derivative, and the program
% approximates the solution u over the boundary. Of course, the solution
% is unique only up to the addition of a constant. At each point (x,y) on 
% the boundary, the double layer integral will be approximated using the 
% trapezoidal rule.
%
% This program will request information defining the curve.  
%
% As a demonstration, use one of the commands and sample data.
%         demo_Nystrom_ExtNmn('ellipse',40,15,1)    Use a=1, b=2
%         demo_Nystrom_ExtNmn('cardioid',40,15,1)   Use c=0.8, k=1.0, a=b=1
%
% The user must specify the name of the curve; see the function
% 'set_bdy_param' given below for examples defining a curve. You must
% also provide the number of subdivisions, called num_trap, and a quantity 
% called 'Fourier_degree' which is used in approximating the right side
% of (7.2.66). See the manual for an explanation of the latter. You must 
% also provide the index of the problem (index_bdyf) that is to be solved.  

% INPUT:
% curve -       The name of the boundary curve.
% Fourier_degree - The degree of the Fourier approximation of the given 
%               normal derivative, used in create_rhs_NMN to compute
%               the right side of the integral equation (7.2.66).
% num_trap -    The number of subdivisions used in applying the Nystrom
%               method with the trapezoidal rule to the solution of the
%               double layer potential integral equation.
% index_bdyf -  This is the index for the boundary function, given in the
%               external programs 'bdyfcn' and 'normal_deriv_bdyf'.

% Print the input parameters.
disp(' ')
disp('INPUT PARAMETERS:')
disp(['curve = ',curve])
disp(['index_bdyf = ',num2str(index_bdyf)])
disp(['num_trap = ',num2str(num_trap)])
disp(['Fourier_degree = ',num2str(Fourier_degree)])
disp(' ')

% Set up information about the boundary curve.
[curve_parms, ~, ~] = set_bdy_param(curve);
disp(' ')

% The structure 'curve_obj' is to contain the name of the curve and the
% structure 'curve_parms'.  The latter contains the data defining the
% curve, and this will vary with the curve being considered.
curve_obj.name = curve;
curve_obj.curve_parms = curve_parms;
num_plot_curve_points = 200;
draw_bdy(curve_obj,num_plot_curve_points)
figure(gcf)
pause

% Solve for the unknown solution u at the node points as determined by the
% parameter num_trap.
[t_nodes_Nystrom,approx] = Nystrom_ExtNmn(curve_obj,@normal_deriv_bdyf,...
    num_trap,Fourier_degree,index_bdyf);

% Print the solution at the node points.
%figure
%plot(t_nodes_Nystrom,approx)
%name = curve_obj.name;
%title(['Exterior Neumann Problem on ',name,...
%    ': The boundary solution using the Nystrom node points'])
%xlabel(['curve = ',curve_obj.name,'   Boundary function ',...
%    num2str(index_bdyf),'   Fourier degree = ',num2str(Fourier_degree)])
%print_curve_data(curve)
%pause

% Compare our approximate solution to the true solution over a grid of
% num_plot evenly spaced points in [0,2pi].
num_plot = 201; % The number of plot points for checking the error.
step_plot = 2*pi/(num_plot-1);
z = step_plot*(0:num_plot-1)';
[x,~,~,y,~,~] = generate_curve(z,curve_obj);
true_u = bdyfcn(z,x,y,index_bdyf);

% Generate the approximate solution values at the nodes in z. This will be
% done with Nystrom interpolation. Denote this new set of values by
% approx_u. 

% Produce data for evaluating double-layer integral term at points in z.
num_quad = max(100,3*Fourier_degree + 1);

rhs_at_z = create_rhs_NMN(@normal_deriv_bdyf,z,x,y,index_bdyf,...
                               Fourier_degree,num_quad,curve_obj);
Lt = length(t_nodes_Nystrom); h = 2*pi/Lt;
[x_s,dx_s,d2x_s,y_s,dy_s,d2y_s] ...
                             = generate_curve(t_nodes_Nystrom,curve_obj);
interp = zeros(num_plot,1);
for i=1:num_plot
    point_t = [x(i) y(i)];
    for j=1:Lt
        point_s = [x_s(j),y_s(j),dx_s(j),dy_s(j),d2x_s(j),d2y_s(j)];
        kernel = kernel_Nystrom(point_t,point_s);
        interp(i) = interp(i) + kernel*approx(j);
    end
end
interp = h*interp;
approx_u = (interp - rhs_at_z)/pi;

% Normalize the approximate solution values so that they and the true 
% values will agree at the node point z(midpt).
midpt = floor((num_plot-1)/2)+1;
approx_u = approx_u - approx_u(midpt) + true_u(midpt);

% Print the true solution and approximate solution.
figure
plot(z,true_u,z,approx_u,'r-.')
legend('true u','approx u')
title(['Approx solution on boundary: Nystrom method',...
    '  num subdiv = ',num2str(num_trap)])
xlabel(['curve = ',curve_obj.name,'   Boundary function ',...
    num2str(index_bdyf),'   Fourier degree = ',num2str(Fourier_degree)])
pause

% Print the error.
error_u = true_u - approx_u;
disp(' '); 
disp(['max error in solution = ',num2str(norm(error_u,inf))])
figure
plot(z,error_u)
title(['Error in solution: num subdiv = ',num2str(num_trap)])
xlabel(['curve = ',curve_obj.name,'   Boundary function ',...
    num2str(index_bdyf),'   Fourier degree = ',num2str(Fourier_degree)])

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function print_curve_data(curve)
% The following print contains curve dependent parameters.
switch curve
    case 'ellipse'
        a = curve_parms.ellipse_a; b = curve_parms.ellipse_b;     % Ellipse parameters        
        xlabel(['a = ',num2str(a),'   b = ',num2str(b),'   num:trap = ',...
            num2str(num_trap)])
    case 'cardioid'
        a = curve_parms.cardioid_a; b = curve_parms.cardioid_b;           
        c = curve_parms.cardioid_c; k = curve_parms.cardioid_k; % Cardioid parameters
        xlabel(['c = ',num2str(c),'   k = ',num2str(k),...
            '   a = ',num2str(a),'   b = ',num2str(b),'   num:trap = ',...
            num2str(num_trap)])
end
end % print_curve_data

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

end % demo_Nystrom_ExtNmn

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function [curve_parms, grading_param, spacing] = set_bdy_param(curve)
    
switch curve
    case 'ellipse'
        % Define the object containing the needed curve parameters for an ellipse.
        curve_parms.length = 2*pi;    % The length of the parameterization interval.
        disp('Give curve parameters for the ellipse.')
        disp('      (x/a)^2 + (y/b)^2 = 1')
        a = input('a = '); b = input('b = ');
        curve_parms.ellipse_a = a; curve_parms.ellipse_b = b; 
    case 'cardioid'
        % Define the object containing the needed curve parameters for a cardioid.
        % Initially try c=.8, k=1, a=b=1.
        curve_parms.length = 2*pi;    % The length of the parameterization interval.
        disp('Give the parameters for the cardioid')
        disp('(x,y) = (c*cos(t)+k)*(a*cos(t),b*sin(t)),   k > c')
        c = input('c = '); k = input('k = '); 
        a = input('a = '); b = input('b = ');
        curve_parms.cardioid_a = a; curve_parms.cardioid_b = b; 
        curve_parms.cardioid_c = c; curve_parms.cardioid_k = k; 
end

switch curve
    case 'ellipse'
        curve_parms.int_pt = [0 0];
    case 'cardioid'
        curve_parms.int_pt = [a*c,0];
end

% Allow input of grading parameter for the case of curve='teardrop'.
switch curve
    case 'ellipse'
        grading_param = 1;
        spacing = 'uniform';
    case {'cardioid'}
        grading_param = 1;
        spacing = 'uniform';
end

end % set_bdy_param
