function kernel_value = kernel_B(point_t,point_s)

% Evaluate the kernel function B(t,s) using the formula in (7.2.71) on 
% page 328 of my integral equations text. The parameterization interval
% for the first kind integral equation is assumed to be [0,2*pi].

% Input:
% point_t = [t,x_t,y_t], the point on the boundary corresponding to the 
% parameterization variable t.  It is assumed that x_t, and y_t are each 
% single numbers, not arrays.
%
% point_s = [s,x_s,y_s,dx_s,dy_s] with (x_s,y_s) the point on
% the boundary corresponding to the parameterization variable s. The
% vector (dx_s,dy_s) is the first derivative of the vector function 
% (x(s),y(s)), evaluated at the given parameterization point s.  It is 
% assumed that x_s, y_s, ... are each single numbers, not arrays.

t = point_t(1); x_t = point_t(2); y_t = point_t(3); 

s = point_s(1); x_s = point_s(2); y_s = point_s(3);
dx_s = point_s(4); dy_s = point_s(5);

% Two points are considered as identical if the distance between them
% is bounded by 1.0E-10.  This should be improved, possibly by making
% it relative to the size of the curve from which the points are being 
% taken.

distance = sqrt((x_t - x_s)^2 + (y_t - y_s)^2);

% Calculate the kernel function.
if distance > 1.0e-10
    numerator = sqrt(exp(1))*distance;
    denominator = 2*abs(sin((t-s)/2));
    kernel_value = log(numerator/denominator);
else
    argument = sqrt(exp(1))*sqrt(dx_s^2 + dy_s^2);
    kernel_value = log(argument);
end

end % kernel_B