function kernel_value = kernel_Nystrom(point_t,point_s)

% Evaluate the double layer kernel function K(t,s), using the formulas
% (7.1.32), (7.1.33) on page 316 of my integral equations text.

% INPUT
% point_t = [x_t,y_t], the point on the boundary corresponding to the 
%       parameterization variable t.  It is assumed that x_t, and y_t are
%       each single numbers, not arrays.
%
% point_s = [x_s,y_s,dx_s,dy_s,d2x_s,d2y_s] with (x_s,y_s) the point on
%       the boundary corresponding to the parameterization variable s. The
%       vectors (dx_s,dy_s) and (d2x_s,d2y_s) are the first and second
%       derivatives of the vector function (x(s),y(s)), evaluated at the given
%       given parameterization point s.  It is assumed that x_s, y_s, ... 
%       are each single numbers, not arrays.

x_t = point_t(1); y_t = point_t(2); 

x_s = point_s(1); y_s = point_s(2);
dx_s = point_s(3); dy_s = point_s(4);
d2x_s = point_s(5); d2y_s = point_s(6);

% Two points are considered as identical if the distance between them
% is bounded by 1.0E-10.  This should be improved, possibly by making
% it relative to the size of the curve from which the points are being 
% taken.

distance = sqrt((x_t - x_s)^2 + (y_t - y_s)^2);

% Calculate the kernel function.
if distance > 1.0e-10
    numerator = dy_s*(x_t - x_s) - dx_s*(y_t - y_s);
    denominator = distance^2;
    kernel_value = numerator/denominator;
else
    numerator = dy_s*d2x_s - dx_s*d2y_s;
    denominator = 2*(dx_s^2 + dy_s^2);
    kernel_value = numerator/denominator;
end

end % kernel_Nystrom