function demo_bie_polygon(degree,num_subdiv_in,coll_quad_order,...
    grading_param,index_bdyfcn,index_bdy)

% Copyright 2013 by Kendall Atkinson
%
% This demonstrates various programs in the package, all associated with
% solving the interior Dirichlet problem as a double layer potential. This
% is for only the case of polygonal boundary curves. It is based on the
% programs for a smooth boundary curve, with modifications as needed, and 
% thus there are places where the coding may seem a bit convoluted. In
% running the program, note there is a pause after the drawing of each
% graph.  Simply push any key to continue.  Some of the computations are
% longer than others, so be aware that you may need to wait for them to be
% completed.
% 
% The numerical method is piecewise polynomial collocation, carried out
% in the program 'pw_poly_collocation'.  We also evaluate the approximating
% potential solution and its error, doing so in the programs 
% 'test_evaluate_potential' and 'test_evaluate_potential2'. Both programs
% call on the routine 'evaluate_potential_polygon'. The first evaluates the 
% potential along a line toward the boundary from a point with respect to 
% which the domain is starlike. The second evaluates over the entire 
% region. These two programs are the only ones that require that the region 
% be starlike with respect to a given point. See the routine 
% 'create_polygon' for the definition of this central starlike point.
%
% Finally, we evaluate the function that is conjugate to our double layer
% potential, doing so over the boundary. We use it to evaluate the normal
% derivative of the solution of the original problem over the boundary. 
% This is done in the routines 'test_conjugate_function' and 
% 'test_normal_deriv_method'.
%
% As a demonstration, use one of the following commands.
%       demo_bie_polygon(2,32,10,2,1,1)
%       demo_bie_polygon(2,48,10,2,1,2)
% When requested, we suggest using pot_quad_order=20. This can be varied, 
% and we suggest doing so as an experiment.  The value of pot_quad_order 
% will probably not be optimal and the user should experiment with its
% size.
%
% The program will request information defining the curve by using 
% 'create_polygon'. To evaluate the double layer potential at each point 
% (x,y), the double layer integral will be approximated over each of the 
% num_subdiv subdivisions used in obtaining the collocation solution of the 
% second kind boundary integral equation. The integration over each 
% subdivision will use Gauss-Legendre quadrature with pot_quad_order nodes 
% per collocation subinterval of the parameterization interval for the 
% boundary.
%
% See the program 'create_polygon' for examples of defining the polygonal
% boundary. You must also provide the degree of the piecewise polynomial
% approximation, the number of subdivisions, and the order of the 
% Gauss-Legendre quadrature to be used to evaluate various integrals in the
% collocation method. You must also provide the index of the problem 
% (index_bdyfcn) that is to be solved. Other parameters given below can be 
% changed.  
%
% In the program, the structure curve_obj is to contain the name of the 
% curve and the structure curve_parms.  The latter contains the data 
% defining the curve, and this will vary with the curve being considered.
% The parameter 'spacing' will always equal 'graded' for polygonal
% boundaries.
%
% INPUT:
% degree -      The degree of the piecewise polynomial function.
% num_subdiv_in - The number of subdivisions for the piecewise polynomial
%               approximation. This may be adjusted internally based on the
%               number of sides to the polygonal boundary and the lengths
%               of those sides.  The re-adjustment will be noted on the
%               output graph.
% coll_quad_order -  The collocation integrals must be evaluated 
%               numerically, and we use Gauss-Legendre quadrature over
%               each subdivision. The number of quadrature points per
%               subdivision is coll_num_quad.
% grading_param - 'grading_param' is used in creating a graded mesh about 
%               each corner on the bounary.  If you want a uniform mesh, 
%               simply set grading_param=1; and if you want the program to
%               determine the grading automatically, let grading_param=inf.
%               See the program 'generate_nodes_polygon' for a detailed
%               look at how grading of the collocation subintervals is
%               actually determined.
% index_bdyfcn -  This is the index for the boundary function, given in the
%               external program 'bdyfcn'.
% index_bdy -   This is the index of the polygonal boundary curve.  See the
%               program 'create_polygon' for the choices.

disp(' ')
disp('INPUT PARAMETERS:')
disp(['degree = ',num2str(degree)])
disp(['num_subdiv_in = ',num2str(num_subdiv_in)])
disp(['coll_quad_order = ',num2str(coll_quad_order)])
disp(['grading_param = ',num2str(grading_param)])
disp(['index_bdyfcn = ',num2str(index_bdyfcn)])
disp(['index_bdy = ',num2str(index_bdy)])
disp('  ')

disp('PROGRAM PARAMETERS SET WITHIN demo_bie_polygon:')
cf_quad_order = coll_quad_order; % Quadrature order for calculating conjugate 
                                 % function.
disp(['cf_quad_order = ',num2str(cf_quad_order)])
disp('For polygonal curves, we always use the following.')
spacing = 'graded';     % Always use this for polygonal curves.
type = 'gauss';         % Always use this for polygonal curves.
disp(['node_type = ',num2str(type)])
disp(['spacing = ',num2str(spacing)])
disp(' ')


% Define the object containing the needed curve parameters for a polygon.
[vertices,int_pt] = create_polygon(index_bdy);
curve_obj = create_polygon_bdy(vertices,int_pt);
poly_curve = curve_obj.curve_parms;
% L = poly_curve.Total_length;

num_plot_points = 1000;  % A large number is used in order to avoid the 
                         % need to distinguish the corners.
draw_bdy_polygon(curve_obj,num_plot_points)
pause

% Find the collocation approximation for the double layer density function.
[t_subdiv,t_nodes,density,num_subdiv] = pw_poly_collocation_polygon(...
   curve_obj,num_subdiv_in,degree,coll_quad_order,grading_param,...
   index_bdyfcn);

% Create an object for the output of 'pw_poly_collocation'.  This is to
% avoid repeatedly calculating this in each of the test programs called by
% this demo program.  If any of the demo programs is to be used in a stand
% alone way, then it needs to be changed appropriately, to actually carry
% out the computations in 'pw_poly_collocation'.
test.t_subdiv = t_subdiv;
test.t_nodes = t_nodes;
test.density = density;
test.num_subdiv = num_subdiv;

figure
disp('This is the graph of the double layer density function.')
plot(t_nodes,density)
title(['Interior Dirichlet Problem on polygon',...
    ': The Double Layer Density Function'])
xlabel(['quad coll = ',num2str(coll_quad_order),',  num subdiv = ',...
    num2str(num_subdiv),',   degree = ',num2str(degree),',   bdyfcn ',...
    num2str(index_bdyfcn),',   grading param = ',num2str(grading_param)])
pause

test_evaluate_potential_polygon2(curve_obj,degree,...
    index_bdyfcn,int_pt,test)
pause

test_evaluate_potential_polygon(curve_obj,num_subdiv,degree,...
    coll_quad_order,index_bdyfcn,int_pt,test)
pause

% The following is set for this demo program.
cf_quad_order = coll_quad_order;     % Quadrature order for calculating
                                     % conjugate function.
Lngth = poly_curve.length;
numv = length(Lngth);
breakpoints = poly_curve.breakpoints(1:2:2*numv+1);
z_eval = zeros(20*numv+1,1);
delta = Lngth/20;

for k=1:numv
    h = delta(k);
    t = breakpoints(k):h:breakpoints(k+1);
    id = 20*(k-1)+2:20*k+1;
    z_eval(id) = t(2:21);
end
    
% Produce the conjugate function to the double layer potential. This can be
% deleted without affecting the call on 'test_normal_deriv_method_polygon'.
disp(' ');
disp('Produce the conjugate function and the normal derivative to the')
disp('given solution function over the boundary.  The function is plotted')
disp('on [0,L], the parameterization interval. The normal derivative')
disp('is discontinuous at the corner points of the boundary. We begin') 
disp('by using numerical integration to calculate the function that is')
disp('conjugate over [0,L] to our potential function.')
test_conjugate_function_polygon(curve_obj,degree,cf_quad_order,...
    z_eval,index_bdyfcn,test)
pause

disp(' ');
test_normal_deriv_method_polygon(curve_obj,degree,cf_quad_order,...
   index_bdyfcn,test)    

end % demo_bie_polygon

