function [potential,z,w] = evaluate_potential_polygon(x_eval,y_eval,...
   t_nodes,density,curve_obj,num_subdiv,t_subdiv,degree,num_pquad)   

% Evaluate the double-layer potential u with the given "density" function
% at the nodes given in (x_eval,y_eval).  It is assumed that x_eval and
% y_eval are matrices.  We integrate over each subinterval of the piecewise 
% polynomial function using Gaussian quadrature with "num_pquad" points 
% on that subinterval.  

% Initialization.
% spacing = 'graded';
type = 'gauss';

% The parameterization interval is [0,L].
% poly_curve = curve_obj.curve_parms;
% L = poly_curve.Total_length;

[nr,nc] = size(x_eval);

% Obtain the quadrature nodes and weights on the interval [0,1].
[zq,wq] = gauss_nodes_wts(num_pquad,0,1);

% Generate the nodes and weights over the entire interval [0,L]. 
N = num_subdiv*num_pquad;
z = zeros(1,N); w = z;
for i=1:num_subdiv
    h = t_subdiv(i+1)-t_subdiv(i);
    w((i-1)*num_pquad+1:i*num_pquad) = h*wq;
    z((i-1)*num_pquad+1:i*num_pquad) = t_subdiv(i)+h*zq;
end

% Evaluate the density function at each of the eventual quadrature node
% points. Also generate the corresponding points on the boundary
% corresponding to the quadrature node points.
value = zeros(1,N);
point = zeros(N,4);
for i=1:N
    [x,dx,~,y,dy,~] = generate_curve_polygon(z(i),curve_obj);
    point(i,1:4) = [x,y,dx,dy];
    value(i) = interp_density(z(i),t_subdiv,t_nodes,density,type,degree);
end

% Combine the quadrature weights and density function.
value = w.*value;

% Evaluate the potential function.
potential = zeros(nr,nc);
for i=1:nr
    for j=1:nc
        sum = 0;
        for k=1:N
            sum = sum + value(k)*kernel_M(x_eval(i,j),y_eval(i,j),point(k,:));
        end
        potential(i,j) = sum;
    end
end

end % evaluate_potential_polygon

%========================================================================
function value = kernel_M(x,y,point_s)

% Evaluate the double layer potential kernel function for a point (x,y)
% interior to the region of interest. 

% point_s = [x_s,y_s,dx_s,dy_s] with (x_s,y_s) the point on the boundary 
% corresponding to the integration parameterization variable s. The 
% vector (dx_s,dy_s) is the first derivative of the vector function 
% (x(s),y(s)), evaluated at the given parameterization point s.  It is 
% assumed that s, x_s, y_s, ... are each single numbers, not arrays.

x_s = point_s(1); y_s = point_s(2);
dx_s = point_s(3); dy_s = point_s(4);

denominator = (x_s-x)^2 + (y_s-y)^2;
numerator = -dy_s*(x_s-x) + dx_s*(y_s-y);
value = numerator/denominator;

end % kernel_M