function [t_subdiv,t_nodes,num_nodes,subdiv_out] = ...
          generate_nodes_polygon(subdiv_in,degree,curve_obj,grading_param)      

% Create the nodes for the collocation scheme.  We are using piecewise
% polynomial collocation on [0,L].  There are to be subdiv_in subdivisions
% of [0,L]; and on each subinterval, we will use polynomial interpolation
% of the given degree. This is a variant of 'generate_nodes', designed
% specifically for polygonal boundaries.  The number of subdivisions is
% possibly different from 'subdiv_in', although close to it.  It is given  
% as the output variable 'subdiv_out'.

% The spacing used in defining the subdivision of [0,L] is a 'graded' 
% subdivision scheme.  The collocation points will be of type 'gauss', 
% to avoid having a corner point be a collocation node point. For the
% grading, the program determines a grading exponent q_j about each corner 
% point point_j; and then we use the minimum of q_j and 'grading_param' in 
% creating a graded mesh about the corner point_j.  If you want a uniform
% mesh, simply set grading_param=1; and if you want the program to
% determine the grading automatically, let grading_param=inf.

    poly_curve = curve_obj.curve_parms;
    subdiv = subdiv_in;
    
    % Create the subdivision. The boundary curve is polygonal.
    Lngth = poly_curve.length;
    angle = poly_curve.angle;
    numv = length(poly_curve.dx);
    temp = 1 - angle/pi;
    beta = 1./(1+temp);
    grading_exp = (degree+1)./beta;
    grading_exp(numv+1) = grading_exp(1);
    k = max(1,floor(subdiv/(2*numv)));
    fracs = (0:k)/k;
    t_subdiv = zeros(2*k*numv+1,1);
    for i=1:numv
        base = (i-1)*2*k;
        q = min(grading_exp(i),grading_param);
        pts = (fracs.^q)';
        t_subdiv(base+2:base+k+1) = pts(2:k+1)*Lngth(i)/2 + t_subdiv(base+1);
        base = base + k;
        q = min(grading_exp(i+1),grading_param);
        pts = fracs.^q;
        t_subdiv(base+2:base+k+1) = (1-pts(k:-1:1))*Lngth(i)/2 + ...
            t_subdiv(base+1);
    end
    subdiv = 2*k*numv;
    subdiv_out = subdiv;

    % Create the interpolation nodes.
    % Use with degree >= 0.
    [model,~] = gauss_nodes_wts(degree+1,0,1);
    if is_row(model) 
        model = model';
    end
    t_nodes = zeros(subdiv*(degree+1),1);
    for i=1:subdiv
        step = t_subdiv(i+1) - t_subdiv(i);
        t_nodes((i-1)*(degree+1)+(1:degree+1)) = t_subdiv(i) + step*model;
    end

    num_nodes = length(t_nodes);
    
end %generate_nodes_polygon

% --------------------------------------------------------------------

function [nodes,wts] = gauss_nodes_wts(n,a,b)

% Gauss-Legendre nodes and weights
%
% a,b   -  integration limits
% n     -  order of formula 
% nodes,wts -  Gauss base points and weight factors on [a,b]

u = (1:n-1)./sqrt((2*(1:n-1)).^2-1);
[vc,bp] = eig(diag(u,-1)+diag(u,1));
[bp,k] = sort(diag(bp));
wts = (b-a)*vc(1,k)'.^2; 
nodes = (a+b)/2+((b-a)/2)*bp;

end %gauss_nodes_wts