function info_bie_polygon
%
% Following is a list of programs in the package for solving the Dirichlet
% problem over a bounded simply-connected region in the plane.  It is
% assumed that the region has a polygonal boundary. 
% 
% For notation in the following, we use u=u(x,y) to denote the unknown
% potential solution being sought, and we also use it to reference the 
% approximating solution. We use v=v(x,y) to denote a conjugate function
% to u, with all such conjugate functions differing by a constant.
%
%
% TEST PROGRAMS:
%
% demo_bie_polygon - This is a demonstration program incorporating calls on
%           all of the remaining test programs and the collocation program
%           'pw_poly_collocation'.
% test_evaluate_potential_polygon - This tests the evaluation of the double
%           layer potential function u along a line specified by the user.
%           It is compared to the known true potential function.
% test_evaluate_potential_polygon2 - This tests the evaluation of the
%           double layer potential function u over the entire region.  It
%           is compared to the known true potential function.
% test_conjugate_function_polygon - This tests the calculation of the
%           conjugate function v using numerical quadrature of an
%           appropriate integral formula for v.
% test_normal_deriv_method_polygon - This produces another approximation to
%           the conjugate function v, based on a cubic spline interpolant
%           to data values obtained by another numerical integration. This
%           is compared to the true conjugate function.  In addition, the 
%           derivative of the spline function is used in obtaining the 
%           normal derivative of u over the boundary. Errors are calculated
%           and graphed with both the conjugate  function and the normal 
%           derivative.
%
%
% REMAINING PROGRAMS:
%
% conjugate_function_polygon - This calculates the conjugate function using
%           the formula given on page 32 of the PhD thesis of Clayton
%           Miller, University of Iowa, 1979. A composite numerical 
%           integration rule is used with a 5-point Gaussian quadrature
%           formula used per subdivision.  The number of subdivisions is
%           'num_subdiv'. 
% conjugate_kernel - This calculates the conjugate kernel function needed
%           to define the conjugate function.
% create_coll_matrix - This creates the collocation matrix.
% create_polygon_bdy - Use the vertices supplied in create_polygon to
%           create a structure containing more detail on the boundary.
% create_spline_conjugate_fcn_polygon - Creates the cubic spline
%           interpolant to the conjugate function.
% draw_bdy_polygon - Draw the boundary of the region.
% draw_bdy_polygon_with_line - Draw the boundary of the region together
%           with the line along
% eval_spline_conjugate_fcn_polygon - Evaluate the cubic spline interpolant
%           created using 'create_spline_conjugate_fcn'.
% evaluate_potential_polygon - Evaluate the double layer potential at given
%           node points.  A composite numerical integration rule is used
%           that is based on Gaussian quadrature with 'num_quad' nodes per
%           subinterval (num_quad specified by the user). The number of
%           subdivisions is that of the collocation solution for the double
%           layer density function.
% find_interval - A utility routine. Given a point t in [0,L] and a 
%           subdivision of [0,L], find the subinterval containing t.
% gauss_nodes_wts - Calculate needed Gaussian quadrature nodes and weights.
% generate_curve_polygon - Given an arc length parameterization variable t,
%           calculate (x(t),y(t)) and (x'(t),y'(t)).
% generate_K - Create a set of values of the double layer kernel function.
% generate_nodes_polygon - Generate collocation subintervals and node points.
% generate_quad_pts - Generate quadrature node points for a composite rule
%           using Gaussian quadrature on each subdivision.
% interp_density - Interpolate the piecewise polynomial function defining
%           the approximate double layer density function.
% is_row - A utility function. Used to tell if a vector is a row or column
%           vector.
% kernel - Evaluate the double layer density function.
% model_quad - Evaluate the Lagrange basis functions over [0,1] relative to
%           the type of collocation nodes being used, namely 'equal' or
%           'gauss'.
% normal_deriv_method_polygon - Calculate the cubic spline that
%           interpolates the approximate conjugate function. Then calculate
%           its value and its derivative values at a given set of input
%           values for the parameterization variable.
% pw_poly_collocation - The main program for finding the piecewise
%           polynomial function that approximates the double layer density
%           function.
%
%
% FUNCTIONS TO BE SUPPLIED BY THE USER:
%
% bdyfcn - The true potential solution, from which the Dirichlet boundary
%           data is generated.
% create_polygon - Define the polygonal boundary by specifying the
%           vertices. Also, give a point 'int_pt' with respect to which the
%           boundary is star-like.
% normal_deriv_bdyf - Defines the true normal derivative of the potential
%           function being calculated.
% true_conjugate_fcn - Defines the true conjugate function of the potential
%           function being calculated.
%
%
% STANDARD VARIABLE NAMES:
%
% angle:        This is the vector of angles (possibly exterior) at the  
%               vertices of the boundary, defined as the interior or  
%               exterior angle in the interval [0,pi].
% basis_fcns:   These are values of the Lagrange interpolation basis
%               functions for some sub-interval.
% breakpoints:  These are the parameter values for the vertices of the
%               polygonal boundary and the midpoints of the edges.
% cf_values:    Conjugate function values, obtained from the routine
%               "conjugate_function_polygon", based on spline interpolation.  
%               These are the values at given input parameter values 'z_eval'.
% cf_quad_order: The order of the Gaussian quadrature to be used in
%               calculating the integrals over each subinterval for the
%               conjugate function.
% coeffs:       The spline coefficients for the spline function 
%               approximating the conjugate function for the double layer
%               potential.
% coll_quad_order: The order of the Gaussian quadrature to be used in
%               calculating the collocation integrals over each
%               subinterval.
% curve:        This is a string variable, identifying the boundary curve
%               being used.
% curve_obj:    This structure contains two objects, curve_obj.name and
%               curve_obj.curve_parms. For the polygonal boundary case,
%               curve_obj.name = 'polygon'. For all cases, 
%               curve_obj.curve_parms always contains information needed in
%               defing the boundary curve.  This varies between curves.
%               For polygonal boundaries, see the routine
%               create_polygon_bdy.  
% degree:       The degree of the piecewise polynomial approximation.
% delta:        The subinterval lengths for the various edges of the
%               polgonal boundary.  This is used in various places in
%               various ways.
% density:      This is the double layer density function, and it is
%               calculated using "pw_poly_collocation".
% deriv_cf_values:  These are the first derivatives of the spline function
%               approximating the conjugate function, corrected for a lack
%               of arc-length parameterization, to obtain the normal
%               derivative of the double layer potential.
% grading_param:  The grading exponent used in creating a graded mesh in the
%               case spacing='graded'.  Choose "grading_param" greater than
%               or equal to 1. A value of 1 will result in a uniform mesh.
%               See the routine 'generate_nodes_polygon' for more
%               information on the generating of graded meshes.  A value of
%               grading_param=inf will result in grading dependent on the
%               local angle at each vertex.
% index_bdyf:   This is the index of the function for the Dirichlet
%               boundary data function.
% int_pt:       This is input to the program 'create_polygon_bdy' to 
%               produce the information needed in defining the boundary.
%               It is a point with respect to which the boundary is 
%               starlike. Also input are the vertices defining the boundary.
% K_matrix:     This matrix contains the kernel values to be used in
%               evaluating the matrix collocation integrals.
% KM:           Collocation matrix, using integrals calculated numerically.
% L:            The length of the parameterization interval for the
%               polygonal boundary.
% Lngth:        A vector containing the lengths of the edges of the
%               polygonal boundary.
% numv:         This is the number of vertices in the polgonal boundary,
%               and it also is the number of edges to the boundary.
% n_spline:     The number of equally-spaced subdivisions of each edge of 
%               the polygonal boundary used in specifying t_spline.
% num_subdiv:   The number of subdivisions to be used in defining our
%               piecewise polynomial approximation. This is computed inside
%               the routine 'create_polygon_bdy' and it may be smaller than
%               num_subdiv_in.
% num_subdiv_in: This is the input to the routine 'demo_bie_polygon' as an
%               initial request for the number of subdivisions to be used
%               in creating the collocation subintervals.  In the program 
%               'create_polygon_bdy' it is adjusted to be an even multiple
%               of numv, the number of edges of the boundary.
% pot_quad_order: This is the order of the Gauss-Legendre quadrature to be
%               used on each sub-interval of the boundary when calculating
%               the double layer potential integral.
% poly_curve:   This is the actual name given to the structure in 
%               curve_obj.curve_parms.  For non-polygonal boundaries, this
%               will usually have another name.
% pp_polygon:   This array structure is used to store the pp structures
%               created in 'create_spline_conjugate_fcn_polygon' for each 
%               edge of the polygon.  This array structure is used
%               subsequently in 'eval_spline_conjugate_fcn_polygon' to
%               evaluate the conjugate function and its derivative, the
%               normal derivative of the original double layer potential.
% pts_per_side: The number of points to be used in checking the accuracy of
%               the spline-based conjugate function computation, along with
%               the normal derivative computation. Presently it is set at
%               20 points per edge of the polygonal boundary.
% quad_cf_values: Conjugate function values, used in the routine
%               "conjugate_function", based on quadrature and used to 
%               produce an interpolating spline function.  The node values 
%               are those for uniform spline interpolation over each edge
%               with n_spline subdivisions per edge. The values are
%               obtained by quadrature in "conjugate_function_polygon".
% spline_cf_values: Conjugate function values, obtained from the routine
%               "conjugate_function_polygon", based on spline interpolation.
%               These are the values at given input parameter values 'z_eval'.
% spacing:      This is a string variable defining the type of spacing used
%               in defining the subdivision. The two acceptable values are
%               'uniform' and 'graded'.
% t_nodes:      These are the collocation points.  The length of "t_nodes"
%               is denoted by "num_nodes", and it varies with the choice 
%               of "type", "degree", and "num_subdiv".
% t_spline:     The spline function subdivision breakpoints for the spline
%               function approximating the conjugate function for the 
%               double layer potential.  These points are evenly spaced.
%               used on each subinterval of the boundary when approximating
%               the double layer potential.
% t_subdiv:     These are the breakpoints for the piecewise polynomial
%               function, and the length of "t_subdiv" is "num_subdiv".
% type:         This is a string variable.  At present it takes the values
%               'equal' and 'gauss'. With 'equal', there are degree+1
%               interpolation nodes that are evenly space in each 
%               subinterval [t(i),t(i+1)], including the endpoints. With 
%               'gauss' we use as interpolation nodes the Gauss-Legendre
%               nodes of order=degree+1.
% unit_vec:     This is a vector containing unit tangent vectors in the
%               direction of increasing arc-length, given at each vertex.
% vertices:     This is an array of dimension numv X 2, with row k
%               containing vertex #k for the boundary.  This is input to
%               the program 'create_polygon_bdy' to produce the information
%               needed in defining the parameterization of the polygonal
%               boundary.  Also input is a point "int_pt" in side the
%               region and with respect to which the boundary is starlike.
% x,y,dx,dy,d2x,d2y: (x,y) is a point on the boundary corresponding to a
%               given parameter value t.  (dx,dy) and (d2x,d2y) are the
%               first and second derivatives with respect to t.  These are
%               to be calculated in the routine 'generate_curve_polygon',
%               which in turn uses curve_obj.
% z_eval:       A temporary storage vector for parameterization values at
%               which various quantities (e.g. the conjugate function) are
%               to be evaluated.
% zq,wq:        Gauss-Legendre nodes and weights on [0,1].
