function [spline_cf_values,deriv_cf_values] = ...
    normal_deriv_method_polygon(z_eval,curve_obj,num_subdiv,degree,...
    t_nodes,density,t_subdiv,cf_quad_order,n_spline)

% Create the spline interpolant that approximates the normal derivative 
% function on the boundary of the curve for the double layer potential 
% being found above.

% Initialization.
%spacing = 'graded';
%type = 'gauss';

% The parameterization interval is [0,L].
%poly_curve = curve_obj.curve_parms;
%L = poly_curve.Total_length;

n_spline = max(2,n_spline);
pp_polygon = create_spline_conjugate_fcn_polygon(n_spline,...
   t_nodes,density,curve_obj,num_subdiv,t_subdiv,degree,cf_quad_order);

% Calculate the conjugate function and its derivative at the given
% parameter values in z_eval.  The latter should have been so chosen as to 
% avoid the vertices of the polygonal boundary.
[spline_cf_values, deriv_cf_values] = eval_spline_conjugate_fcn_polygon(...
    pp_polygon,z_eval,curve_obj);

end % normal_deriv_method_polygon

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function pp_polygon = create_spline_conjugate_fcn_polygon(n_spline,...
   t_nodes,density,curve_obj,num_subdiv,t_subdiv,degree,num_bdyquad)

% Create a spline fit to the conjugate function as produced by the routine
% named 'conjugate_function'.  The interpolating spline function will be  
% based on dividing each edge of the polygonal boundary into n_spline 
% subintervals of equal length, with the subinterval length of edge #k 
% being equal to delta(k) = Lngth(k)/n_spline. The value of n_spline must 
% be greater than 1.

% On the parameterization interval 
%                [breakpoints(2k-1),breakpoints(2k+1)], 
% we use not-a-knot boundary conditions, and therefore we also use as
% interpolation points the parameter points 
%    breakpoints(2k-1)+delta(k)/2 and breakpoints(2k+1)-delta(k)/2
% to improve the accuracy of the interpolant around the endpoints of the
% parameterization interval.

% Initialization.
%spacing = 'graded';
%type = 'gauss';

poly_curve = curve_obj.curve_parms;
%L = poly_curve.Total_length;    % The parameterization interval is [0,L].
Lngth = poly_curve.length;
numv = length(Lngth);
breakpoints = poly_curve.breakpoints(1:2:2*numv+1);
numv = length(Lngth);
delta = Lngth/n_spline;
h_delta = delta/10;

for k=1:numv
    a = breakpoints(k)+h_delta(k); b = breakpoints(k+1)-h_delta(k);
    h= (b-a)/n_spline;
    t_spline = a:h:b;
    t_spline = [a, a+h/2,t_spline(2:n_spline), b-h/2,b];
    cf_values = zeros(size(t_spline));
    for i=1:n_spline+3
        t = t_spline(i);
        [x,~,~,y,~,~] = generate_curve_polygon(t,curve_obj);
        cf_values(i) = conjugate_function_polygon(t,x,y,t_nodes,density,...
            curve_obj,t_subdiv,degree,num_bdyquad);
    end
    pp = spline(t_spline,cf_values);
    [~,coeffs,num_int,~,~]=unmkpp(pp);
    
    % Discard the interpolation points corresponding to the parameter points 
    %      a+h/2 and b-h/2.
    % The polynomial on [a,a+h/2] suffices for all of [a,a+h].  The
    % analogous result is true for the right-hand subinterval [b-h/2,b].
    t_spline = a:h:b;
    coeffs = [coeffs(1,:); coeffs(3:num_int-1,:)];
    
    pp = mkpp(t_spline,coeffs);
    pp_polygon(k) = pp;
end

end % create_spline_conjugate_fcn_polygon

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function [spline_cf_values, deriv_cf_values] = ...
    eval_spline_conjugate_fcn_polygon(pp_polygon,t_eval,curve_obj)

% Calculate the values of the spline interpolant to the approximation of
% the conjugate function to the double layer potential.  This is produced
% by the routine create_spline_conjugate_fcn.  The evaluation points are
% given in the vector t_eval. This routine assumes the boundary curve is a
% polygon; and the needed spline interpolation information for edge #k is
% given in pp_polygon(k).

% Initialization.
%spacing = 'graded';
%type = 'gauss';

poly_curve = curve_obj.curve_parms;
numv = length(poly_curve.length);
breakpoints = poly_curve.breakpoints(1:2:2*numv+1);
lnth = length(t_eval);
spline_cf_values = zeros(size(t_eval));
deriv_cf_values = zeros(size(t_eval));
for i=1:lnth
    t = t_eval(i);
    [lower,~] = find_interval(t,breakpoints); 
    k = lower;      % t corresponds to a point on edge #k.
    pp = pp_polygon(k);
    [t_spline,cf,~,~,~]=unmkpp(pp);
    delta = t_spline(2)-t_spline(1);
    m = size(cf,1);
    num_int = floor(1 + (t-t_spline(1))/delta);
    if num_int > m
        num_int = m;
    end
    if num_int < 1
        num_int = 1;
    end
    j = num_int;
    h = t - t_spline(j);
    spline_cf_values(i) = cf(j,4)+h*(cf(j,3)+h*(cf(j,2)+h*cf(j,1)));
    deriv_cf_values(i) = cf(j,3)+h*(2*cf(j,2)+3*h*cf(j,1));
end

spline_cf_values = spline_cf_values';
deriv_cf_values = deriv_cf_values';

end % eval_spline_conjugate_fcn_polygon