function [t_subdiv,t_nodes,density,num_subdiv] = ...
               pw_poly_collocation_polygon(curve_obj,num_subdiv_in,...
                            degree,quad_order,grading_exp,index_bdyf)

% This program sets up the linear sytem for solving the integral equation
% of the second kind based on using a double-layer potential to represent
% the solution of the interior Dirichlet problem for Laplace's equation.
% The numerical method is collocation with piecewise polynomial 
% approximating functions. 
%
% This particular variant of 'pw_poly_collocation' is used for polygonal 
% boundary curves.  For that reason, the "spacing" parameter is set to
% 'graded' and the "type" parameter is set to 'gauss'.  The latter is
% chosen to avoid corner points being used as collocation node points.

% Input parameters:
% curve_obj -   This an object identifying the type of boundary
%               curve on which Laplace's equation is being solved. It also
%               includes information regarding the definition of that
%               curve.
% num_subdiv_in - The number of subdivisions for the piecewise polynomial
%               approximation.
% degree -      The degree of the piecewise polynomial function.
% quad_order -  The collocation integrals must be evaluated numerically, 
%               and we use Gauss-Legendre quadrature over each subdivision.
%               The number of quadrature points per subdivision is
%               num_quad.
% grading_exp - Used in determining the spacing of the subdivisions for
%               defining the piecewise polynomial approximant.  It is used
%               in "generate_nodes_polygon".

% Output values:
% t_subdiv -    The subdivision points for the piecewise polynomial
%               approximation functions.
% t_nodes -     These are the collocation points at which the density 
%               function is calculated.
% density -     These are the estimated values of the unknown density
%               function.
% num_subdiv -  This is number of subdivisions used on the boundary.  This
%               may differ from the input value of "num_subdiv_in", being
%               changed inside of "generate_nodes_polygon"

% Initialization.
% spacing = 'graded';
type = 'gauss';

% The parameterization interval is [0,L].
% poly_curve = curve_obj.curve_parms;
% L = poly_curve.Total_length;

% Create the collocation nodes and the subdivision of [0,L].
[t_subdiv,t_nodes, num_nodes, num_subdiv] = generate_nodes_polygon(...
    num_subdiv_in,degree,curve_obj,grading_exp);

% Create the quadrature nodes, using piecewise Gauss-Legendre quadrature.
[quad_nodes,~,num_quad] = generate_quad_pts(t_subdiv,quad_order);

% Create the boundary points corresponding to t_nodes and quad_nodes.
[x_nodes,~,~,y_nodes,~,~] = generate_curve_polygon(t_nodes,curve_obj);

[x_quad,dx_quad,d2x_quad,y_quad,dy_quad,d2y_quad] = ...
    generate_curve_polygon(quad_nodes,curve_obj);

% Calculate the array of kernel values to be used in evaluating the
% collocation integrals.
K_matrix = generate_K(num_nodes,num_quad,t_nodes,x_nodes,y_nodes,...
    quad_nodes,x_quad,y_quad,dx_quad,dy_quad,d2x_quad,d2y_quad);

% Evaluation of Lagrange basis functions at the quadrature nodes.
[basis_fcns,~,wq] = model_quad(degree,type,quad_order);

% Create the collocation matrix.
KM = create_coll_matrix(K_matrix,basis_fcns,wq,t_subdiv,num_subdiv,type);

KM = -pi*eye(num_nodes) + KM;

% Create the right hand side of the linear system.
rhs = bdyfcn(t_nodes,x_nodes,y_nodes,index_bdyf);
if is_row(rhs)
    rhs = rhs';
end

% Solve the double-layer density function.
density = KM\rhs;

if is_row(t_nodes)
    t_nodes = t_nodes';
end

end % pw_poly_collocation_polygon