function test_evaluate_potential_polygon(curve_obj,num_subdiv,degree,...
    coll_quad_order,index_bdyf,int_pt,test)
%
% Test the evaluation of the double layer potential u of the interior 
% Dirichlet problem over the interior region D_i. This program approximates 
% u by evaluating along a line from the starlike interior point int_pt to a 
% point on the boundary, specified by giving the parameterization point t 
% in [0,L]. The user is also asked for the number of quadrature nodes to be 
% used each of the subdivisions into which the boundary has been divided.
%
% This program should be used only if D_i is starlike with respect to 
% the given internal point 'int_pt'.
% 
% Input parameters:
% curve_obj -   This an object identifying the type of boundary
%               curve on which Laplace's equation is being solved. It also
%               includes information regarding the definition of that
%               curve.
% num_subdiv -  The number of subdivisions for the piecewise polynomial
%               approximation.
% degree -      The degree of the piecewise polynomial function.
% coll_quad_order - The collocation integrals must be evaluated numerically, 
%               and we use Gauss-Legendre quadrature over each subdivision.
%               The number of quadrature points per subdivision is
%               num_quad.
% index_bdyf -  This is the index for the boundary function, given in the
%               external program 'bdyfcn'.
% int_pt -      This is a point with respect to which the region D_i is
%               starlike.
% test -        A structure containing information about the approximating
%               dipole density function obtained in the collocation program
%               'pw_poly_collocation_polygon'.

% Initialization.
% spacing = 'graded';
% type = 'gauss';
num_plot_points = 1000; % Used in plotting the boundary.

% The parameterization interval is [0,L].
% poly_curve = curve_obj.curve_parms;
% L = poly_curve.Total_length;

t_subdiv = test.t_subdiv;
t_nodes = test.t_nodes;
density = test.density;

disp(' ');
disp('We evaluate the potential along a line joining a given interior ')
disp('point int_pt (given in create_polygon) and a point on the boundary.')
disp('This boundary point is specified by giving its parameter value t.')
disp('You are to specify this value t. The interior point is specified')
disp('in this demo by calling the program "create_polygon".')
disp(' ')
disp('Give a point on the boundary by means of its parameterization.')
disp('variable t. It is to be joined to the given interior star-like')
disp('centerpoint and the solution displayed along it. The number t is')
disp('to be chosen in the parameterization interval [0,L] with L the')
disp('arc length of the polygonal boundary.')
disp(' ')
tbdy = input('t = ');
disp(' ')
disp('Numerical integration will be used over each subinterval of the ')
disp('boundary curve.  What is the number of quadrature nodes to be ')
disp('used on each subinterval? We suggest 5 or 20, for comparison.')
disp(' ')
pot_quad_order = input('pot_quad_order = ');

figure
draw_bdy_polygon_with_line(curve_obj,num_plot_points,tbdy)
pause

[xbdy,~,~,ybdy,~,~] = generate_curve_polygon(tbdy,curve_obj);

num_pts = 20; % Used in determining the points at which the potential is to
              % be evaluated along the given line in D_i.
h = (.2/num_pts);
t = 0:h:1-5*h; t = t'; % Points for evaluating the potential u(x,y).
x_eval = (1-t)*int_pt(1) + t*xbdy; y_eval = (1-t)*int_pt(2) + t*ybdy;
[potential,~,~] = evaluate_potential_polygon(x_eval,y_eval,t_nodes,...
    density,curve_obj,num_subdiv,t_subdiv,degree,pot_quad_order);
if is_row(potential)
    potential = potential';
end
true_value = bdyfcn(t,x_eval,y_eval,index_bdyf);
error = true_value - potential;

figure
semilogy(t,abs(error))
% min_err = min(abs(error));
title(['Error in potential solution: num subdiv = ',num2str(num_subdiv),...
    ',   degree = ',num2str(degree),...
    ',   quad coll = ',num2str(coll_quad_order)])
xlabel(['q over [0,1):','  parameter t = ',num2str(tbdy),...
    ',   quad pot = ',num2str(pot_quad_order)])

end % test_evaluate_potential_polygon