function test_evaluate_potential_polygon2(curve_obj,degree,index_bdyf,...
                                                              int_pt,test)
%
% Test the evaluation of the double layer potential u of the interior 
% Dirichlet problem over the interior region D_i. This program approximates 
% u over D_i by using a mesh based on polar coordinates with a center at 
% the starlike interior point int_pt. The user is asked for the number of
% subdivisions to be used in the radial directions. In the azimuthal
% direction, we use the subdivision of the boundary based on the
% subinterval endpoints into which the boundary is divided when defining
% the piecewise approximation of the dipole density function. This then
% defines the mesh. The user is also asked for the number of quadrature 
% nodes to be used each of the subdivisions into which the boundary has 
% been divided.
%
% This program should be used only if D_i is starlike.
% 
% Input parameters:
% curve_obj -   This an object identifying the type of boundary
%               curve on which Laplace's equation is being solved. It also
%               includes information regarding the definition of that
%               curve.
% degree -      The degree of the piecewise polynomial function.
% index_bdyf -  This is the index for the boundary function, given in the
%               external program 'bdyfcn'.
% int_pt -      This is a point with respect to which the region D_i is
%               starlike.
% test -        A structure containing information about the approximating
%               dipole density function obtained in the collocation program
%               'pw_poly_collocation_polygon'.

% Initialization.
%spacing = 'graded';
%type = 'gauss';

% The parameterization interval is [0,L].
%poly_curve = curve_obj.curve_parms;
%L = poly_curve.Total_length;

t_subdiv = test.t_subdiv;
t_nodes = test.t_nodes;
density = test.density;
num_subdiv = test.num_subdiv;

n_rad = 10;
disp(' ')
disp('We evaluate the potential over the entire region.  We use the fact')
disp('that the region is starlike with respect to the given "int_pt" to')
disp('generate a polar coordinates type of grid in the region with')
disp('"int_pt" at its center. We use 10 subdivisions in the radial ')
disp('direction. For the angular direction, we use the collocation')
disp('subinterval endpoints on the boundary, those used in obtaining')
disp('the collocation solution of the boundary integral equation.')
disp(' ')
disp('To evaluate the double layer potential, numerical integration will')
disp('be used over each subinterval of the boundary curve.  You will be')
disp('asked for the number of quadrature nodes, "pot_quad_order", to be')
disp('used on each subinterval of the original subdivision of the')
disp('boundary curve, as used in producing the approximate double layer')
disp('density function over the boundary. We suggest 5 or 20.  You should')
disp('experiment to obtain a better feel for the different choices.')
disp(' ')
pot_quad_order = input('pot_quad_order = ');

r = 0:1/n_rad:1;
th = test.t_subdiv; n_ang = num_subdiv; 
th(n_ang+1) = 0;

X = zeros(n_ang+1,n_rad+1); Y = zeros(n_ang+1,n_rad+1);
for i=1:n_ang+1
    [xbdy,~,~,ybdy,~,~] = generate_curve_polygon(th(i),curve_obj);
    X(i,:) = (1-r)*int_pt(1) + r*xbdy;
    Y(i,:) = (1-r)*int_pt(2) + r*ybdy;
end

potential = zeros(n_ang+1,n_rad+1);
% Calculate potential at points interior to region.
potential(:,1:n_rad) = evaluate_potential_polygon(X(:,1:n_rad),Y(:,1:n_rad),...
                        t_nodes,density,curve_obj,num_subdiv,t_subdiv,...
                        degree,pot_quad_order);
% Calculate potential at points on the boundary.
potential(:,n_rad+1) = bdyfcn(th',X(:,n_rad+1),Y(:,n_rad+1),index_bdyf);

true_value = bdyfcn([],X,Y,index_bdyf);
error = true_value - potential;
figure
mesh(X,Y,potential)
xlabel('x')
ylabel('y')
zlabel('u')
title('The potential solution u(x,y)')
pause

disp(' ')
max_err = max(max(abs(error)));
disp(['Max error = ',num2str(max_err)])
figure
mesh(X,Y,error)
xlabel('x')
ylabel('y')
zlabel('error')
title('The error in the potential solution')

end % test_evaluate_potential_polygon2