function test_normal_deriv_method_polygon(curve_obj,degree,...
                                            cf_quad_order,index_bdyf,test)

% Evaluate the conjugate function for the double layer density given in the
% structure 'test'. Evaluate the conjugate function at the parameterization 
% points in z using the formula given in (Miller, page 32).  Use piecewise 
% Gauss-Legendre quadrature, doing so on each subinterval given in 
% t_subdiv, using cf_quad_order points per subinterval.
%
% INPUT
% curve_obj -   This an object identifying the type of boundary
%               curve on which Laplace's equation is being solved. It also
%               includes information regarding the definition of that
%               curve.
% degree -      The degree of the piecewise polynomial function.
% cf_quad_order - The number of Gauss-Legendre node points to be used in
%               the numerical integration over each subinterval in the
%               computation of the conjugate function.
% index_bdyf -  This is the index for the boundary function, given in the
%               external program 'bdyfcn'.
% test -        A structure containing information about the approximating
%               dipole density function obtained in the collocation program
%               'pw_poly_collocation_polygon'.
    
% Initialization.
%spacing = 'graded';
%type = 'gauss';

% The parameterization interval is [0,L].
poly_curve = curve_obj.curve_parms;
%L = poly_curve.Total_length;
Lngth = poly_curve.length;
numv = length(Lngth);
breakpoints = poly_curve.breakpoints(1:2:2*numv+1);
numv = length(Lngth);

t_subdiv = test.t_subdiv;
t_nodes = test.t_nodes;
density = test.density;
num_subdiv = test.num_subdiv;

% Create points at which to evaluate the conjugage function and the normal 
% derivative.
pts_per_side = 20;  % This is the number of points on each side of the 
                    % polygon at which the conjugate function is to be
                    % evaluated and then interpolated using a cubic spline
                    % function. This could be increased to improve the
                    % accuracy in the spline interpolant.
num_plot = pts_per_side*numv;
z = zeros(1,num_plot);
for k=1:numv
    delta = .98*Lngth(k)/(pts_per_side-1);
    t = breakpoints(k)+.01*Lngth(k):delta:breakpoints(k+1)-.01*Lngth(k);
    z(1+(k-1)*pts_per_side:k*pts_per_side) = t;
end

% The following is used in the spline conjugate function approximation. It
% is defined using the equally spaced subdivisions on each edge of the 
% polygonal boundary, when constructing the spline function interpolating 
% the conjugate function over that edge.
n_spline = floor(num_subdiv/numv);

[spline_cf_values,deriv_cf_values] = ...
    normal_deriv_method_polygon(z,curve_obj,num_subdiv,degree,t_nodes,...
    density,t_subdiv,cf_quad_order,n_spline);

true_conj_value = zeros(num_plot,1);
true_dv = zeros(num_plot,1);
for i=1:num_plot
    [x,dx,~,y,dy,~] = generate_curve_polygon(z(i),curve_obj);
    true_conj_value(i) = true_conjugate_fcn(x,y,index_bdyf);
    true_dv(i) = normal_deriv_bdyf(z(i),x,y,dx,dy,index_bdyf);
end

% Normalize the conjugate function values so that they agree at the inital
% parameter value t=0.
spline_cf_values = spline_cf_values - spline_cf_values(1) + true_conj_value(1);
figure; hold;
for k=1:numv
    id = 1+(k-1)*pts_per_side:k*pts_per_side;
    plot(z(id),true_conj_value(id),z(id),spline_cf_values(id),'.')
end
legend('True conjugate function','Approx conjugate function')
title(['Spline conjugate function approx: degree = ',num2str(degree),...
    ',  num subdiv = ',num2str(num_subdiv)])
xlabel(['curve = ',curve_obj.name,'   Boundary function ',...
    num2str(index_bdyf),',   quad cf = ',num2str(cf_quad_order)])
hold off
pause

error_cf = true_conj_value - spline_cf_values;
disp(' ');
disp(['max error in spline-based conjugate function = ',...
    num2str(norm(error_cf,inf))])
figure; hold;
for k=1:numv
    id = 1+(k-1)*pts_per_side:k*pts_per_side;
    plot(z(id),error_cf(id),z(id),error_cf(id),'.r')
end
title(['Error in spline conjugate fcn: degree = ',num2str(degree),...
    ',  num subdiv = ',num2str(num_subdiv)])
xlabel(['curve = ',curve_obj.name,',   Boundary function ',...
    num2str(index_bdyf),',  n:spline = ',num2str(n_spline)])
hold off
pause

figure; hold;
for k=1:numv
    id = 1+(k-1)*pts_per_side:k*pts_per_side;
    plot(z(id),true_dv(id),z(id),deriv_cf_values(id),'.')
end
legend('True normal derivative','Approx normal derivative')
title(['Normal derivative approx: degree = ',num2str(degree),...
    ',  num subdiv = ',num2str(num_subdiv)])
xlabel(['curve = ',curve_obj.name,',   Boundary function ',...
    num2str(index_bdyf)])
hold off
pause

error_dv = true_dv - deriv_cf_values;
disp(' '); 
disp(['max error in normal derivative = ',num2str(norm(error_dv,inf))])
figure; hold;
for k=1:numv
    id = 1+(k-1)*pts_per_side:k*pts_per_side;
    plot(z(id),error_dv(id),z(id),error_dv(id),'.r')
end
title(['Error in normal derivative: degree = ',num2str(degree),...
    ',  num subdiv = ',num2str(num_subdiv)])
xlabel(['curve = ',curve_obj.name,',   Boundary function ',...
    num2str(index_bdyf),',  n:spline = ',num2str(n_spline)])
hold off
pause

end % test_normal_deriv_method_polygon
