function cans = conjugate_function(t,x_t,y_t,t_nodes,density,curve_obj,...
   t_subdiv,degree,type)

% Evaluate the conjugate function (C. Miller, page 32) at the 
% parameterization point t.  Use Gauss-Legendre quadrature on each 
% subinterval (defined by t_subdiv) with cf_quad_order points per 
% subinterval.
%
% INPUT
% t -       A parameterization point from [0,L].
% x_t,y_t - The xy-coordinates of the point on the boundary that
%           corresponds to the point t.
% t_nodes - These are the node points for the collocation method used to
%           solve for the unknown density function over the boundary.
% density - These are the approximate values of the density obtained at the
%           collocation nodes in t_nodes.
% curve_obj - This an object identifying the type of boundary curve on
%           which Laplace's equation is being solved. It also includes
%           information regarding the definition of that curve.
% t_subdiv - These are the subdivision node points used in defining the
%           piecewise polynomial function.
% type -    This is either 'equal' or 'gauss', specifying whether the
%           interpolation nodes in each subinterval are to be equally
%           spaced for are to the Gauss-Legendre zeros of the appropriate
%           order.

cf_quad_order = 5;  % Experimentally this seems a good choice.
% cf_quad_order is he number of Gauss-Legendre node points to be used in
% the numerical integration over each subdivision when evaluating the
% conjugate function. It can be made into an input parameter rather than
% specifying it here.

% curve_parms = curve_obj.curve_parms;
% L = curve_parms.length;
lnth = length(t_subdiv);
point_t = [t,x_t,y_t];
density_t = interp_density(t,t_subdiv,t_nodes,density,type,degree);

[quad_nodes,quad_wts] = gauss_nodes_wts(cf_quad_order,0,1);

[lower,upper] = find_interval(t,t_subdiv);
i_t = lower;
a_t = t_subdiv(i_t); b_t = t_subdiv(i_t+1);

% Determine if t equals either t_subdiv(i) or t_subdiv(i+1).
if abs(a_t - t) < 100*eps || abs(b_t - t) < 100*eps
    % t is a subdivision node point.
    cans = 0;
    for i=1:lnth-1
        h = t_subdiv(i+1) - t_subdiv(i);
        for j=1:cf_quad_order
            s = t_subdiv(i) + h*quad_nodes(j);
            [x,dx,~,y,dy,~] = generate_curve(s,curve_obj);
            point_s = [s,x,y,dx,dy];
            f = conjugate_kernel(point_t,point_s,density_t,...
                               t_subdiv,t_nodes,density,type,degree);
            cans = cans + quad_wts(j)*h*f;
        end
    end
    return
end
% t is internal to [a_t,b_t] = [t_subdiv(i_t),t_subdiv(i_t+1)].
cans = 0;
for i=1:i_t-1
    h = t_subdiv(i+1) - t_subdiv(i);
    for j=1:cf_quad_order
        s = t_subdiv(i) + h*quad_nodes(j);
        [x,dx,~,y,dy,~] = generate_curve(s,curve_obj);
        point_s = [s,x,y,dx,dy];
        f = conjugate_kernel(point_t,point_s,density_t,...
                               t_subdiv,t_nodes,density,type,degree);
        cans = cans + quad_wts(j)*h*f;
    end
end

h = t - a_t;
for j=1:cf_quad_order
    s = a_t + h*quad_nodes(j);
    [x,dx,~,y,dy,~] = generate_curve(s,curve_obj);
    point_s = [s,x,y,dx,dy];
    f = conjugate_kernel(point_t,point_s,density_t,...
                               t_subdiv,t_nodes,density,type,degree);
    cans = cans + quad_wts(j)*h*f;
end

h = b_t - t;
for j=1:cf_quad_order
    s = t + h*quad_nodes(j);
    [x,dx,~,y,dy,~] = generate_curve(s,curve_obj);
    point_s = [s,x,y,dx,dy];
    f = conjugate_kernel(point_t,point_s,density_t,...
                               t_subdiv,t_nodes,density,type,degree);
    cans = cans + quad_wts(j)*h*f;
end

for i=i_t+1:lnth-1
    h = t_subdiv(i+1) - t_subdiv(i);
    for j=1:cf_quad_order
        s = t_subdiv(i) + h*quad_nodes(j);
        [x,dx,~,y,dy,~] = generate_curve(s,curve_obj);
        point_s = [s,x,y,dx,dy];
        f = conjugate_kernel(point_t,point_s,density_t,...
                               t_subdiv,t_nodes,density,type,degree);
        cans = cans + quad_wts(j)*h*f;
    end
end

end % conjugate_function