function value = conjugate_kernel(point_t,point_s,density_t,...
                               t_subdiv,t_nodes,density,type,degree)

% Evaluate the conjugate kernel function using the formula
% (2.18c) on page 33 of Clay Miller's thesis.  This function makes no sense
% if point_t or point_s is at a corner of the boundary, as then there is no
% sensible definition of the kernel function because the derivative does
% not exist.
%
% INPUT:
%
% point_t = [t,x_t,y_t] with (x_t,y_t) the point on the boundary 
% corresponding to the parameterization variable t.  It is assumed that t, 
% x_t, and y_t are each single numbers, not arrays.
%
% point_s = [s,x_s,y_s,dx_s,dy_s] with (x_s,y_s) the point on
% the boundary corresponding to the parameterization variable s. The
% vector (dx_s,dy_s) is the first derivative of the vector function 
% (x(s),y(s)), evaluated at the given parameterization point s.  It is 
% assumed that s, x_s, y_s, ... are each single numbers, not arrays.
%
% It is further assumed that point_t and point_s correspond to different 
% parameterization variables and different points on the boundary.
%
% density_t is the interpolated value of the density function, evaluated
% for the parameter t.

t = point_t(1); x_t = point_t(2); y_t = point_t(3); 

s = point_s(1); x_s = point_s(2); y_s = point_s(3);
dx_s = point_s(4); dy_s = point_s(5);

numerator = dx_s*(x_t - x_s) + dy_s*(y_t - y_s);
denominator = (x_t - x_s)^2 + (y_t - y_s)^2;

if sqrt(denominator)/max(sqrt(x_t^2+y_t^2),sqrt(x_s^2+y_s^2)) < 100*eps
    disp('Error in conjugate_kernel: point_t=point_s')
    stop
end

frac = numerator/denominator;
density_s = interp_density(s,t_subdiv,t_nodes,density,type,degree);
value = -(density_s - density_t)*frac;

end % conjugate_kernel