function [t_spline,coeffs] = create_spline_conjugate_fcn(n_spline,...
   t_nodes,density,curve_obj,t_subdiv,degree,type)

% Create a spline fit to the conjugate function as produced by the routine
% named 'conjugate_function'.  The spline function will be based on a
% uniform subdivision of [0,L], with subinterval width delta = L/(n_spline-1).
% In practice, we use a slight endpoint modification of this subdivision.
% Because we are using not-a-knot boundary conditions, we also use as
% interpolation points the parameter points delta/2 and L-delta/2 to
% improve the accuracy of the interpolant around the endpoints of [0,L].

% INPUT:
% n_spline -    The number of subdivisions to be used in creating the
%               interpolating cubic spline function.
% t_nodes -     These are the collocation points at which the density 
%               function is calculated.
% density -     These are the estimated values of the unknown dipole 
%               density function.
% curve_obj -   This an object identifying the type of boundary
%               curve on which Laplace's equation is being solved. It also
%               includes information regarding the definition of that
%               curve.
% t_subdiv -    These are the subdivision node points used in defining the
%               piecewise polynomial function.
% degree -      The degree of the piecewise polynomial function.
% type -        This is either 'equal' or 'gauss', specifying whether the
%               interpolation nodes in each subinterval are to be equally
%               spaced for are to the Gauss-Legendre zeros of the 
%               appropriate order.
%
% OUTPUT:
% t_spline -    These are the evenly spaced spline interpolation nodes.
% coeffs -      These are the coefficients for the cubic spline on the
%               n_spline subdivisions of [0,L].

curve_parms = curve_obj.curve_parms;
L = curve_parms.length;
h = L/(1000000*(n_spline-1));
a = h*L; b = (1-h)*L;  % Moving the endpoints of [0,L] so as to possibly  
                       % improve the accuracy around the end of [0,L] when
                       % doing the spline interpolation.
delta = (b-a)/(n_spline-1);     % The mesh spacing for the spline.
t_spline = a:delta:b;
t_spline = [a,a+delta/2,t_spline(2:n_spline-1),b-delta/2,b];

lnth = length(t_spline);
cf_values = zeros(size(t_spline));
for i=1:lnth
    t = t_spline(i);
    [x,~,~,y,~,~] = generate_curve(t,curve_obj);
    cf_values(i) = conjugate_function(t,x,y,t_nodes,density,curve_obj,...
         t_subdiv,degree,type);
end

pp = spline(t_spline,cf_values);
[~,coeffs,num_int,~,~]=unmkpp(pp);
% Discard the interpolation points corresponding to the parameter points 
% delta/2 and L-delta/2. The cubic polynomials on [0,delta/2] and on
% [delta/2,delta] are the same, and therefore the polynomial on [0,delta/2]
% suffices for all of [0,delta].  The analogous result is true for the
% interval [L-delta,L].
t_spline = a:delta:b;
coeffs = [coeffs(1,:)
          coeffs(3:num_int-1,:)];

end % create_spline_conjugate_fcn
