function demo_bie(curve,degree,num_subdiv,coll_quad_order,index_bdyf)

% Copyright 2013 by Kendall Atkinson
%
% This demonstrates various programs in the package, all associated with
% solving the interior Dirichlet problem as a double layer potential. The
% region is to be simply-connected with a smooth boundary or a boundary
% having a corner at one point; and the region is to be star-like with 
% respect to a given point.  Three sample regions are given in the
% subprogram 'set_bdy_param', given following the present program. When
% running the program, note there is a pause after the drawing of each
% graph.  Simply push any key to continue.  Some of the computations are
% longer than others, so be aware that you may need to wait for them to be
% completed.  In addition, we provide a special print instruction for each
% curve, given below in this current program.
%
% For new boundary value functions, and thus new true solutions, see the 
% programs 'bdyfcn', 'true_conjugate_fcn', and 'normal_deriv_bdyf'.
% 
% The numerical method is piecewise polynomial collocation, carried out
% in the program 'pw_poly_collocation'.  We also evaluate the approximating
% potential solution and its error, doing so in the programs 
% 'test_evaluate_potential' and 'test_evaluate_potential2'. Both programs
% call on the routine 'evaluate_potential_polygon'. The first evaluates the 
% potential along a line toward the boundary from a point with respect to 
% which the domain is starlike. The second evaluates over the entire 
% region. These two programs are the only ones that require that the region 
% be starlike with respect to a given point. See the routine 
% 'create_polygon' for the definition of this central starlike point.
%
% Finally, we evaluate the function that is conjugate to our double layer
% potential, doing so over the boundary. We use it to evaluate the normal
% derivative of the solution of the original problem over the boundary. 
% This is done in the routines 'test_conjugate_function' and 
% 'test_normal_deriv_method'.
%
% As a demonstration, use one of the commands and sample data.
%         demo_bie('ellipse',2,24,5,1)     Use a=1, b=2
%         demo_bie('teardrop',2,24,5,1)    Use angle=2
%                                           grading parameter = 2
%         demo_bie('cardioid',2,24,5,1)    Use c=0.8, k=1.0, a=b=1
%                                           grading parameter = 1
% In all cases, use n_rad=10, n_ang=20, pot_quad_order=20.
% This value of pot_quad_order may be much larger than needed. 

% The program will request information defining the curve.  Later it will
% ask for information to set up a grid over the region for evaluating the
% double layer potential.  At each point (x,y), the double layer integral 
% will be approximated over each of the num_subdiv subdivisions using 
% Gauss-Legendre quadrature with pot_quad_order nodes per subinterval of 
% the parameterization interval for the boundary.
%
% The user must specify the name of the curve; see the function
% 'set_bdy_param' given below for examples of defining the curve. You must
% also provide the degree of the piecewise polynomial approximation, the 
% number of subdivisions, and the order of the Gauss-Legendre quadrature 
% to be used to evaluate various integrals in the collocation method. You
% must also provide the index of the problem (index_bdyf) that is to be
% solved. Other parameters given below can be changed.  
%
% The structure curve_obj is to contain the name of the curve and the
% structure curve_parms.  The latter contains the data defining the curve,
% and this will vary with the curve being considered. The parameter 
% 'spacing' will be either 'uniform' or 'graded', and the latter should be 
% used if there is a corner on the curve corresponding to the 
% parameterization variable t=0.
%
% INPUT:
% curve -       The name of the boundary curve.
% degree -      The degree of the piecewise polynomial function.
% num_subdiv -  The number of subdivisions for the piecewise polynomial
%               approximation.
% coll_quad_order -  The collocation integrals must be evaluated 
%               numerically, and we use Gauss-Legendre quadrature over
%               each subdivision. The number of quadrature points per
%               subdivision is coll_num_quad.
% index_bdyf -  This is the index for the boundary function, given in the
%               external program 'bdyfcn'.

disp(' ')
disp('INPUT PARAMETERS:')
disp(['curve = ',curve])
disp(['degree = ',num2str(degree)])
disp(['num_subdiv = ',num2str(num_subdiv)])
disp(['coll_quad_order = ',num2str(coll_quad_order)])
disp(['index_bdyf = ',num2str(index_bdyf)])
disp('  ')

disp('PROGRAM PARAMETERS SET WITHIN demo_bie')
% If the boundary curve contains a corner, it is better to use type='gauss'.
type = 'gauss';                  % Default for this demo program.
disp(['node_type = ',num2str(type)])
cf_quad_order = coll_quad_order; % Quadrature order for calculating conjugate 
                                 % function.
disp(['cf_quad_order = ',num2str(cf_quad_order)])
num_plot = 100;    % Number of points at which to plot conjugate function,
                   % as computed by quadrature.
disp(['num_plot = ',num2str(num_plot)])
disp(' ')

[curve_parms, grading_param, spacing] = set_bdy_param(curve);
disp(' ')
curve_obj.name = curve;
curve_obj.curve_parms = curve_parms;
num_plot_points = 200;
draw_bdy(curve_obj,num_plot_points)
figure(gcf)
pause

% Solve the double-layer integral equation.
[t_subdiv,t_nodes,density] = pw_poly_collocation(curve_obj,num_subdiv,...
   degree,spacing,type,coll_quad_order,grading_param,index_bdyf);

% Create an object for the output of 'pw_poly_collocation'.  This is to
% avoid calculating this repeatedly in each of the test programs called by
% this demo program.  If any of the demo programs is to be used in a stand
% alone way, then it needs to be changed appropriately, to actually carry
% out the computations in 'pw_poly_collocation'.
test.t_subdiv = t_subdiv;
test.t_nodes = t_nodes;
test.density = density;

figure
disp('This is the graph of the dipole density function.')
plot(t_nodes,density)
name = curve_obj.name;
title(['Interior Dirichlet Problem on ',name,...
    ': The Double Layer Density Function'])
print_curve_data(curve)     
pause

disp(' ')
disp('We evaluate the double layer potential along a line joining a given')
disp('interior point, often the origin, and a point on the boundary. This')
disp('boundary point is specified by giving its parameter value t. You')
disp('are to specify this value t. The interior point is specified in')
disp('this demo program.')
disp(' ')
disp('In addition, numerical integration will be used over each subinterval')
disp('of the boundary curve.  You will be asked for the number of')
disp('quadrature nodes to be used on each subinterval.')

int_pt = curve_parms.int_pt;
test_evaluate_potential(curve_obj,num_subdiv,degree,type,...
                                 index_bdyf,int_pt,test)
pause

disp(' ')
disp('We evaluate the potential over the entire region.  We use the fact')
disp('that the region is starlike with respect to the given "int_pt" to')
disp('generate a polar coordinates type of grid in the region with int_pt')
disp('at its center.  You will be asked for the number of subdivisions in')
disp('radial and angular directions.')
disp(' ')
disp('In addition, numerical integration will be used over each subinterval')
disp('of the boundary curve.  You will be asked for the number of')
disp('quadrature nodes to be used on each subinterval.')

int_pt = curve_parms.int_pt;
test_evaluate_potential2(curve_obj,num_subdiv,degree,type,index_bdyf,...
                                                          int_pt,test)
pause

% Produce the conjugate function to the double layer potential.
disp(' ')
disp('Produce the conjugate function and the normal derivative to the')
disp('given solution function over the boundary.  The function is plotted')
disp('on [delta,L-delta] where [0,L] is the parameterization interval.')
disp('The input variable delta is to be non-negative and very small,')
disp('perhaps 0. The printed maximum errors will be over the')
disp('interval [delta,L-delta].')
disp(' ')
delta = input('delta = (To begin, we suggest 0) ');
%delta = 0;

% Evaluate the conjugate function, over the boundary, of the double layer
% potential.
test_conjugate_function(curve_obj,num_subdiv,degree,type,num_plot,...
    index_bdyf,test,delta)
pause

%disp('For the number of subdivisions to be used in computing the spline')
%disp('approximation to the conjugate function, give it as an integer')
%disp('multiple of the number of subdivisions.')
%multiple = input('multiple = ');
%n_spline = multiple*num_subdiv;  % Number of subdivisions to use in 
                                 % computing the spline approximation to 
                                 % the conjugate function.
n_spline = num_subdiv;
% Evaluate the conjugate function (actually its spline interpolant) and the
% normal derivative of the double layer potential.
test_normal_deriv_method(curve_obj,num_subdiv,degree,type,...
    num_plot,index_bdyf,n_spline,test,delta)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function print_curve_data(curve)
% The following print contains curve dependent parameters.
switch curve
    case 'ellipse'
        % Ellipse parameters
        a = curve_parms.ellipse_a; b = curve_parms.ellipse_b;             
        xlabel(['a = ',num2str(a),'   b = ',num2str(b),'   degree = ',...
            num2str(degree),'   num subdiv = ',num2str(num_subdiv),...
            '   quad order = ',num2str(coll_quad_order)])
    case 'teardrop'
        % Teardrop parameter
        theta_max = curve_parms.teardrop_thetamax;    
        xlabel(['max theta = ',num2str(theta_max),'   degree = ',...
            num2str(degree),'   num subdiv = ',num2str(num_subdiv),...
            '   quad order = ',num2str(coll_quad_order)])
    case 'cardioid'
        % Cardioid parameters
        a = curve_parms.cardioid_a; b = curve_parms.cardioid_b;           
        c = curve_parms.cardioid_c; k = curve_parms.cardioid_k; 
        xlabel(['c = ',num2str(c),'   k = ',num2str(k),...
            '   a = ',num2str(a),'   b = ',num2str(b)])
end

end % print_curve_data

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

end % demo_bie

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function [curve_parms, grading_param, spacing] = set_bdy_param(curve)
    
switch curve
    case 'ellipse'
        % Define the object containing the needed curve parameters for an ellipse.
        curve_parms.length = 2*pi;    % The length of the parameterization interval.
        disp('Give curve parameters for the ellipse.')
        disp('      (x/a)^2 + (y/b)^2 = 1')
        a = input('a = '); b = input('b = ');
        curve_parms.ellipse_a = a; curve_parms.ellipse_b = b; 
    case 'teardrop'
        % Define the object containing the needed curve parameters for a teardrop.
        % Initially try thetamax = 1.
        disp('Give the angle at the origin for the teardrop curve.')
        thetamax = input('angle at origin = ');
        curve_parms.teardrop_thetamax = thetamax;
        curve_parms.length = thetamax; % The length of the parameterization interval.
    case 'cardioid'
        % Define the object containing the needed curve parameters for a cardioid.
        % Initially try c=.8, k=1, a=b=1.
        curve_parms.length = 2*pi;    % The length of the parameterization interval.
        disp('Give the parameters for the cardioid')
        disp('(x,y) = (c*cos(t)+k)*(a*cos(t),b*sin(t)),   k > c')
        c = input('c = '); k = input('k = '); 
        a = input('a = '); b = input('b = ');
        curve_parms.cardioid_a = a; curve_parms.cardioid_b = b; 
        curve_parms.cardioid_c = c; curve_parms.cardioid_k = k; 
end

switch curve
    case 'ellipse'
        curve_parms.int_pt = [0 0];
    case 'teardrop'
        x = cos(thetamax/2); y = sin(thetamax/2);
        curve_parms.int_pt = [x/2 y/2];
    case 'cardioid'
        curve_parms.int_pt = [a*c,0];
end

% Allow input of grading parameter for the case of curve='teardrop'.
switch curve
    case 'ellipse'
        grading_param = 1;
        spacing = 'uniform';
    case {'teardrop','cardioid'}
        grading_param = input('Grading parameter = ');
        spacing = 'graded';
end

end % set_bdy_param
