function [cf_values, deriv_cf_values] = eval_spline_conjugate_fcn(...
                    t_spline,cf,t_eval,curve_obj)

% Calculate the values of the spline interpolant to the approximation of
% the conjugate function to the double layer potential.  This is produced
% by the routine create_spline_conjugate_fcn.  The evaluation points are
% given in the vector t_eval.
%
% INPUT:
% t_spline -    These are the evenly spaced spline interpolation nodes.
% cf -          These are the coefficients for the cubic spline on the
%               n_spline subdivisions of [0,L].
% t_eval -      These are the points on [0,L] at which the cubic spline and
%               its first derivative are to be evaluated.
% curve_obj -   This an object identifying the type of boundary
%               curve on which Laplace's equation is being solved. It also
%               includes information regarding the definition of that
%               curve.
%
% OUTPUT:
% cf_values -   The values of the spline interpolant at t_eval.
% deriv_cf_values - The values of the first derivative of the spline
%               interpolant at t_eval. These values are then corrected to
%               make the derivative with respect to arc length.

delta = t_spline(2)-t_spline(1);
[m,~] = size(cf);

lnth = length(t_eval);      % Equals n_spline+1
cf_values = zeros(size(t_eval));
deriv_cf_values = zeros(size(t_eval));

for i=1:lnth
    t = t_eval(i);
    num_int = floor(1+t/delta);
    if num_int > m
        num_int = m;
    end
    if num_int < 1
        num_int = 1;
    end
    j = num_int;
    h = t - t_spline(j);
    cf_values(i) = cf(j,4)+h*(cf(j,3)+h*(cf(j,2)+h*cf(j,1)));
    deriv_cf_values(i) = cf(j,3)+h*(2*cf(j,2)+3*h*cf(j,1));
    % Correction for not using arc length as the parameterization variable
    [~,dx,~,~,dy,~] = generate_curve(t,curve_obj);
    deriv_cf_values(i) = deriv_cf_values(i)/sqrt(dx^2+dy^2);
end

end % eval_spline_conjugate_fcn