function potential = evaluate_potential(x_eval,y_eval,t_nodes,density,...
       curve_obj,num_subdiv,t_subdiv,degree,type,num_pquad)

% Evaluate the double-layer potential u with the given "density" function
% at the nodes given in (x_eval,y_eval).  x_eval and y_eval can be either
% one or two dimensional arrays. We integrate over each subinterval of the 
% piecewise polynomial function using Gaussian quadrature with "num_pquad" 
% points on that subinterval. As points approach the boundary, a higher
% order numerical integration is needed to preserve the accuracy associated
% with that of the approximating double layer density function.
%
% INPUT:
% x_eval,y_eval - The coordinates at which to evaluate the double layer 
%               potential.
% t_nodes -     These are the nodes at which the Nystrom approximation was
%               computed using the trapezoidal rule. The number of 
%               subdivisions length(num_trap).
% density -     This is the Nystrom solution for the double layer density
%               at the points in t_nodes.
% curve_obj -   This an object identifying the type of boundary curve on
%               which Laplace's equation is being solved. It also includes
%               information regarding the definition of that curve.
% num_subdiv -  The number of subdivisions for the piecewise polynomial
%               approximation.
% t_subdiv -    These are the breakpoints for creating the subdivision
%               for the piecewise polynomial approximation.
% degree -      The degree of the piecewise polynomial function.
% type -        This equals 'equal' or 'gauss', used in defining the way in
%               which the collocation degree+1 node points are distributed
%               within each subinterval.
% num_pquad -   This is the number of Gauss points to use on each
%               subdivision when approximating the double layer potential.
%
% OUTPUT:
% potential -   The approximation of the double layer potential at the
%               nodes in (x_eval,y_eval).

[nr,nc] = size(x_eval);

% Obtain the quadrature nodes and weights on the interval [0,1].
[zq,wq] = gauss_nodes_wts(num_pquad,0,1);

% Generate the nodes and weights over the entire interval [0,L]. 
N = num_subdiv*num_pquad;
z = zeros(1,N); w = z;
for k=1:num_subdiv
    h = t_subdiv(k+1)-t_subdiv(k);
    w((k-1)*num_pquad+1:k*num_pquad) = h*wq;
    z((k-1)*num_pquad+1:k*num_pquad) = t_subdiv(k)+h*zq;
end

% Evaluate the density function at each of the eventual quadrature node
% points. Also generate the corresponding points on the boundary
% corresponding to the quadrature node points.
value = zeros(1,N);
point = zeros(N,4);
for k=1:N
    [x,dx,~,y,dy,~] = generate_curve(z(k),curve_obj);
    point(k,1:4) = [x,y,dx,dy];
    value(k) = interp_density(z(k),t_subdiv,t_nodes,density,type,degree);
end

% Combine the quadrature weights and density function.
value = w.*value;

% Evaluate the potential function.
potential = zeros(nr,nc);
for i=1:nr
    for j=1:nc
        sum = 0;
        for k=1:N
            sum = sum + ...
                value(k)*kernel_M(x_eval(i,j),y_eval(i,j),point(k,:));
        end
        potential(i,j) = sum;
    end
end

end % evaluate_potential

%========================================================================
function value = kernel_M(x,y,point_s)

% Evaluate the double layer potential kernel function for a point (x,y)
% interior to the region of interest. 

% point_s = [x_s,y_s,dx_s,dy_s] with (x_s,y_s) the point on the boundary 
% corresponding to the integration parameterization variable s. The 
% vector (dx_s,dy_s) is the first derivative of the vector function 
% (x(s),y(s)), evaluated at the given parameterization point s.  It is 
% assumed that s, x_s, y_s, ... are each single numbers, not arrays.

x_s = point_s(1); y_s = point_s(2);
dx_s = point_s(3); dy_s = point_s(4);

denominator = (x_s-x)^2 + (y_s-y)^2;
numerator = -dy_s*(x_s-x) + dx_s*(y_s-y);
value = numerator/denominator;

end % kernel_M