function [x,dx,d2x,y,dy,d2y] = generate_curve(t,curve_obj)

% Generate the points (x,y) on the boundary curve, corresponding to
% the parameterization variables in t.  We also generate the first 
% and second derivatives of the parameterization function.
%
% INPUT:
% t -       The points t in [0,L] at which the curve values are to be
%           evaluated. This includes the coordinates (x,y) and the first
%           and second derivatives at those coordinates
% curve_obj - This an object identifying the type of boundary curve on
%           which Laplace's equation is being solved. It also includes
%           information regarding the definition of that curve.

curve = curve_obj.name;
curve_parms = curve_obj.curve_parms;
switch curve
    case 'ellipse'
        % This is the ellipse (x/a)^2 + (y/b)^2 = 1
        a = curve_parms.ellipse_a; b = curve_parms.ellipse_b;
        cs = cos(t-pi/2); sn = sin(t-pi/2);
        x = a*cs; y = b*sn;
        dx = -a*sn; dy = b*cs;
        d2x = -x; d2y = -y;
    case 'teardrop'
        % This is the teardrop shaped boundary
        %    (x,y) = sin(c*t)*(cos(t),sin(t)),  c = pi/theta_max
        % the parameterization interval is [0,theta_max]. The boundary has 
        % a corner at the origin, corresponding to the end-points of the
        % parameterization interval. The angle at the corner is theta_max.
        %
        % With this curve, it is best to use type='gauss' in solving 
        % boundary integral equations, to avoid having the corner point be 
        % a node_point. Theoretically, the integral equation needs a 
        % modified definition at the corner point.
        c = pi/curve_parms.teardrop_thetamax; d = 1+c*c;
        cs = cos(t); sn = sin(t);
        sc = sin(c*t); cc = cos(c*t);
        x = sc.*cs; y = sc.*sn;
        dx = c*cs.*cc - sn.*sc; dy = cs.*sc + c*sn.*cc;
        d2x = -d*cs.*sc - 2*c*sn.*cc; d2y = -d*sn.*sc + 2*c*cs.*cc;
    case 'cardioid'
        % This defines the cardioid boundary
        %   (x,y) = r(a cos(theta),b sin(theta))
        %       r = c*cos(theta) + k
        % In choosing the cardioid parameters, use k > c, and 
        % choose a,b > 0. 
        a = curve_parms.cardioid_a; b = curve_parms.cardioid_b;           
        c = curve_parms.cardioid_c; k = curve_parms.cardioid_k;
        theta = t - pi;
        cs = cos(theta); sn = sin(theta);
        r = c*cs + k; dr = -c*sn; d2r = -c*cs;
        x = a*r.*cs; 
        dx = a*(dr.*cs - r.*sn); 
        d2x = a*(d2r.*cs - 2*dr.*sn - r.*cs); 
        y = b*r.*sn;
        dy = b*(dr.*sn + r.*cs);
        d2y = b*(d2r.*sn + 2*dr.*cs - r.*sn);
end

end % generate_curve