function [t_subdiv,t_nodes,num_nodes] = generate_nodes(...
                         subdiv,degree,spacing,type,grading_exp,curve_obj)      

% Create the nodes for the collocation scheme.  We are using piecewise
% polynomial collocation on [0,L].  There are to be subdiv subdivisions
% of [0,L], and on each subinterval, we will use polynomial interpolation
% of the given degree.
%
% The spacing is used in defining the subdivisions, with the possibilities
% being 'uniform' and 'graded'.  With the latter, we need the grading_exp.
% The variable 'type' is 'equal' or 'gauss'.  With boundary curves having
% one corner, choose type='gauss' in order to avoid having the corner point 
% be a collocation node point.

% INPUT:
% subdiv -      The number of subdivisions of [0,L] to be created.
% degree -      The degree of the piecewise polynomial function.
% spacing -     The spacing of the subdivisions.  The possibilities are
%               as follows.
%               'uniform' - Using equal spacing of the parameterization
%                           variable.
%               'graded' -  Use a mesh that is graded around the endpoints
%                           of the integration interval. The grading is
%                           geometric.
% type -        This is either 'equal' or 'gauss', specifying whether the
%               interpolation nodes in each subinterval are to be equally
%               spaced or are to the Gauss-Legendre zeros of the 
%               appropriate order.
% grading_exp - When the mesh is 'graded' around the point corresponding to
%               0 (or equivalently, L), this constant is used in defining
%               an algebraic grading of the mesh. It should be 1 or larger.
%               Using grading_exp=1 corresponds to a uniform mesh (no 
%               grading). See the following program for the grading 
%               process.
% curve_obj -   This an object identifying the type of boundary curve on
%               which Laplace's equation is being solved. It also includes
%               information regarding the definition of that curve.
%
% OUTPUT:
% t_subdiv -    The subdivision points for the piecewise polynomial
%               approximation functions.
% t_nodes -     These are the collocation points at which the density 
%               function is calculated.
% num_nodes -   The length of t_nodes.

    curve_parms = curve_obj.curve_parms;
    L = curve_parms.length;

    if degree == 0 && strcmp(type,'equal')
        type = 'gauss';
    end

    % Create the subdivision.
    % The boundary curve is not polygonal.  It is assumed there is at most
    % one corner point on the boundary; and if there is a corner point,
    % then it occurs at the parameter value 0, or equivalently, at L.
    switch spacing
        case 'uniform'
            h = L/subdiv;
            t_subdiv = h*(0:subdiv);
        case 'graded'
            % grade the subdivisions around the endpoints of the 
            % interval [0,L].
            half_subdiv = floor(subdiv/2);
            if 2*half_subdiv < subdiv
                t_left = 0.5*L*((0:half_subdiv)/(subdiv/2)).^grading_exp;
                t_right = L - t_left(half_subdiv+1:-1:1);
                t_subdiv = [t_left,t_right];
            else
                t_left = 0.5*L*((0:half_subdiv)/half_subdiv).^grading_exp;
                t_right = L - t_left(half_subdiv+1:-1:1);
                t_subdiv = [t_left(1:half_subdiv),t_right];
            end
    end

    % Create the interpolation nodes.
    switch type
        case 'equal'
            % Use only with degree > 0.
            model = (0:degree-1)/degree;
            for i=1:subdiv
                step = t_subdiv(i+1) - t_subdiv(i);
                t_nodes((i-1)*(degree)+(1:degree)) = t_subdiv(i) + step*model;
            end
            t_nodes = [t_nodes  L];
        case 'gauss'
            % Use with degree >= 0.
            [model,~] = gauss_nodes_wts(degree+1,0,1);
            if ~is_row(model) 
                model = model';
            end
            for i=1:subdiv
                step = t_subdiv(i+1) - t_subdiv(i);
                t_nodes((i-1)*(degree+1)+(1:degree+1)) = t_subdiv(i) + step*model;
            end
    end

    num_nodes = length(t_nodes);
    
end % generate_nodes

% --------------------------------------------------------------------

function [nodes,wts] = gauss_nodes_wts(n,a,b)

% Gauss-Legendre nodes and weights
%
% a,b   -  integration limits
% n     -  order of formula 
% nodes,wts -  Gauss base points and weight factors on [a,b]

u = (1:n-1)./sqrt((2*(1:n-1)).^2-1);
[vc,bp] = eig(diag(u,-1)+diag(u,1));
[bp,k] = sort(diag(bp));
wts = (b-a)*vc(1,k)'.^2; 
nodes = (a+b)/2+((b-a)/2)*bp;

end % gauss_nodes_wts

