function info_bie
%
% Following is a list of programs in the package for solving the Dirichlet
% problem over a bounded simply-connected region in the plane.  It is
% assumed that the region has a boundary with a parameterization
% (x(t),y(t)) with t varying over an interval [0,L].  It is assumed that
% the parameterization is periodic and continuously differentiable over
% [0,L], although it is permitted for the first derivative to not be 
% periodic (i.e. the derivatives at t=0 and t=L may differ).  In this
% latter case, the boundary is said to have a corner at (x(0),y(0)), and 
% we assume the angle at the corner is in the open interval (0,2*pi).
% 
% For notation in the following, we use u=u(x,y) to denote the unknown
% potential solution being sought, and we also use it to reference the 
% approximating solution. We use v=v(x,y) to denote a conjugate function
% to u, with all such conjugate functions differing by a constant.
%
%
% TEST PROGRAMS:
%
% demo_bie - This is a demonstration program incorporating calls on all of
%           the remaining test programs and the collocation program
%           'pw_poly_collocation'.
% test_evaluate_potential - This tests the evaluation of the double layer
%           potential function u along a line specified by the user.  It
%           is compared to the known true potential function.
% test_evaluate_potential2 - This tests the evaluation of the double layer
%           potential function u over the entire region.  It is compared
%           to the known true potential function.
% test_conjugate_function - This tests the calculation of the conjugate
%           function v using numerical quadrature of an appropriate
%           integral formula for v.
% test_normal_deriv_method - This produces another approximation to the
%           conjugate function v, based on a cubic spline interpolant to
%           data values obtained by another numerical integration. This
%           is compared to the true conjugate function.  In addition, the 
%           derivative of the spline function is used in obtaining the 
%           normal derivative of u over the boundary. Errors are calculated
%           and graphed with both the conjugate  function and the normal 
%           derivative.
%
%
% REMAINING PROGRAMS:
%
% conjugate_function - This calculates the conjugate function using the
%           formula given on page 32 of the PhD thesis of Clayton Miller,
%           University of Iowa, 1979. A composite numerical integration 
%           rule is used with a 5-point Gaussian quadrature formula used
%           per subdivision.  The number of subdivisions is 'num_subdiv'.
% conjugate_kernel - This calculates the conjugate kernel function needed
%           to define the conjugate function.
% create_coll_matrix - This creates the collocation matrix.
% create_spline_conjugate_fcn - Creates the cubic spline interpolant to the
%           conjugate function.
% draw_bdy - Draw the boundary of the region.
% draw_bdy_with_line - Draw the boundary of the region together with the
%           line along
% eval_spline_conjugate_fcn - Evaluate the cubic spline interpolant created
%           using 'create_spline_conjugate_fcn'.
% evaluate_potential - Evaluate the double layer potential at given node
%           points.  A composite numerical integration rule is used that is
%           based on Gaussian quadrature with 'num_quad' nodes per
%           subinterval (num_quad specified by the user). The number of
%           subdivisions is that of the collocation solution for the double
%           layer density function.
% find_interval - A utility routine. Given a point t in [0,L] and a 
%           subdivision of [0,L], find the subinterval containing t.
% gauss_nodes_wts - Calculate needed Gaussian quadrature nodes and weights.
% generate_K - Create a set of values of the double layer kernel function.
% generate_nodes - Generate collocation subintervals and node points.
% generate_quad_pts - Generate quadrature node points for a composite rule
%           using Gaussian quadrature on each subdivision.
% interp_density - Interpolate the piecewise polynomial function defining
%           the approximate double layer density function.
% is_row - A utility function. Used to tell if a vector is a row or column
%           vector.
% kernel - Evaluate the double layer density function.
% model_quad - Evaluate the Lagrange basis functions over [0,1] relative to
%           the type of collocation nodes being used, namely 'equal' or
%           'gauss'.
% pw_poly_collocation - The main program for finding the piecewise
%           polynomial function that approximates the double layer density
%           function.
%
%
% FUNCTIONS TO BE SUPPLIED BY THE USER:
%
% bdyfcn - The true potential solution, from which the Dirichlet boundary
%           data is generated.
% generate_curve - Defines the boundary curve.
% normal_deriv_bdyf - Defines the true normal derivative of the potential
%           function being calculated.
% true_conjugate_fcn - Defines the true conjugate function of the potential
%           function being calculated.
%
%
% STANDARD VARIABLE NAMES:
%
% Standard variable names throughout the various programs for solving over
% a boundary with at most one corner, namely at the parameter value t=0 
% (and t=L).
%
% basis_fcns:   These are values of the Lagrange interpolation basis
%               functions for some sub-interval.
% cf_values:    Conjugate function values, obtained from the routine
%               "conjugate_function", based on spline interpolation. These 
%               are the values at given input parameter values 'z_eval'.
% cf_quad_order: The order of the Gaussian quadrature to be used in
%               calculating the integrals over each subinterval for the
%               conjugate function.
% coeffs:       The spline coefficients for the spline function 
%               approximating the conjugate function for the double layer
%               potential.
% coll_quad_order: The order of the Gaussian quadrature to be used in
%               calculating the collocation integrals over each
%               subinterval.
% curve:        This is a string variable, identifying the boundary curve
%               being used.
% curve_obj:    This structure contains two objects, curve_obj.name and
%               curve_obj.curve_parms. For all cases, curve_obj.curve_parms
%               contains information needed in defining the boundary
%               curve.  This varies between curves.
% degree:       The degree of the piecewise polynomial approximation.
% density:      This is the double layer density function, and it is
%               calculated using "pw_poly_collocation".
% deriv_cf_values:  These are the first derivatives of the spline function
%               approximating the conjugate function, corrected for a lack
%               of arc-length parameterization, to obtain the normal
%               derivative of the double layer potential.
% grading_param:  The grading exponent used in creating a graded mesh in the
%               case spacing='graded'.  Choose "grading_param" greater than
%               or equal to 1. A value of 1 will result in a uniform mesh.
% index_bdyf, index_bdyfcn:   This is the index of the function for the
%               Dirichlet boundary data function.
% int_pt:       This is input to the program 'generate_curve' that creates
%               curve_obj, and it is stored in the structure 'curve_parms'
%               as curve_parms.int_pt. It is a point with respect to which 
%               the boundary is starlike. 
% K_matrix:     This matrix contains the kernel values to be used in
%               evaluating the matrix collocation integrals.
% KM:           Collocation matrix, using integrals calculated numerically.
% L:            The length of the parameterization interval.
% n_spline:     The number of subdivisions used in specifying t_spline for
%               computing the spline interpolant to the conjugate function.
% num_subdiv:   The number of subdivisions to be used in defining our
%               piecewise polynomial approximation.
% pot_quad_order: This is the order of the Gauss-Legendre quadrature to be
%               used on each sub-interval of the boundary when calculating
%               the double layer potential integral.
% pp:           This structure is used to store the piecewise polynomial
%               created in 'create_spline_conjugate_fcn'.  This structure 
%               is used subsequently in 'eval_spline_conjugate_fcn' to
%               evaluate the conjugate function and its derivative, the
%               normal derivative of the original double layer potential.
% quad_cf_values: Conjugate function values, used in the routine
%               "conjugate_function", based on quadrature and used to 
%               produce an interpolating spline function.  
% spline_cf_values: Conjugate function values, obtained from the routine
%               "conjugate_function", based on spline interpolation.
%               These are the values at given input parameter values 'z_eval'.
% spacing:      This is a string variable defining the type of spacing used
%               in defining the subdivision. The two acceptable values are
%               'uniform' and 'graded'.
% t_nodes:      These are the collocation points.  The length of "t_nodes"
%               is denoted by "num_nodes", and it varies with the choice 
%               of "type", "degree", and "num_subdiv".
% t_spline:     The spline function subdivision breakpoints for the spline
%               function approximating the conjugate function for the 
%               double layer potential.  These points are evenly spaced.
%               used on each subinterval of the boundary when approximating
%               the double layer potential.
% t_subdiv:     These are the breakpoints for the piecewise polynomial
%               function, and the length of "t_subdiv" is "num_subdiv".
% type:         This is a string variable.  At present it takes the values
%               'equal' and 'gauss'. With 'equal', there are degree+1
%               interpolation nodes that are evenly space in each 
%               subinterval [t(i),t(i+1)], including the endpoints. With 
%               'gauss' we use as interpolation nodes the Gauss-Legendre
%               nodes of order=degree+1.
% x,y,dx,dy,d2x,d2y: (x,y) is a point on the boundary corresponding to a
%               given parameter value t.  (dx,dy) and (d2x,d2y) are the
%               first and second derivatives with respect to t.  These are
%               to be calculated in the routine 'generate_curve', which
%               in turn uses curve_obj.
% z_eval:       A temporary storage vector for parameterization values at
%               which various quantities (e.g. the conjugate function) are
%               to be evaluated.
% zq,wq:        Gauss-Legendre nodes and weights on [0,1].
