function [t_subdiv,t_nodes,density] = pw_poly_collocation(curve_obj,...
   num_subdiv,degree,spacing,node_type,quad_order,options_nodes,index_bdyf)

% This program sets up the linear sytem for solving the integral equation
% of the second kind based on using a double-layer potential to represent
% the solution of the interior Dirichlet problem for Laplace's equation.
% The numerical method is collocation with piecewise polynomial 
% approximating functions. 

% INPUT:
% curve_obj -   This an object identifying the type of boundary
%               curve on which Laplace's equation is being solved. It also
%               includes information regarding the definition of that
%               curve.
% num_subdiv -  The number of subdivisions for the piecewise polynomial
%               approximation.
% degree -      The degree of the piecewise polynomial function.
% spacing -     The spacing of the subdivisions or breakpoints.  The 
%               possibilities are as follows:
%               'uniform' - Using equal spacing of the parameterization
%                           variable.
%               'graded' -  Use a mesh that is graded around the endpoints
%                           of the integration interval. The grading is
%                           geometric.
% node_type -   The placement of the interpolation node points within 
%               each subdivision; it is also called 'type' in many of the 
%               routines. The possibilitiesare as follows:
%               'equal' -   Use equal spacing of the degree+1 nodes within
%                           each subdivision.
%               'gauss' -   Use the Gauss-Legendre nodes of order degree+1.
% quad_order -  The collocation integrals must be evaluated numerically, 
%               and we use Gauss-Legendre quadrature over each subdivision.
%               The number of quadrature points per subdivision is
%               num_quad.
% options_nodes Options for the nodes. For example, if spacing='graded',
%               then options_nodes(1) is the grading parameter. This
%               generality is introduced to allow for future growth in
%               information about the definition of breakpoints and nodes.
% index_bdyf -  This is the index of the boundary function, given in the
%               external program 'bdyfcn'.

% Output values:
% t_subdiv -    The subdivision points for the piecewise polynomial
%               approximation functions.
% t_nodes -     These are the collocation points at which the density 
%               function is calculated.
% density -     These are the estimated values of the unknown density
%               function.

% The parameterization interval is [0,L].
% curve_parms = curve_obj.curve_parms;
% L = curve_parms.length;

% Consider the case of piecewise constant interpolation/collocation.
if degree == 0 && strcmp(node_type,'equal')
    node_type = 'gauss';
end

% Initialize the variable grading_exp based on the form of spacing.
if strcmp(spacing,'graded')
    grading_exp = options_nodes(1);
else
    grading_exp = 1;
end

% Create the collocation nodes and the subdivision of [0,L].
[t_subdiv,t_nodes, num_nodes] = generate_nodes(num_subdiv,degree,...
    spacing,node_type,grading_exp,curve_obj);

% Create the quadrature nodes, using piecewise Gauss-Legendre quadrature.
[quad_nodes,~,num_quad] = generate_quad_pts(t_subdiv,quad_order);

% Create the boundary points corresponding to t_nodes and quad_nodes.
[x_nodes,~,~,y_nodes,~,~] = generate_curve(t_nodes,curve_obj);

[x_quad,dx_quad,d2x_quad,y_quad,dy_quad,d2y_quad] = ...
                                generate_curve(quad_nodes,curve_obj);

% Calculate the array of kernel values to be used in evaluating the
% collocation integrals.
K_matrix = generate_K(num_nodes,num_quad,t_nodes,x_nodes,y_nodes,...
    quad_nodes,x_quad,y_quad,dx_quad,dy_quad,d2x_quad,d2y_quad);

% Evaluation of Lagrange basis functions at the quadrature nodes.
[basis_fcns,~,wq] = model_quad(degree,node_type,quad_order);

% Create the collocation matrix.
KM = create_coll_matrix(K_matrix,basis_fcns,wq,t_subdiv,num_subdiv,...
                                   node_type);

KM = -pi*eye(num_nodes) + KM;

% Create the right hand side of the linear system.
rhs = bdyfcn(t_nodes,x_nodes,y_nodes,index_bdyf);
if is_row(rhs)
    rhs = rhs';
end

% Solve the double-layer density function.
density = KM\rhs;

if is_row(t_nodes)
    t_nodes = t_nodes';
end

end % pw_poly_collocation