function test_conjugate_function(curve_obj,num_subdiv,degree,type,...
    num_plot,index_bdyf,test,delta)
%
% Evaluate the conjugate function for the double layer density given in the
% structure 'test'. Evaluate the conjugate function at the evenly spaced 
% parameterization points obtained by subdividing [delta,L-delta] into 
% num_plot evenly spaced points. Use the formula given in (Miller, page 32).  
% Use piecewise Gauss-Legendre quadrature, doing so on each subinterval 
% given in t_subdiv, using cf_quad_order points per subinterval.
%
% INPUT
% curve_obj -   This an object identifying the type of boundary
%               curve on which Laplace's equation is being solved. It also
%               includes information regarding the definition of that
%               curve.
% num_subdiv -  The number of subdivisions into which [0,L] has been
%               subdivided in order to define the piecewise polynomial  
%               approximation.
% degree -      The degree of the piecewise polynomial function.
% type -        This is either 'equal' or 'gauss', specifying whether the
%               interpolation nodes in each subinterval are to be equally
%               spaced for are to the Gauss-Legendre zeros of the 
%               appropriate order.
% num_plot -    This is the number of evenly spaced points on
%               [delta,L-delta] at which the conjugate function is to be
%               evaluated and then plotted.
% index_bdyf -  This is the index for the boundary function, given in the
%               external program 'bdyfcn'.
% test -        A structure containing information about the approximating
%               dipole density function obtained in the collocation program
%               'pw_poly_collocation_polygon'.
% delta -       In some cases, the conjugate function is not as accurate
%               around the endpoints of [0,L], and thus we can choose to
%               plot the error on [delta,L-delta] if so desired. The
%               quantity delta is always non-negative, and it can be zero.

curve_parms = curve_obj.curve_parms;
L = curve_parms.length;

t_subdiv = test.t_subdiv;
t_nodes = test.t_nodes;
density = test.density;

step_plot = (L-2*delta)/(num_plot-1);
z = step_plot*(0:num_plot-1) + delta;
conj_fcn_value = zeros(num_plot,1);
true_cf = zeros(length(z),1);
for i=1:num_plot
    [x,~,~,y,~,~] = generate_curve(z(i),curve_obj);
    conj_fcn_value(i) = conjugate_function(z(i),x,y,t_nodes,density,...
                        curve_obj,t_subdiv,degree,type);
    true_cf(i) = true_conjugate_fcn(x,y,index_bdyf);
end

midpt = floor((num_plot-1)/2);
figure
true_cf = true_cf-true_cf(midpt)+conj_fcn_value(midpt);
plot(z,conj_fcn_value,'.',z,true_cf)
legend('Approximation','True')
title(['Conjugate function approx using quadrature: degree = ',...
    num2str(degree),'  num subdiv = ',num2str(num_subdiv)])
xlabel(['curve = ',curve_obj.name,...
    '   Boundary function ',num2str(index_bdyf)])
pause

disp(' ')
maxerr = norm(conj_fcn_value-true_cf,inf);
disp(['Max error in the conjugate function using quadrature = ',...
    num2str(maxerr)])
figure
plot(z,conj_fcn_value-true_cf)
title('Error in the conjugate function using quadrature')

end % test_conjugate_function
