function test_evaluate_potential2(curve_obj,num_subdiv,degree,type,...
    index_bdyf,int_pt,test)
%
% Test the evaluation of the double layer potential u of the interior 
% Dirichlet problem over the interior region D_i. This program approximates 
% u over D_i by using a mesh based on polar coordinates with a center at 
% the starlike interior point int_pt. The user is asked for the number of
% subdivisions to be used in the radial and azimuthal directions. The user 
% is also asked for the number of quadrature nodes to be used each of the 
% subdivisions into which the boundary has been divided.
%
% This program should be used only if D_i is starlike with respect to 
% the given internal point 'int_pt'.
% 
% INPUT:
% curve_obj -   This an object identifying the type of boundary
%               curve on which Laplace's equation is being solved. It also
%               includes information regarding the definition of that
%               curve.
% num_subdiv -  The number of subdivisions for the piecewise polynomial
%               approximation.
% degree -      The degree of the piecewise polynomial function.
% type -        This is either 'equal' or 'gauss', specifying whether the
%               interpolation nodes in each subinterval are to be equally
%               spaced for are to the Gauss-Legendre zeros of the 
%               appropriate order.
% index_bdyf -  This is the index for the boundary function, given in the
%               external program 'bdyfcn'.
% int_pt -      This is a point with respect to which the region D_i is
%               starlike.
% test -        A structure containing information about the approximating
%               dipole density function obtained in the collocation program
%               'pw_poly_collocation_polygon'.

curve_parms = curve_obj.curve_parms;
L = curve_parms.length;
% Find the dipole density function for the double layer potential solving
% the interior Dirichlet problem for Laplace's equation.
%[t_subdiv,t_nodes,density] = pw_poly_collocation(curve_obj,num_subdiv,...
%    degree,spacing,type,coll_quad_order,options_nodes,index_bdyf);
t_subdiv = test.t_subdiv;
t_nodes = test.t_nodes;
density = test.density;

disp(' ')
disp('Give the number of radial points, extending from the')
disp('"center point" to the boundary?')
disp(' ')
n_rad = input('n_rad = (We suggest 10) ');
disp(' ')
disp('Give the number of points around the boundary.')
disp(' ')
n_ang = input('n_ang = (We suggest 20) ');
disp(' ')
disp('Numerical integration will be used over each subinterval of the ')
disp('boundary curve.  What is the number of quadrature nodes to be ')
disp('used on each subinterval? We suggest 5 or 20, for comparison.')
disp(' ')
pot_quad_order = input('pot_quad_order = ');

r = 0:1/n_rad:1;
th = 0:L/n_ang:L;

X = zeros(n_ang+1,n_rad+1); Y = zeros(n_ang+1,n_rad+1);
for i=1:n_ang+1
    [xbdy,~,~,ybdy,~,~] = generate_curve(th(i),curve_obj);
    X(i,:) = (1-r)*int_pt(1) + r*xbdy;
    Y(i,:) = (1-r)*int_pt(2) + r*ybdy;
end

potential = zeros(n_ang+1,n_rad+1);
% Calculate potential at points interior to region.
potential(:,1:n_rad) = evaluate_potential(X(:,1:n_rad),Y(:,1:n_rad),...
                        t_nodes,density,curve_obj,num_subdiv,t_subdiv,...
                        degree,type,pot_quad_order);
% Calculate potential at points on the boundary.
potential(:,n_rad+1) = bdyfcn(th',X(:,n_rad+1),Y(:,n_rad+1),index_bdyf);
                   
true_value = bdyfcn([],X,Y,index_bdyf);
error = true_value - potential;
%disp('q, x, y, approximate potential, error')
%format short e
%disp([t,x_eval,y_eval,potential,error])
figure
surf(X,Y,potential)
xlabel('x')
ylabel('y')
zlabel('u')
title('The approximate solution u(x,y)')
pause

max_err = max(max(abs(error)));
disp(' ')
disp(['Max error in the approximate solution = ',num2str(max_err)])
figure
% mesh(X,Y,error)
mesh(X,Y,-log10(abs(error)))
xlabel('x')
ylabel('y')
zlabel('-log10(error)')
title('The error in the approximate solution')

end % test_evaluate_potential2