function test_normal_deriv_method(curve_obj,num_subdiv,degree,...
    type,num_plot,index_bdyf,n_spline,test,delta)

% Evaluate the conjugate function for the double layer density given in the
% structure 'test'. Evaluate the conjugate function at the evenly spaced 
% parameterization points obtained by subdividing [delta,L-delta] into 
% num_plot evenly spaced points. Use the integral formula given in (Miller,  
% page 32). Use piecewise Gauss-Legendre quadrature to approximate this 
% integral, doing so on each subinterval given in t_subdiv, using 
% cf_quad_order points per subinterval. 
%
% Following this, produce a cubic spline interpolating to the conjugate 
% function, in order to approximate the derivative of the conjugate 
% function along the boundary of the region. This derivative is then used 
% to construct the inner normal derivative of the double layer potential 
% along its boundary. Both the spline interpolant of the conjugate function
% and the normal derivative of the double layer potential along the
% boundary are graphed, and their errors are also graphed.
%
% INPUT
% curve_obj -   This an object identifying the type of boundary
%               curve on which Laplace's equation is being solved. It also
%               includes information regarding the definition of that
%               curve.
% num_subdiv -  The number of subdivisions into which [0,L] has been
%               subdivided in order to define the piecewise polynomial  
%               approximation.
% degree -      The degree of the piecewise polynomial function.
% type -        This is either 'equal' or 'gauss', specifying whether the
%               interpolation nodes in each subinterval are to be equally
%               spaced for are to the Gauss-Legendre zeros of the 
%               appropriate order.
% num_plot -    This is the number of evenly spaced points on
%               [delta,L-delta] at which the conjugate function is to be
%               evaluated and then plotted.
% index_bdyf -  This is the index for the boundary function, given in the
%               external program 'bdyfcn'.
% n_spline -    The number of subdivisions to be used in producing the
%               spline interpolant to the conjugate function.
% test -        A structure containing information about the approximating
%               dipole density function obtained in the collocation program
%               'pw_poly_collocation_polygon'.
% delta -       In some cases, the conjugate function is not as accurate
%               around the endpoints of [0,L], and thus we can choose to
%               plot the error on [delta,L-delta] if so desired. The
%               quantity delta is always non-negative, and it can be zero.

curve_parms = curve_obj.curve_parms;
L = curve_parms.length;

% Find the dipole density function for the double layer potential solving
% the interior Dirichlet problem for Laplace's equation.
%[t_subdiv,t_nodes,density] = pw_poly_collocation(curve_obj,num_subdiv,...
%    degree,spacing,type,coll_quad_order,options_nodes,index_bdyf);
t_subdiv = test.t_subdiv;
t_nodes = test.t_nodes;
density = test.density;

% Create the spline interpolant that approximates the normal derivative 
% function on the boundary of the curve for the double layer potential 
% being found above.
[t_spline,coeffs] = create_spline_conjugate_fcn(n_spline,t_nodes,density,...
   curve_obj,t_subdiv,degree,type);

% Compare our approximate conjugate function and normal derivative to the 
% true values. 
step_plot = (L-2*delta)/(num_plot-1);
z = step_plot*(0:num_plot-1)' + delta;
% conj_value = zeros(num_plot,1);
% deriv_value = zeros(num_plot,1);
true_conj_value = zeros(num_plot,1);
true_dv = zeros(num_plot,1);

[cf_values, deriv_cf_values] = eval_spline_conjugate_fcn(t_spline,...
                               coeffs,z,curve_obj);

for i=1:num_plot
    [x,dx,~,y,dy,~] = generate_curve(z(i),curve_obj);
    true_conj_value(i) = true_conjugate_fcn(x,y,index_bdyf);
    true_dv(i) = normal_deriv_bdyf(z(i),x,y,dx,dy,index_bdyf);
end

% Normalize the conjugate function values so that they agree at the inital
% parameter value t=0.
midpt = floor((num_plot-1)/2)+1;
cf_values = cf_values - cf_values(midpt) + true_conj_value(midpt);
figure
plot(z,true_conj_value,z,cf_values,'.')
legend('True conjugate function','Approx conjugate function')
title(['Spline conjugate function approx: degree = ',num2str(degree),...
    '  num subdiv = ',num2str(num_subdiv)])
xlabel(['curve = ',curve_obj.name,...
    '   Boundary function ',num2str(index_bdyf)])
pause

error_cf = true_conj_value - cf_values;
disp(' '); 
disp(['Max error in spline-based conjugate function = ',...
    num2str(norm(error_cf,inf))])
figure
plot(z,error_cf,z,error_cf,'.r')
title(['Error in spline conj fcn approx: degree = ',...
    num2str(degree),'  num subdiv = ',num2str(num_subdiv)])
xlabel(['curve = ',curve_obj.name,'   Boundary function ',...
    num2str(index_bdyf),'  n:spline = ',num2str(n_spline)])
pause

figure
plot(z,true_dv,z,deriv_cf_values,'.')
legend('True normal derivative','Approx normal derivative')
title(['Normal derivative approx: degree = ',num2str(degree),...
    '  num subdiv = ',num2str(num_subdiv)])
xlabel(['curve = ',curve_obj.name,'   Boundary function ',...
    num2str(index_bdyf)])
pause

error_dv = true_dv - deriv_cf_values;
disp(' '); 
disp(['Max error in normal derivative = ',num2str(norm(error_dv,inf))])
figure
plot(z,error_dv,z,error_dv,'.r')
title(['Error in normal derivative: degree = ',num2str(degree),...
    '  num subdiv = ',num2str(num_subdiv)])
xlabel(['curve = ',curve_obj.name,'   Boundary function ',...
    num2str(index_bdyf),'  n:spline = ',num2str(n_spline)])

end % test_normal_deriv_method
