function  [t,rho,cf] = Drchlt_Direct_FirstKind(curve_obj,num_degree,...
    num_quad,index_bdyf)

% This program solves approximately the first kind integral equation
% (7.1.28) of page 315 in my integral equations text. The unknown solution
% is the inner normal derivative of u, and the Dirichlet data is to be 
% given in 'bdyfcn'. This program should not be used if the boundary is a
% Gamma-contour; see (7.3.124) on page 343 of my text and the associated
% discussion.
% 
% The program Galerkin_discrete is used to solve the integral equation. It
% expresses the unknown solution at a point r(s)=(x(s),y(s)) as the sum
%
%    2n+1
%    SUM cf(j) psi(s,j-n-1)
%    j=1
%
% divided by abs(r'(s)) where r(s) denotes the position vector at the
% parameterization variable s.
%
% Input parameters:
% curve_obj -   This an object identifying the type of boundary
%               curve on which Laplace's equation is being solved. It also
%               includes information regarding the definition of that
%               curve.
% num_degree -  The degree of the approximation of the single layer density
%               function. In this program, it is simplified to n.
% num_quad -    This is the number of quadrature nodes to be used in
%               evaluating the right hand side g in (7.1.28). It seems
%               sufficient to use num_quad = 2*num_degree, although using
%               num_quad = 3*num_degree should ensure maximum accuracy.
% index_bdyf -  This is the index of the boundary function, given in the
%               external program 'bdyfcn'.

% Output values:

% The parameterization interval is [0,2 pi].
 
n = num_degree; 
M = 2*n+1;
h = 2*pi/(2*n+1);

% Create the quadrature nodes and the subdivision of [0,L].
t = h*(1:M)';

[x_nodes,dx_nodes,~,y_nodes,dy_nodes,~] = ...
                            generate_curve(t,curve_obj);

% Obtain the matrix B_n, a portion of approximating the first kind
% integral operator.
B_matrix = generate_B_n(n,t,x_nodes,y_nodes,dx_nodes,dy_nodes);

Psi = zeros(M,M);
% Psi(j,mm) is to contain the basis function psi_m evaluated at t(j).
for mm = 1:M
    m = mm - n - 1;
    Psi(:,mm) = basis(t,m);
end

Kermat = zeros(M,M);
term1 = zeros(M,M); term2 = zeros(M,M); 
for mm = 1:M
    m = mm - n - 1;
    for j = 1:M
        term1(j,mm) = Psi(j,mm)/max(1,abs(m));
        term2(j,mm) = B_matrix(j,:)*Psi(:,mm);        
        Kermat(j,mm) = term1(j,mm) + term2(j,mm);        
    end
end

% Create the right hand side of the linear system.
rhs = -Create_RHS(t,x_nodes,y_nodes,index_bdyf,num_quad,curve_obj);
if is_row(rhs)
    rhs = rhs';
end

% Solve for the coefficients in the representation of (7.3.159) on
% page 352 of my integral equations text.
cf = Kermat\rhs;

% Evaluate the single layer potential at the node points in t.
abs_r = sqrt(dx_nodes.^2 + dy_nodes.^2);
rho = real((Psi*cf))./abs_r;

disp(' ')
disp(['Condition number of linear system = ',num2str(cond(Kermat))])
disp(' ')

end % Drchlt_Direct_FirstKind

