function demo_Drchlt_Direct_FirstKind(curve,num_degree,index_bdyf,...
    num_quad,n_eval)

% Copyright 2013 by Kendall Atkinson
%
% This solves for the interior normal derivative of the unknown potential u
% when the Dirichlet data is given for u. The method used is a direct
% method; see (7.1.28) on page 315 of my integral equations text. The
% program uses th discrete Galerkin method given on page 351 of my text.
% This program should not be used if the boundary is a Gamma-contour;
% see (7.3.124) on page 343 of my text and the associated discussion
%
% As a demonstration, use one of the commands and sample data.
%    demo_Drchlt_Direct_FirstKind('ellipse',10,1,20,50)   
%                                                  Use a=2, b=1
%    demo_Drchlt_Direct_FirstKind('cardioid',15,1,30,50)  
%                                                  Use c=0.8, k=1.0, a=b=1
%
% Input parameters:
% curve -       This name identifies the boundary.
% num_degree -  The degree of the approximation of the single layer density
%               function. In this program, it is simplified to n.
% index_bdyf -  This is the index of the boundary function, given in the
%               external programs 'bdyfcn' and 'normal_deriv_bdyf'. The
%               latter program gives the exterior normal derivative; and
%               below, we use its negative as the interior normal
%               derivative, to check the error in our computation in the
%               program 'Drchlt_Direct_FirstKind'.
% num_quad -    This is the number of quadrature nodes to be used in
%               evaluating the right hand side g in (7.1.28). It seems
%               sufficient to use num_quad = 2*num_degree, although using
%               num_quad = 3*num_degree should ensure maximum accuracy.
% n_eval -      The number of subdivisions to be used in producing a graph
%               of our approximation of the normal derivative and checking
%               its error.

n = num_degree;
disp(' ')
disp('INPUT PARAMETERS:')
disp(['curve = ',curve])
disp(['index_bdyf = ',num2str(index_bdyf)])
disp(['num_degree = ',num2str(n)])
disp(['num_quad = ',num2str(num_quad)])
disp(' ')

[curve_parms, ~, ~] = set_bdy_param(curve);
disp(' ')
curve_obj.name = curve;
curve_obj.curve_parms = curve_parms;
num_plot_curve_points = 200;
draw_bdy(curve_obj,num_plot_curve_points)
figure(gcf)
print_curve_data(curve)
pause

[t_at_nodes,rho_at_nodes,cf] = Drchlt_Direct_FirstKind(curve_obj,n,...
    num_quad,index_bdyf);

% Print coefficients of (7.3.159), page 352 of my text.
%idx = (-n:1:n)';
%disp('   j    c(j)')
%disp([idx,cf])

h_eval = 2*pi/n_eval; t_eval = h_eval*(0:n_eval)';
[x_nodes,dx_nodes,~,y_nodes,dy_nodes,~] = ...
                            generate_curve(t_eval,curve_obj);

abs_dr = sqrt(dx_nodes.^2 + dy_nodes.^2);
rho_eval = eval_rho(t_eval,abs_dr,cf);
figure
plot(t_eval,real(rho_eval))
title(['The normal derivative \rho_n: n = ',num2str(n)])
xlabel(['n:eval = ',num2str(n_eval)])
pause

true_dv = -normal_deriv_bdyf(t_eval,x_nodes,y_nodes,dx_nodes,dy_nodes,...
    index_bdyf);
error_dv = true_dv - rho_eval;
figure
plot(t_eval,real(error_dv))
title(['Error in normal derivative \rho_n: n = ',num2str(n)])
xlabel(['n:eval = ',num2str(n_eval)])
max_error = norm(error_dv,inf);
disp(' ')
disp(['Maximum error = ',num2str(max_error)])

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function print_curve_data(curve)
% The following print contains curve dependent parameters.
switch curve
    case 'ellipse'
        a = curve_parms.ellipse_a; b = curve_parms.ellipse_b;     % Ellipse parameters        
        xlabel(['a = ',num2str(a),'   b = ',num2str(b),...
            '   num:degree = ',num2str(num_degree)])
    case 'cardioid'
        a = curve_parms.cardioid_a; b = curve_parms.cardioid_b;           
        c = curve_parms.cardioid_c; k = curve_parms.cardioid_k; % Cardioid parameters
        xlabel(['c = ',num2str(c),'   k = ',num2str(k),...
            '   a = ',num2str(a),'   b = ',num2str(b),...
            '   num:degree = ',num2str(num_degree)])
end
end % print_curve_data

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

end % demo_Drchlt_Direct_FirstKind

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function [curve_parms, grading_param, spacing] = set_bdy_param(curve)
    
switch curve
    case 'ellipse'
        % Define the object containing the needed curve parameters for an ellipse.
        curve_parms.length = 2*pi;    % The length of the parameterization interval.
        disp('Give curve parameters for the ellipse.')
        disp('      (x/a)^2 + (y/b)^2 = 1')
        a = input('a = '); b = input('b = ');
        curve_parms.ellipse_a = a; curve_parms.ellipse_b = b; 
    case 'cardioid'
        % Define the object containing the needed curve parameters for a cardioid.
        % Initially try c=.8, k=1, a=b=1.
        curve_parms.length = 2*pi;    % The length of the parameterization interval.
        disp('Give the parameters for the cardioid')
        disp('(x,y) = (c*cos(t)+k)*(a*cos(t),b*sin(t)),   k > c')
        c = input('c = '); k = input('k = '); 
        a = input('a = '); b = input('b = ');
        curve_parms.cardioid_a = a; curve_parms.cardioid_b = b; 
        curve_parms.cardioid_c = c; curve_parms.cardioid_k = k; 
end

switch curve
    case 'ellipse'
        curve_parms.int_pt = [0 0];
    case 'cardioid'
        curve_parms.int_pt = [a*c,0];
end

% Allow input of grading parameter for the case of curve='teardrop'. This
% is not needed in our solution of the first kind bie.
switch curve
    case 'ellipse'
        grading_param = 1;
        spacing = 'uniform';
    case {'cardioid'}
        grading_param = 1;
        spacing = 'uniform';
end

end % set_bdy_param
