function  [t,rho,cf] = Galerkin_discrete(curve_obj,num_degree,index_bdyf)

% This program solves approximately the first kind integral equation
% (7.3.119) of page 342 in my integral equations text. The unknown single
% layer density evaluated at r(s)=(x(s),y(s)) is the sum
%
%    2n+1
%    SUM cf(j) psi(s,j-n-1)
%    j=1
%
% divided by abs(r'(s)) where r(s) denotes the position vector at the
% parameterization variable s.
%
% Input parameters:
% curve_obj -   This an object identifying the type of boundary
%               curve on which Laplace's equation is being solved. It also
%               includes information regarding the definition of that
%               curve.
% num_degree -  The degree of the approximation of the single layer density
%               function. In this program, it is simplified to n.
% index_bdyf -  This is the index of the boundary function, given in the
%               external program 'bdyfcn'.

% Output values:

% The parameterization interval is [0,2 pi].
 
n = num_degree; 
M = 2*n+1;
h = 2*pi/(2*n+1);

% Create the quadrature nodes and the subdivision of [0,L].
t = h*(1:M)';

[x_nodes,dx_nodes,~,y_nodes,dy_nodes,~] = ...
                            generate_curve(t,curve_obj);

B_matrix = generate_B_n(n,t,x_nodes,y_nodes,dx_nodes,dy_nodes);

Psi = zeros(M,M);
% Psi(j,mm) is to contain the basis function psi_m evaluated at t(j).
for mm = 1:M
    m = mm - n - 1;
    Psi(:,mm) = basis(t,m);
end

Kermat = zeros(M,M);
term1 = zeros(M,M); term2 = zeros(M,M); 
for mm = 1:M
    m = mm - n - 1;
    for j = 1:M
        term1(j,mm) = Psi(j,mm)/max(1,abs(m));
        term2(j,mm) = B_matrix(j,:)*Psi(:,mm);        
        Kermat(j,mm) = term1(j,mm) + term2(j,mm);        
    end
end

% Create the right hand side of the linear system.
rhs = (-1/pi)*bdyfcn(t,x_nodes,y_nodes,index_bdyf);
if is_row(rhs)
    rhs = rhs';
end

% Solve for the coefficients in the representation of (7.3.159) on
% page 352 of my integral equations text.
cf = Kermat\rhs;

% Evaluate the single layer potential at the node points in t.
abs_r = sqrt(dx_nodes.^2 + dy_nodes.^2);
rho = real((Psi*cf))./abs_r;

disp(' ')
disp(['Condition number of linear system = ',num2str(cond(Kermat))])
disp(' ')

end % Galerkin_discrete

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function tf_val = is_row(v)

% Return TRUE if v is a row vector. Otherwise, return FALSE.  
% If v is a column vector, then FALSE is returned.

[n1,n2] = size(v);
if n1 == 1 && n2 >= 1
    tf_val = true;
else
    tf_val = false;
end

end % is_row