function [t_nodes,density] = Nystrom(curve_obj,num_trap,index_bdyf)

% This program sets up and solves the linear system for solving the 
% integral equation of the second kind based on using a double-layer 
% potential to represent the solution of the interior Dirichlet problem for
% Laplace's equation. The numerical method is Nystrom's method with the 
% trapezoidal rule. See Section 7.2 (page 320) and formula (7.2.49) of my
% integral equations text.
%
% This is not intended for use with boundaries with a single corner point,
% unlike the use of pw_poly_collocation which does allow for such a corner
% point. To allow the handling of such a boundary, the integration rule
% could be changed to something like the midpoint quadrature rule, thus
% avoiding the corner point.

% Input parameters:
% curve_obj -   This an object identifying the type of boundary
%               curve on which Laplace's equation is being solved. It also
%               includes information regarding the definition of that
%               curve.
% num_trap -    The number of quadrature points for the definition of the
%               numerical integration approximation of the double layer 
%               operator.
% index_bdyf -  This is the index of the boundary function, given in the
%               external program 'bdyfcn'.

% Output values:
% t_nodes -     These are the node points at which the density function
%               is approximated.
% density -     These are the estimated values of the unknown double layer
%               density function.

% The parameterization interval is [0,L].
curve_parms = curve_obj.curve_parms;
L = curve_parms.length;

% Create the quadrature nodes and the subdivision of [0,L].
h_trap = L/num_trap;
t_nodes = h_trap*(1:num_trap)';

[x_nodes,dx_nodes,d2x_nodes,y_nodes,dy_nodes,d2y_nodes] = ...
                            generate_curve(t_nodes,curve_obj);

% Calculate the array of kernel values to be used in evaluating the
% collocation integrals.
K_matrix = generate_K_Nystrom(num_trap,x_nodes,y_nodes,dx_nodes,...
    dy_nodes,d2x_nodes,d2y_nodes);

% Create the Nystrom system matrix.
KM = -pi*eye(num_trap) + h_trap*K_matrix;

% Create the right hand side of the linear system.
rhs = bdyfcn(t_nodes,x_nodes,y_nodes,index_bdyf);
if is_row(rhs)
    rhs = rhs';
end

% Solve the double-layer density function.
density = KM\rhs;

end % Nystrom
