function cans = conjugate_function_Nystrom(t,x_t,y_t,t_spline,...
    density_spline,curve_obj)

% Evaluate the conjugate function (C. Miller, page 32) at the 
% parameterization point t.  Use Gauss-Legendre quadrature on each 
% subinterval (defined by t_spline) with cf_quad_order points per 
% subinterval (see below)
%
% INPUT
% t -       A parameterization point from [0,L].
% x_t,y_t - The xy-coordinates of the point on the boundary that
%           corresponds to the point t.
% t_spline - These are the node points for the Nystrom method used to
%           solve for the unknown density function over the boundary.
% density - These are the approximate values of the density obtained at the
%           nodes in t_spline.
% curve_obj - This an object identifying the type of boundary curve on
%           which Laplace's equation is being solved. It also includes
%           information regarding the definition of that curve.

cf_quad_order = 5;  % Experimentally this seems a good choice.
% cf_quad_order is he number of Gauss-Legendre node points to be used in
% the numerical integration over each subdivision when evaluating the
% conjugate function. It can be made into an input parameter rather than
% specifying it here.

[quad_nodes,quad_wts] = gauss_nodes_wts(cf_quad_order,0,1);

% curve_parms = curve_obj.curve_parms;
% L = curve_parms.length;

point_t = [t,x_t,y_t];
density_t = ppval(density_spline,t);
lnth = length(t_spline);

[lower,upper] = find_interval(t,t_spline);
a_t = t_spline(lower); b_t = t_spline(upper);

% Determine if t equals either t_spline(lower) or t_spline(upper).
if abs(a_t - t) < 100*eps || abs(b_t - t) < 100*eps
    % t is a subdivision node point.
    cans = 0;
    for i=1:lnth-1
        h = t_spline(i+1) - t_spline(i);
        s = t_spline(i) + h*quad_nodes;
        density_s = ppval(density_spline,s);
        [x,dx,~,y,dy,~] = generate_curve(s,curve_obj);
        for j=1:cf_quad_order
            point_s = [s(j),x(j),y(j),dx(j),dy(j)];
            f = conjugate_kernel_Nystrom(point_t,point_s,density_t,...
                density_s(j));
            cans = cans + quad_wts(j)*h*f;
        end
    end
    return
end

% t is internal to [a_t,b_t] = [t_spline(i_t),t_spline(i_t+1)].
cans = 0;
for i=1:lower-1
    h = t_spline(i+1) - t_spline(i);
    s = t_spline(i) + h*quad_nodes;
    density_s = ppval(density_spline,s);
    [x,dx,~,y,dy,~] = generate_curve(s,curve_obj);
    for j=1:cf_quad_order
        point_s = [s(j),x(j),y(j),dx(j),dy(j)];
        f = conjugate_kernel(point_t,point_s,density_t,density_s(j));
        cans = cans + quad_wts(j)*h*f;
    end
end

h = t - a_t;
s = a_t + h*quad_nodes;
density_s = ppval(density_spline,s);
[x,dx,~,y,dy,~] = generate_curve(s,curve_obj);
for j=1:cf_quad_order
    point_s = [s(j),x(j),y(j),dx(j),dy(j)];
    f = conjugate_kernel(point_t,point_s,density_t,density_s(j));
    cans = cans + quad_wts(j)*h*f;
end

h = b_t - t;
s = t + h*quad_nodes;
density_s = ppval(density_spline,s);
[x,dx,~,y,dy,~] = generate_curve(s,curve_obj);
for j=1:cf_quad_order
    point_s = [s(j),x(j),y(j),dx(j),dy(j)];
    f = conjugate_kernel(point_t,point_s,density_t,density_s(j));
    cans = cans + quad_wts(j)*h*f;
end

for i=upper:lnth-1
    h = t_spline(i+1) - t_spline(i);
    s = t_spline(i) + h*quad_nodes;
    [x,dx,~,y,dy,~] = generate_curve(s,curve_obj);
    for j=1:cf_quad_order
        point_s = [s(j),x(j),y(j),dx(j),dy(j)];
        f = conjugate_kernel(point_t,point_s,density_t,density_s(j));
        cans = cans + quad_wts(j)*h*f;
    end
end

end % conjugate_function_Nystrom
