function [t_spline,spline_cf] = create_spline_conjugate_fcn_Nystrom(...
   t_nodes,density,curve_obj,multiplier_spline,index_bdyf)

% Create a spline fit to the conjugate function as produced by the routine
% named 'conjugate_function_Nystrom'.  The spline function will be based on
% a uniform subdivision of [0,L], with multiplier_spline*num_trap
% subdivisions (and num_trap the number of subdivisions used in the 
% routine Nystrom). In practice, we use a slight endpoint modification of 
% this subdivision. Because we are using not-a-knot boundary conditions, we
% also use as interpolation points the parameter points delta/2 and 
% L-delta/2 to improve the accuracy of the interpolant around the endpoints 
% of [0,L].

% INPUT:
% t_nodes -     These are the collocation points at which the density 
%               function is calculated.
% density -     These are the estimated values of the unknown dipole 
%               density function.
% curve_obj -   This an object identifying the type of boundary
%               curve on which Laplace's equation is being solved. It also
%               includes information regarding the definition of that
%               curve.
% multiplier_spline - The number of subdivisions of [0,L] is to equal
%               multiplier_spline*num_trap with num_trap the length of
%               t_nodes (and density).
% index_bdyf -  This is the index for the boundary function, given in the
%               external program 'bdyfcn'.
%
% OUTPUT:
% t_spline -    These are the evenly spaced spline interpolation nodes.
% spline_cf -   These are the coefficients for the cubic spline on the
%               n_spline subdivisions of [0,L] as produced by the Matlab
%               program 'spline'.

curve_parms = curve_obj.curve_parms;
L = curve_parms.length;

num_trap = length(t_nodes); h_trap = L/num_trap;

h_spline = L/(multiplier_spline*num_trap);
t_spline = 0:h_spline:L;
lnth = length(t_spline);
t_spline = [0,h_spline/2,t_spline(2:lnth-1),L-h_spline/2,L]';
num_spline = length(t_spline);

% Using Nystrom interpolation, extend the (double layer) density to the new
% node points in t_spline. Begin by calculating the needed curve values at
% the parameterization points in t_nodes and t_spline.
[x_nodes,dx_nodes,d2x_nodes,y_nodes,dy_nodes,d2y_nodes] = ...
                            generate_curve(t_nodes,curve_obj);
[x_spline,~,~,y_spline,~,~] = generate_curve(t_spline,curve_obj);
rhs = bdyfcn(t_spline,x_spline,y_spline,index_bdyf);

density_t_spline = zeros(num_spline,1);
% Use Nystrom interpolation to extend to t_spline the approximation of the
% double layer density function.
for ii=1:num_spline
    point_t = [x_spline(ii),y_spline(ii)];
    for j=1:num_trap
        point_s = [x_nodes(j),y_nodes(j),dx_nodes(j),dy_nodes(j),...
                d2x_nodes(j),d2y_nodes(j)];
        fker = kernel_Nystrom(point_t,point_s);
        density_t_spline(ii) = density_t_spline(ii) + fker*density(j);
    end
    density_t_spline(ii) = (h_trap*density_t_spline(ii) - rhs(ii))/pi;
end

density_spline = spline(t_spline,density_t_spline);

cf_values = zeros(num_spline,1);
for i=1:num_spline
    t = t_spline(i);
    [x,~,~,y,~,~] = generate_curve(t,curve_obj);
    temp = conjugate_function_Nystrom(t,x,y,t_spline,...
                              density_spline,curve_obj);
    cf_values(i) = temp;
end

% Create the spline interpolating the conjugate function values.
spline_cf = spline(t_spline,cf_values);

end % create_spline_conjugate_fcn_Nystrom