function demo_bie_Nystrom(curve,num_trap,index_bdyf)

% Copyright 2013 by Kendall Atkinson
%
% This demonstrates various programs in the package, all associated with
% solving the interior Dirichlet problem as a double layer potential. The
% region is to be simply-connected with a smooth boundary or a boundary
% having a corner at one point; and the region is to be star-like with 
% respect to a given point.  Three sample regions are given in the
% subprogram 'set_bdy_param', given following the present program. When
% running the program, note there is a pause after the drawing of each
% graph.  Simply push any key to continue.  Some of the computations are
% longer than others, so be aware that you may need to wait for them to be
% completed, especially the computation of the normal derivative of the 
% double layer potential. In addition, we provide a special print 
% instruction for each curve, given below in this current program.
%
% For the test case boundary value functions, and thus true solutions, see 
% the programs 'bdyfcn', 'true_conjugate_fcn', and 'normal_deriv_bdyf'.
% 
% The numerical method is Nystroms method, carried out in the program 
% 'Nystrom'.  We also evaluate the approximating potential solution and its 
% error, doing so in the programs 'test_evaluate_potential' and 
% 'test_evaluate_potential2'.  The first evaluates the potential along a 
% line toward the boundary from the given starlike interior point, and the 
% second evaluates over the entire region. These two programs are the only 
% ones that require that the region be starlike with respect to a given 
% point. See the routine 'set_bdy_param' for the definition of this central 
% starlike point.
%
% Finally, we evaluate the function that is conjugate to our double layer
% potential, doing so over the boundary. We use it to evaluate the normal
% derivative of the solution of the original problem over the boundary. 
% This is done in the routines 'test_conjugate_function' and 
% 'test_normal_deriv_method'.
%
% As a demonstration, use one of the commands and sample data.
%         demo_bie_Nystrom('ellipse',40,1)     Use a=1, b=2
%         demo_bie_Nystrom('cardioid',40,1)    Use c=0.8, k=1.0, a=b=1
%         demo_bie_Nystrom('ellipse_kelvin',40,1)  Use a=2, b=4
% In all cases, we suggest using n_rad=10, n_ang=20 in the program
% 'test_evaluate_potential2_Nystrom'.
%
% This program will request information defining the curve.  Later it will
% ask for information to set up a grid over the region for evaluating the
% double layer potential.  At each point (x,y), the double layer integral 
% will be approximated using the trapezoidal rule with num_trap*multiplier 
% nodes of the boundary.
%
% The user must specify the name of the curve; see the function
% 'set_bdy_param' given below for examples of defining the curve. You must
% also provide the number of subdivisions, called num_trap, and the 
% quantity called multiplier, used in determining the numerical integration 
% over the boundary for the conjugate function and other quantities. You
% must also provide the index of the problem (index_bdyf) that is to be
% solved. Other parameters given below can be changed.  
%
% The structure 'curve_obj' is to contain the name of the curve and the
% structure 'curve_parms'.  The latter contains the data defining the
% curve, and this will vary with the curve being considered.
%
% INPUT:
% curve -       The name of the boundary curve.
% num_trap -    The number of subdivisions used in applying the Nystrom
%               method with the trapezoidal rule to the solution of the
%               double layer potential integral equation.
% index_bdyf -  This is the index for the boundary function, given in the
%               external program 'bdyfcn'.

disp(' ')
disp('INPUT PARAMETERS:')
disp(['curve = ',curve])
disp(['index_bdyf = ',num2str(index_bdyf)])
disp(['num_trap = ',num2str(num_trap)])
disp(' ')

[curve_parms, ~, ~] = set_bdy_param(curve);
disp(' ')
curve_obj.name = curve;
curve_obj.curve_parms = curve_parms;
num_plot_curve_points = 200;
draw_bdy(curve_obj,num_plot_curve_points)
figure(gcf)
pause

% Solve for the dipole density function.
[t_nodes_Nystrom,density_Nystrom] = Nystrom(curve_obj,num_trap,index_bdyf);
test.density_Nystrom = density_Nystrom;
test.t_nodes_Nystrom = t_nodes_Nystrom;

figure
disp(' ')
disp(['This is the graph of the Nystrom-based double layer',...
    ' density function.'])
plot(t_nodes_Nystrom,density_Nystrom)
name = curve_obj.name;
title(['Interior Dirichlet Problem on ',name,...
    ': The Double Layer Density Function + Nystrom'])
print_curve_data(curve)
pause

disp(' ')
disp('We evaluate the double layer potential along a line joining a given')
disp('interior point, often the origin, and a point on the boundary. This')
disp('boundary point is specified by giving its parameter value t. You')
disp('are to specify this value t. The interior point is specified in')
disp('this demo program.')
disp(' ')
disp('In addition, numerical integration will be used over the ')
disp('parameterization interval of the boundary curve.  You will be asked ')
disp('for a parameter used to determine the number of quadrature points.')

int_pt = curve_parms.int_pt;
test_evaluate_potential_Nystrom(curve_obj,index_bdyf,int_pt,test)
pause

disp(' ')
disp('We evaluate the potential over the entire region.  We use the fact')
disp('that the region is starlike with respect to the given "int_pt" to')
disp('generate a polar coordinates type of grid in the region with int_pt')
disp('at its center.  You will be asked for the number of subdivisions in')
disp('radial and angular directions.')
disp(' ')
disp('In addition, quadrature over the parameterization [0,L] of the')
disp('boundary curve is needed.  You will be asked for a multiplier that')
disp('determines the number of quadrature nodes to be used on [0,L].')

int_pt = curve_parms.int_pt;
test_evaluate_potential2_Nystrom(curve_obj,index_bdyf,int_pt,test)
pause

%test_conjugate_function_Nystrom(curve_obj,index_bdyf,test);
%pause

test_normal_deriv_method_Nystrom(curve_obj,index_bdyf,test)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function print_curve_data(curve)
% The following print contains curve dependent parameters.
switch curve
    case 'ellipse'
        % Ellipse parameters
        a = curve_parms.ellipse_a; b = curve_parms.ellipse_b;             
        xlabel(['a = ',num2str(a),'   b = ',num2str(b),'   num:trap = ',...
            num2str(num_trap)])
    case 'cardioid'
        % Cardioid parameters
        a = curve_parms.cardioid_a; b = curve_parms.cardioid_b;           
        c = curve_parms.cardioid_c; k = curve_parms.cardioid_k; 
        xlabel(['c = ',num2str(c),'   k = ',num2str(k),...
            '   a = ',num2str(a),'   b = ',num2str(b),'   num:trap = ',...
            num2str(num_trap)])
    case 'ellipse_kelvin'
        % Ellipse_Kelvin parameters: the inversion of the ellipse through
        % the unit circle.
        a = curve_parms.ellipse_a; b = curve_parms.ellipse_b;             
        xlabel(['a = ',num2str(a),'   b = ',num2str(b),'   num:trap = ',...
            num2str(num_trap)])
end
end % print_curve_data

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

end % test_Nystrom

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function [curve_parms, grading_param, spacing] = set_bdy_param(curve)
    
switch curve
    case 'ellipse'
        % Define the object containing the needed curve parameters for an ellipse.
        curve_parms.length = 2*pi;    % The length of the parameterization interval.
        disp('Give curve parameters for the ellipse.')
        disp('      (x/a)^2 + (y/b)^2 = 1')
        a = input('a = '); b = input('b = ');
        curve_parms.ellipse_a = a; curve_parms.ellipse_b = b; 
    case 'cardioid'
        % Define the object containing the needed curve parameters for a cardioid.
        % Initially try c=.8, k=1, a=b=1.
        curve_parms.length = 2*pi;    % The length of the parameterization interval.
        disp('Give the parameters for the cardioid')
        disp('(x,y) = (c*cos(t)+k)*(a*cos(t),b*sin(t)),   k > c > 0')
        c = input('c = '); k = input('k = '); 
        a = input('a = '); b = input('b = ');
        curve_parms.cardioid_a = a; curve_parms.cardioid_b = b; 
        curve_parms.cardioid_c = c; curve_parms.cardioid_k = k; 
    case 'ellipse_kelvin'
        % Define the object containing the needed curve parameters for an 
        % ellipse, and thus for its inversion through the unit circle.
        curve_parms.length = 2*pi; % Length of the parameterization interval.
        disp('Give curve parameters for the ellipse.')
        disp('      (x/a)^2 + (y/b)^2 = 1')
        a = input('a = '); b = input('b = ');
        curve_parms.ellipse_a = a; curve_parms.ellipse_b = b; 
end

switch curve
    case 'ellipse'
        curve_parms.int_pt = [0 0];
    case 'cardioid'
        curve_parms.int_pt = [a*c,0];
    case 'ellipse_kelvin'
        curve_parms.int_pt = [0 0];
end

switch curve
    case 'ellipse'
        grading_param = 1;
        spacing = 'uniform';
    case {'cardioid'}
        grading_param = 1;
        spacing = 'uniform';
    case 'ellipse_kelvin'
        grading_param = 1;
        spacing = 'uniform';
end

end % set_bdy_param
