function [cf_values,deriv_cf_values] = ...
    eval_spline_conjugate_fcn_Nystrom(t_eval,curve_obj,t_nodes,density,...
    multiplier_spline,index_bdyf)

% Create a spline fit to the conjugate function as produced by the routine
% named 'conjugate_function_Nystrom'.  The spline function will be based on
% a uniform subdivision of [0,L], with multiplier_spline*num_trap
% subdivisions (and num_trap the number of subdivisions used in the 
% routine Nystrom). Use 'create_spline_conjugate_fcn_Nystrom'. Then 
% calculate the values of the spline interpolant to the approximation of
% the conjugate function to the double layer potential.  The evaluation 
% points are given in the vector t_eval.
%
% Following this, produce the derivative of the spline interpolant and use
% it to calculate the normal derivative of the original double layer
% potential.
%
% INPUT:
% t_eval -      These are the points on [0,L] at which the cubic spline and
%               its first derivative are to be evaluated.
% curve_obj -   This an object identifying the type of boundary
%               curve on which Laplace's equation is being solved. It also
%               includes information regarding the definition of that
%               curve.
% t_nodes -     These are the collocation points at which the density 
%               function is calculated.
% density -     These are the estimated values of the unknown dipole 
%               density function.
% multiplier_spline - The number of subdivisions of [0,L] is to equal
%               multiplier_spline*num_trap with num_trap the length of
%               t_nodes (and density).
% index_bdyf -  This is the index for the boundary function, given in the
%               external program 'bdyfcn'.
%
% OUTPUT:
% cf_values -   The values of the spline interpolant at t_eval.
% deriv_cf_values - The values of the first derivative of the spline
%               interpolant at t_eval. These values are then corrected to
%               make the derivative with respect to arc length.

curve_parms = curve_obj.curve_parms;
L = curve_parms.length;

[t_spline,spline_cf] = create_spline_conjugate_fcn_Nystrom(t_nodes,...
   density,curve_obj,multiplier_spline,index_bdyf);
[~,cf,num_int,~,~]=unmkpp(spline_cf);

delta = t_spline(3)-t_spline(1);
% Discard the interpolation points corresponding to the parameter points 
% delta/2 and L-delta/2. The cubic polynomials on [0,delta/2] and on
% [delta/2,delta] are the same, and therefore the polynomial on [0,delta/2]
% suffices for all of [0,delta].  The analogous result is true for the
% interval [L-delta,L].
t_spline = 0:delta:L;
cf = [cf(1,:)
      cf(3:num_int-1,:)];
[m,~] = size(cf);

lnth = length(t_eval);
cf_values = zeros(size(t_eval));
deriv_cf_values = zeros(size(t_eval));

for i=1:lnth
    t = t_eval(i);
    num_int = floor(1+t/delta);
    if num_int > m
        num_int = m;
    end
    if num_int < 1
        num_int = 1;
    end
    j = num_int;
    h = t - t_spline(j);
    cf_values(i) = cf(j,4)+h*(cf(j,3)+h*(cf(j,2)+h*cf(j,1)));
    deriv_cf_values(i) = cf(j,3)+h*(2*cf(j,2)+3*h*cf(j,1));
    % Correction for not using arc length as the parameterization variable
    [~,dx,~,~,dy,~] = generate_curve(t,curve_obj);
    deriv_cf_values(i) = deriv_cf_values(i)/sqrt(dx^2+dy^2);
end

end % eval_spline_conjugate_fcn_Nystrom