function potential = evaluate_potential_Nystrom(x_eval,y_eval,...
   t_nodes,density,index_bdyf,curve_obj,multiplier)

% Evaluate the double-layer potential u with the given "density" function
% at the nodes given in (x_eval,y_eval).  x_eval and y_eval can be either
% one or two dimensional arrays. We integrate over each subinterval of the 
% piecewise polynomial function using Gaussian quadrature with "num_pquad" 
% points on that subinterval. As points approach the boundary, a higher
% order numerical integration is needed to preserve the accuracy associated
% with that of the approximating double layer density function.

curve_parms = curve_obj.curve_parms;
L = curve_parms.length;
[nr,nc] = size(x_eval);

% The trapezoidal rule will be used over the boundary when integrating the
% double layer potential integral. The variable num_nodes is the number of
% subdivisions to be used in the trapezoidal rule.
num_trap = length(t_nodes); h_trap = L/num_trap;
num_quad = num_trap*multiplier;
h_quad = L/num_quad;
t_quad = h_quad*(1:num_quad)';

% Using Nystrom interpolation, extend the (double layer) density to the new
% quadrature node points. Begin by calculating the needed curve values at
% the points in t_nodes.
[x_nodes,dx_nodes,d2x_nodes,y_nodes,dy_nodes,d2y_nodes] = ...
                            generate_curve(t_nodes,curve_obj);    
[x_quad,dx_quad,~,y_quad,dy_quad,~] = generate_curve(t_quad,curve_obj);
rhs = bdyfcn(t_quad,x_quad,y_quad,index_bdyf);
density_quad = zeros(num_quad,1);

for ii=1:num_quad
    if multiplier*floor(ii/multiplier) == ii
        % Use original density value.
        density_quad(ii) = density(ii/multiplier);
    else
        % Do Nystrom interpolation.
        point_t = [x_quad(ii),y_quad(ii)];
        for j=1:num_trap
            point_s = [x_nodes(j),y_nodes(j),dx_nodes(j),dy_nodes(j),...
                d2x_nodes(j),d2y_nodes(j)];
            fker = kernel_Nystrom(point_t,point_s);
            density_quad(ii) = density_quad(ii) + fker*density(j);
        end
        density_quad(ii) = (h_trap*density_quad(ii) - rhs(ii))/pi;
    end
end

% Evaluate the potential function.
potential = zeros(nr,nc);
for ii=1:nr
    for j=1:nc
        sum = 0;
        for k=1:num_quad
            point = [x_quad(k),y_quad(k),dx_quad(k),dy_quad(k)];
            sum = sum + density_quad(k)*kernel_M(x_eval(ii,j),...
                y_eval(ii,j),point);
        end
        potential(ii,j) = h_quad*sum;
    end
end

end % evaluate_potential

%========================================================================
function value = kernel_M(x,y,point_s)

% Evaluate the double layer potential kernel function for a point (x,y)
% interior to the region of interest. For a formula, see  (7.2.57) on page
% 324 of my integral equation text.

% point_s = [x_s,y_s,dx_s,dy_s] with (x_s,y_s) the point on the boundary 
% corresponding to the integration parameterization variable s. The 
% vector (dx_s,dy_s) is the first derivative of the vector function 
% (x(s),y(s)), evaluated at the given parameterization point s.  It is 
% assumed that s, x_s, y_s, ... are each single numbers, not arrays.

x_s = point_s(1); y_s = point_s(2);
dx_s = point_s(3); dy_s = point_s(4);

denominator = (x_s-x)^2 + (y_s-y)^2;
numerator = -dy_s*(x_s-x) + dx_s*(y_s-y);
value = numerator/denominator;

end % kernel_M

