function [x,dx,d2x,y,dy,d2y] = generate_curve(t,curve_obj)

% Generate the points (x,y) on the boundary curve, corresponding to
% the parameterization variables in t.  We also generate the first 
% and second derivatives of the parameterization function.

curve = curve_obj.name;
curve_parms = curve_obj.curve_parms;
switch curve
    case 'ellipse'
        % This is the ellipse (x/a)^2 + (y/b)^2 = 1
        a = curve_parms.ellipse_a; b = curve_parms.ellipse_b;
        cs = cos(t); sn = sin(t);
        x = a*cs; y = b*sn;
        dx = -a*sn; dy = b*cs;
        d2x = -x; d2y = -y;
    case 'cardioid'
        % This defines the cardioid boundary
        %   (x,y) = r(a cos(theta),b sin(theta))
        %       r = c*cos(theta) + k
        % Choose k > c, and choose a,b > 0. 
        a = curve_parms.cardioid_a; b = curve_parms.cardioid_b;           
        c = curve_parms.cardioid_c; k = curve_parms.cardioid_k; % Cardioid parameters
        theta = t - pi;
        cs = cos(theta); sn = sin(theta);
        r = c*cs + k; dr = -c*sn; d2r = -c*cs;
        x = a*r.*cs; 
        dx = a*(dr.*cs - r.*sn); 
        d2x = a*(d2r.*cs - 2*dr.*sn - r.*cs); 
        y = b*r.*sn;
        dy = b*(dr.*sn + r.*cs);
        d2y = b*(d2r.*sn + 2*dr.*cs - r.*sn);
    case 'ellipse_kelvin'
        % This is for the inversion of the ellipse (x/a)^2 + (y/b)^2 = 1
        % through the unit circle.
        a = curve_parms.ellipse_a; b = curve_parms.ellipse_b;
        cs = cos(t); sn = sin(t);
        cs2 = cos(2*t); 
        cs3 = cos(3*t); cs5 = cos(5*t);
        sn3 = sin(3*t); sn5 = sin(5*t);
        xi = a*cs; eta = b*sn;
        rsq = xi.^2 + eta.^2;
        x = xi./rsq; y = eta./rsq;
        denom = (a^2-b^2)*cs2 + a^2+b^2; 
        dx = (a^3-5*a*b^2)*sn + (a^3-a*b^2)*sn3;
        dx = dx./denom.^2;
        dy = (5*b*a^2-b^3)*cs + (b^3-b*a^2)*cs3;
        dy = dy./denom.^2;
        d2x = (0.5*a^5-(a^3)*(b^2)+0.5*a*b^4)*cs5...
            + (26*(a^3)*(b^2)-11*a*b^4-7*a^5)*cs...
            + (10.5*a*b^4-1.5*a^5-9*(a^3)*(b^2))*cs3;
        d2x = -d2x./denom.^3;
        d2y = (1.5*b^5+9*(a^2)*(b^3)-10.5*b*a^4)*sn3 ...
            + (0.5*b^5-(a^2)*(b^3)+0.5*b*a^4)*sn5 ...
            + (26*(a^2)*(b^3)-7*b^5-11*b*a^4)*sn;
        d2y = -d2y./denom.^3;        
end

end % generate_curve