function test_normal_deriv_method_Nystrom(curve_obj,index_bdyf,test)

% Evaluate the conjugate function for the double layer density given in the
% structure 'test'. Evaluate the conjugate function at the evenly spaced 
% parameterization points obtained by subdividing [0,L] into num_plot 
% evenly spaced points. We use num_plot=201, but that can be changed to 
% being an input parameter. Use the integral formula given in (Miller,
% page 32). To evaluate the integral defining the conjugate function, we 
% use multiplier_spline*num_trap subdivisions and Gauss-Legendre quadrature
% on each subinterval. See 'create_spline_conjugate_fcn_Nystrom' for more
% detail.
%
% Following this, produce a cubic spline interpolating to the conjugate 
% function, in order to approximate the derivative of the conjugate 
% function along the boundary of the region. This derivative is then used 
% to construct the inner normal derivative of the double layer potential 
% along its boundary. Both the spline interpolant of the conjugate function
% and the normal derivative of the double layer potential along the
% boundary are graphed, and their errors are also graphed.
%
% INPUT:
% curve_obj - This structure contains information on the boundary curve
%             under consideration.
% index_bdyf - The index of the boundary function (Dirichlet data for the
%             determining the potential function.
% test -      This structure contains data obtained earlier when solving
%             the Dirichlet problem using a double layer potential.

curve_parms = curve_obj.curve_parms;
L = curve_parms.length;

% Recall the dipole density function for the double layer potential
% solving the interior Dirichlet problem for Laplace's equation.
t_nodes = test.t_nodes_Nystrom;
density = test.density_Nystrom;
num_trap = length(t_nodes);

disp(' ')
disp('Give the integer multiplying factor for the spline interpolant')
disp('nodes of the Nystrom approximation of the double layer density')
disp('function: num_spline = multiplier*num_trap. Experimentally,')
disp('multiplier = 4 or 5 seems an optimal choice.')
disp(' ')
multiplier_spline = input('multiplier = ');

% Compare our approximate conjugate function and normal derivative to the 
% true values. 
delta = 0;  % This can be changed to a small positive number.
num_plot = 201;
step_plot = (L-2*delta)/(num_plot-1);
z = step_plot*(0:num_plot-1)' + delta;

% Create the spline interpolant that approximates the conjugate function 
% on the boundary of the curve for the double layer potential.
[cf_values,deriv_cf_values] = eval_spline_conjugate_fcn_Nystrom(z,...
    curve_obj,t_nodes,density,multiplier_spline,index_bdyf);

[x,dx,~,y,dy,~] = generate_curve(z,curve_obj);
true_cf = true_conjugate_fcn(x,y,index_bdyf);
true_dv = normal_deriv_bdyf(z,x,y,dx,dy,index_bdyf);

% Normalize the conjugate function values so that they agree at the inital
% parameter value t=0.
midpt = floor((num_plot-1)/2)+1;
cf_values = cf_values - cf_values(midpt) + true_cf(midpt);

figure
plot(z,true_cf,z,cf_values,'.')
title(['Conjugate fcn approx: Nystroms method',...
    '   num of subdiv = ',num2str(num_trap),...
    '   multiplier = ',num2str(multiplier_spline)])
xlabel(['curve = ',curve_obj.name,...
    '   Boundary function ',num2str(index_bdyf)])
pause

error_cf = true_cf - cf_values;
disp(' '); 
disp(['max error in spline-based conjugate function = ',...
    num2str(norm(error_cf,inf))])
figure
plot(z,error_cf,z,error_cf,'.r')
title('Error in the conjugate function')
xlabel(['num:trap = ',num2str(num_trap),'   multiplier = ',...
    num2str(multiplier_spline)])
pause

figure
plot(z,true_dv,z,deriv_cf_values,'.')
legend('True normal derivative','Approx normal derivative')
title(['Normal derivative approx: Nystroms method',...
    '  num subdiv = ',num2str(num_trap)])
xlabel(['curve = ',curve_obj.name,'   Boundary function ',...
    num2str(index_bdyf)])
pause

error_dv = true_dv - deriv_cf_values;
disp(' '); 
disp(['max error in normal derivative = ',num2str(norm(error_dv,inf))])
figure
plot(z,error_dv,z,error_dv,'.r')
title(['Error in normal derivative: num subdiv = ',num2str(num_trap)])
xlabel(['curve = ',curve_obj.name,'   Boundary function ',...
    num2str(index_bdyf)])

end % test_normal_deriv_method_Nystrom
