function [t_nodes,approx_u] = Nystrom_IntNmn(curve_obj,normal_deriv,...
    num_trap,Fourier_degree,index_bdyf)

% This program sets up the linear system for solving the integral equation
% of the second kind based on using a direct formula relating the Dirichlet
% and Neumann data on the boundary. See (7.2.66) on page 328 of my integral
% equations text. For notation, let u denote the solution of the Laplace
% equation over the original interior region D_i, and let U denote the 
% harmonic function obtained by applying the Kelvin transform to u. The 
% function U is harmonic over the inversion of D_i through the unit circle.
% This program solves for U and then converts it to the desired solution u.
%
% The numerical method is Nystrom's method with the trapezoidal rule. The 
% right side of (7.2.66) is evaluated numerically using (7.2.69)-(7.2.72) 
% on page 328, and this carried out in 'create_rhs_NMN_Kelvin'. For the 
% relation between the normal derivative for U and that for u, see 
% (7.1.16) on page 312. The latter is used in the program 
% 'create_rhs_NMN_Kelvin'.
%
% This program is intended only for regions with a smooth boundary. 

% Input parameters:
% curve_obj -   This is an object identifying the type of boundary
%               curve on which Laplace's equation is being solved. It also
%               includes information regarding the definition of that
%               curve.
% normal_deriv - The function defining the given normal derivative over the
%               interior region.
% num_trap -    The number of quadrature points for the definition of the
%               numerical integration approximation of the double layer 
%               operator.
% Fourier_degree - The degree of the Fourier approximation of the given 
%               normal derivative, to be used in 'create_rhs_NMN'.
% index_bdyf -  This is the index of the boundary function, given in the
%               external program 'normal_deriv_bdyf'.

% Output values:
% t_nodes -     These are the node points at which the density function
%               is approximated.
% density -     These are the estimated values of the unknown double layer
%               density function.

% The parameterization interval is [0,2*pi].
% Create the quadrature nodes and the subdivision of [0,2*pi].
h_trap = 2*pi/num_trap;
t_nodes = h_trap*(1:num_trap)';
[~,point_kelvin] = generate_curve_Kelvin(t_nodes,curve_obj);
x_nodes = point_kelvin.xk; y_nodes = point_kelvin.yk; 
dx_nodes = point_kelvin.dxk; dy_nodes = point_kelvin.dyk; 
d2x_nodes = point_kelvin.d2xk; d2y_nodes = point_kelvin.d2yk; 

% Calculate the array of kernel values to be used in evaluating the
% collocation integrals.
K_matrix = generate_K_Nystrom(num_trap,x_nodes,y_nodes,dx_nodes,...
    dy_nodes,d2x_nodes,d2y_nodes);

% Create the Nystrom system matrix.
KM = -pi*eye(num_trap) + h_trap*K_matrix;

% Create the right hand side of the linear system.
num_quad = max(100,3*Fourier_degree + 1);  % num_quad > 99.
rhs = create_rhs_NMN_Kelvin(normal_deriv,t_nodes,x_nodes,y_nodes,...
    index_bdyf,Fourier_degree,num_quad,curve_obj);

if is_row(rhs)
    rhs = rhs';
end

% Solve the double-layer density function.
approx_u = KM\rhs;

end % Nystrom_IntNmn
