function rhs = create_rhs_NMN_Kelvin(normal_deriv,t,x_t,y_t,...
          index_bdyf,Fourier_degree,num_quad,curve_obj)

% Create the right hand function g used in (7.2.66) when using a direct
% boundary integral equation for solving the Neumann problem. See
% page 328 of my integral equations text; and see formulas (7.2.72),
% (7.2.74), and (7.2.71). It is also necessary to approximate the given
% normal derivative (see 'normal_deriv_quad') multiplied by the boundary
% curve Jacobian by a Fourier series, which is then used in (7.2.74). 

% INPUT PARAMETERS:
% t,x_t,y_t -   The points at which the right side of (7.2.66) is to be
%               evaluated.
% index_bdyf -  This is the index of the boundary function, given in the
%               external program 'normal_deriv_bdyf'.
% Fourier_degree - The degree of the Fourier approximation of the given 
%               normal derivative.
% num_quad -    The number of subdivisions to be used in the numerical
%               integration of the Fourier coefficients of the given normal
%               derivative and the integral operator B_n. It should be
%               greater than 2*Fourier_degree. In the calling program 
%               'Nystrom_IntNmn', wegenerally require num_quad to be at
%               least 100.
% curve_obj -   This is an object identifying the type of boundary
%               curve on which Laplace's equation is being solved. It also
%               includes information regarding the definition of that
%               curve.

if is_row(t)
    t = t';
end
M = length(t); 

h = 2*pi/num_quad; s_quad = (h:h:2*pi)';
[point_orig_s,point_kelvin_s] = generate_curve_Kelvin(s_quad,curve_obj);
normal_deriv_quad = normal_deriv(point_orig_s,index_bdyf);
x_s = point_kelvin_s.xk; y_s = point_kelvin_s.yk;
dx_s = point_kelvin_s.dxk; dy_s = point_kelvin_s.dyk;
normal_deriv_quad = -normal_deriv_quad./(x_s.^2+y_s.^2);
phi = normal_deriv_quad.*sqrt(dx_s.^2+dy_s.^2);

% Approximate Fourier coefficients of phi.
deg = Fourier_degree;     % Abbreviation
Basis_matrix = zeros(2*deg+1,num_quad);
for m=-deg:deg
    Basis_matrix(m+deg+1,:) = basis(s_quad',-m);
end
phi_hat = h*Basis_matrix*phi;     % Approximate Fourier coefficients

absm = abs((-deg:deg)'); absm(deg+1) = 1;
phi_hat = phi_hat./absm;

% Approximate B*phi in (7.2.72) using the trapezoidal rule.
rhs1 = zeros(M,1);
B_matrix = zeros(M,num_quad);
for j=1:M
    point_t = [t(j),x_t(j),y_t(j)];
    for k=1:num_quad
        point_s = [s_quad(k),x_s(k),y_s(k),dx_s(k),dy_s(k)];
        B_matrix(j,k) = kernel_B(point_t,point_s);
        rhs1(j)= rhs1(j) + B_matrix(j,k)*phi(k);
    end
end
rhs1 = h*rhs1;

% Approximate A*phi using a truncation of (7.2.74).
rhs2 = zeros(M,1);
for m=-deg:deg
    rhs2 = rhs2 + phi_hat(m+deg+1)*basis(t,m);
end

rhs = rhs1 - pi*rhs2;   % See (7.2.72) on page 328 in my text.
rhs = real(rhs);

end % create_rhs_NMN_Kelvin

