function demo_Nystrom_IntNmn(curve,num_trap,Fourier_degree,index_bdyf)

% Copyright 2013 by Kendall Atkinson
%
% This program solves the interior Neumann problem for Laplace's equation.
% The method begins by transforming the interior problem to an exterior
% problem using the Kelvin transform. For notation, let u denote the 
% solution of the Laplace equation over the original interior region D_i, 
% and let U denote the harmonic function obtained by applying the Kelvin 
% transform to u. The function U is harmonic over the inversion of D_i 
% through the unit circle. This program solves for U and then converts it 
% to the desired solution u. The program 'Nystrom_IntNmn' is then used, 
% and it is a minor modification of 'Nystrom_ExtNmn'.
%
% After reformulation as an exterior problem, we solve an integral  
% equation of the second kind that is based on using a direct 
% formulation relating the Dirichlet and Neumann data on the boundary. See 
% (7.2.66) on page 328 of my integral equations text. Since the interior
% Neumann problem is unique only up to the addition of an arbitrary
% constant, the solution found here will be zero at the origin. This test
% program finds only the Dirichlet data on the boundary, not the interior
% solution, although that can be added. 
%
% The region is to be simply-connected with a smooth boundary; and the 
% origin is assumed to be in the interior of the boundary. Two sample 
% regions are given in the subprogram 'set_bdy_param', located following 
% the present program.  In addition, we provide a special print instruction
% for each curve, called 'print_curve_data',again located following
% this current test program.
%
% For the test boundary value functions, and thus true solutions, see 
% the programs 'bdyfcn' and 'normal_deriv_bdyf'.
%
% The numerical method is Nystrom's method, carried out in the program 
% 'Nystrom_IntNmn'. The user gives the normal derivative over the boundary
% and this is converted to the normal derivative over the Kelvin
% transformed boundary; see 'create_rhs_NMN_Kelvin'. The program 
% 'Nystrom_IntNmn' approximates the solution u over the boundary, with the 
% added requirement u(0,0)=0 to obtain uniquesness. 
%
% This program will request information defining the curve.  At each point
% (x,y), the double layer integral will be approximated using the 
% trapezoidal rule.
%
% As a demonstration, use one of the commands and sample data.
%       demo_Nystrom_IntNmn('ellipse',40,10,1)     Use a=1, b=2
%       demo_Nystrom_IntNmn('cardioid',40,10,1)    Use c=0.8, k=1.0, a=b=1
%
% The user must specify the name of the curve; see the function
% 'set_bdy_param' given below for examples defining a curve. You must also
% provide the number of subdivisions, called 'num_trap', and a quantity 
% called 'Fourier_degree' which is used in approximating the right side
% of (7.2.66). You must also provide 'index_bdyf', the index of the problem
% that is to be solved. Other parameters given below can be changed.  
%
% For information on the meaning of these parameters, type
%                help info_Nystrom_IntNmn
%
% The structure 'curve_obj' is to contain the name of the curve and the
% structure 'curve_parms'.  The latter contains the data defining the
% curve, and this will vary with the curve being considered.

% INPUT:
% curve -       The name of the boundary curve.
% Fourier_degree - The degree of the Fourier approximation of the given 
%               normal derivative, used in create_rhs_NMN to compute
%               the right side of the integral equation (7.2.66).
% num_trap -    The number of subdivisions used in applying the Nystrom
%               method with the trapezoidal rule to the solution of the
%               double layer potential integral equation.
% index_bdyf -  This is the index for the boundary function, given in the
%               external program 'bdyfcn'.

% Print the input parameters.
disp(' ')
disp('INPUT PARAMETERS:')
disp(['curve = ',curve])
disp(['index_bdyf = ',num2str(index_bdyf)])
disp(['num_trap = ',num2str(num_trap)])
disp(['Fourier_degree = ',num2str(Fourier_degree)])
disp(' ')

% Set up information about the boundary curve.
[curve_parms, ~, ~] = set_bdy_param(curve);
disp(' ')
curve_obj.name = curve;
curve_obj.curve_parms = curve_parms;
num_plot_curve_points = 200;
draw_bdy_Kelvin(curve_obj,num_plot_curve_points)
figure(gcf)
pause

% Solve for the unknown solution u at the node points as determined by the
% parameter num_trap.
[t_nodes_Nystrom,approx] = Nystrom_IntNmn(curve_obj,...
    @normal_deriv_bdyf,num_trap,Fourier_degree,index_bdyf);

% Print the solution at the node points.
%figure
%plot(t_nodes_Nystrom,approx)
%name = curve_obj.name;
%title(['Interior Neumann Problem on ',name,...
%    ': The boundary solution using the Nystrom node points'])
%xlabel(['curve = ',curve_obj.name,'   Boundary function ',...
%    num2str(index_bdyf),'   Fourier degree = ',num2str(Fourier_degree)])
%print_curve_data(curve)
%pause

% Compare our approximate solution to the true solution over a grid of
% num_plot evenly spaced points in [0,2pi].
num_plot = 201;
step_plot = 2*pi/(num_plot-1);
z = step_plot*(0:num_plot-1)';
[point_orig_z,point_kelvin_z] = generate_curve_Kelvin(z,curve_obj);
true_u = bdyfcn(point_orig_z,index_bdyf);

% Generate the approximate solution values at the nodes in z. This will be
% done with Nystrom interpolation. Denote this new set of values by
% approx_u. 

% Produce data for evaluating double-layer integral term at points in z.
num_quad = max(100,3*Fourier_degree + 1);

xk = point_kelvin_z.xk; yk = point_kelvin_z.yk;
rhs_at_z = create_rhs_NMN_Kelvin(@normal_deriv_bdyf,z,xk,yk,...
                         index_bdyf,Fourier_degree,num_quad,curve_obj);
Lt = length(t_nodes_Nystrom); h = 2*pi/Lt;
[~,point_kelvin_s] = generate_curve_Kelvin(t_nodes_Nystrom,curve_obj);
x_s = point_kelvin_s.xk; y_s = point_kelvin_s.yk; 
dx_s = point_kelvin_s.dxk; dy_s = point_kelvin_s.dyk; 
d2x_s = point_kelvin_s.d2xk; d2y_s = point_kelvin_s.d2yk; 

interp = zeros(num_plot,1);
kern = zeros(num_plot,Lt);
for i=1:num_plot
    point_t = [xk(i) yk(i)];
    for j=1:Lt
        point_s = [x_s(j),y_s(j),dx_s(j),dy_s(j),d2x_s(j),d2y_s(j)];
        kern(i,j) = kernel_Nystrom(point_t,point_s);
        kernel = kern(i,j);
        interp(i) = interp(i) + kernel*approx(j);
    end
end
interp = h*interp;
approx_u = (interp - rhs_at_z)/pi;

% Normalize the approximate solution values so that they agree with the 
% true values at the node point z(midpt).
midpt = floor((num_plot-1)/2)+1;
approx_u = approx_u - approx_u(midpt) + true_u(midpt);

% Print the true solution and approximate solution.
figure
plot(z,true_u,z,approx_u)
legend('true u','approx u')
title(['Approx solution on boundary: Nystrom method',...
    '  num subdiv = ',num2str(num_trap)])
xlabel(['curve = ',curve_obj.name,'   Boundary function ',...
    num2str(index_bdyf),'   Fourier degree = ',num2str(Fourier_degree)])
pause

% Print the error.
error_u = true_u - approx_u;
disp(' '); 
disp(['max error in solution = ',num2str(norm(error_u,inf))])
figure
plot(z,error_u)
title(['Error in solution: num subdiv = ',num2str(num_trap)])
xlabel(['curve = ',curve_obj.name,'   Boundary function ',...
    num2str(index_bdyf),'   Fourier degree = ',num2str(Fourier_degree)])

%pause

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function print_curve_data(curve)
% The following print contains curve dependent parameters.
switch curve
    case 'ellipse'
        a = curve_parms.ellipse_a; b = curve_parms.ellipse_b;     % Ellipse parameters        
        xlabel(['a = ',num2str(a),'   b = ',num2str(b),...
            '   num:trap = ',num2str(num_trap)])
    case 'cardioid'
        a = curve_parms.cardioid_a; b = curve_parms.cardioid_b;           
        c = curve_parms.cardioid_c; k = curve_parms.cardioid_k; % Cardioid parameters
        xlabel(['c = ',num2str(c),'   k = ',num2str(k),...
            '   a = ',num2str(a),'   b = ',num2str(b),'   num:trap = ',...
            num2str(num_trap)])
end
end % print_curve_data

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

end % test_Nystrom_IntNmn

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function [curve_parms, grading_param, spacing] = set_bdy_param(curve)
    
switch curve
    case 'ellipse'
        % Define the object containing the needed curve parameters for an ellipse.
        curve_parms.length = 2*pi;    % The length of the parameterization interval.
        disp('Give curve parameters for the ellipse.')
        disp('      (x/a)^2 + (y/b)^2 = 1')
        a = input('a = '); b = input('b = ');
        curve_parms.ellipse_a = a; curve_parms.ellipse_b = b; 
    case 'cardioid'
        % Define the object containing the needed curve parameters for a cardioid.
        % Initially try c=.8, k=1, a=b=1.
        curve_parms.length = 2*pi;    % The length of the parameterization interval.
        disp('Give the parameters for the cardioid')
        disp('(x,y) = (c*cos(t)+k)*(a*cos(t),b*sin(t)),   k > c')
        c = input('c = '); k = input('k = '); 
        a = input('a = '); b = input('b = ');
        curve_parms.cardioid_a = a; curve_parms.cardioid_b = b; 
        curve_parms.cardioid_c = c; curve_parms.cardioid_k = k; 
end

switch curve
    case 'ellipse'
        curve_parms.int_pt = [0 0];
    case 'cardioid'
        curve_parms.int_pt = [a*c,0];
end

% Allow input of grading parameter for the case of curve='teardrop'.
switch curve
    case 'ellipse'
        grading_param = 1;
        spacing = 'uniform';
    case {'cardioid'}
        grading_param = 1;
        spacing = 'uniform';
end

end % set_bdy_param
